package com.anssi.ebios.services
{
	import com.anssi.ebios.model.Action;
	import com.anssi.ebios.model.Activite;
	import com.anssi.ebios.model.Deliverable;
	import com.anssi.ebios.model.ModuleEbios;
	import com.anssi.ebios.model.Regle;
	import com.anssi.ebios.model.RiskCriteria;
	
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLErrorEvent;
	import flash.events.SQLEvent;
	
	import mx.collections.ArrayCollection;
	import mx.rpc.IResponder;
	import mx.utils.ObjectUtil;
	
	public class ActionService extends AppServices
	{
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement;
		
		private var _actionList:ArrayCollection;
		private var _indexActionToUpdate:int = -1;
		private var _stageList:ArrayCollection;
		private var _whereInCondition:String = "";
		private var _whereNotInCondition:String = "";
		private var _idDeliverable:Number;
		
		public function ActionService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		/** ******* PUBLIC SERVICE METHODE ******** **/
		
		public function getAction():void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = 
				
			"SELECT A.libelle as action_libelle, numero, A.idACTION as idAction, retenu, idREGLE , R.libelle as regle_libelle "+
			"from ACTION A "+
			"LEFT OUTER JOIN REGLE R "+
			"ON  A.idAction = R.idAction";
				
			_sqlStatement.text = query;	
			_sqlStatement.addEventListener(SQLEvent.RESULT,getActionResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		public function updateActionRegle(actionList:ArrayCollection):void
		{
			if(actionList)
			_actionList = actionList;
			
			_indexActionToUpdate ++
			if (_indexActionToUpdate >= _actionList.length ) {
				
				_indexActionToUpdate = -1;
				_sqlStatement.sqlConnection.close();
				responder.result(null);
				return;
			}
			
			
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			
			var action:Action = _actionList.getItemAt(_indexActionToUpdate) as Action;
			
			var sql:String;
			if(Number(action.regle.id)>0)
			{
				sql = 
					"UPDATE  REGLE " +
					" SET libelle = :libelle, dateModification = :dateModification " +
					" WHERE REGLE.idACTION= :idACTION";
				_sqlStatement.clearParameters();
				_sqlStatement.parameters[":dateModification"] = new Date();
			}
			else
			{
				sql = 
					
					"INSERT INTO REGLE (libelle, idACTION, dateCreation, dateModification) " +
					" VALUES (:libelle, :idACTION, :dateCreation, :dateModification)";
				_sqlStatement.clearParameters();
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();
			}

			_sqlStatement.parameters[":libelle"] = action.regle_libelle;
			_sqlStatement.parameters[":idACTION"] = action.id;
			_sqlStatement.text = sql;
			
			_sqlStatement.addEventListener(SQLEvent.RESULT,updateActionRegleResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		

			
		}
		
		public function getActionByKey(key:String):void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = 
				
				"SELECT A.libelle as action_libelle, numero, A.idACTION as idAction, idREGLE , R.libelle as regle_libelle "+
				" from ACTION A "+
				" LEFT OUTER JOIN REGLE R "+
				" ON  A.idAction = R.idAction "+
				" WHERE  A.numero = :key";
			
			
			_sqlStatement.text = query;
			
			_sqlStatement.parameters[":key"] = key;
			
			_sqlStatement.addEventListener(SQLEvent.RESULT,getActionByIdResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		
		
		/** ******* PRIVATE HANDLER ******** **/
		
		private function getActionByIdResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			if (result != null && result.data != null)
			{
				var row:Object= result.data[0];
				var action:Action = new Action();	
				action.id= row["idAction"];
				action.actionKey = row["numero"];
				action.libelle = row["action_libelle"];
				var regle:Regle = new Regle();
				regle.id = row["idREGLE"];
				regle.libelle = row["regle_libelle"];
				action.regle = regle;
				
			}
			_sqlStatement.sqlConnection.close();
			responder.result(action);
		}
		private function getActionResult(event:SQLEvent):void
		{	
			var actionList:ArrayCollection = new ArrayCollection();
			var result:SQLResult = SQLStatement(event.target).getResult();
			if (result != null && result.data != null){
				actionList = constructActionList(result);	
			}
			_sqlStatement.sqlConnection.close();
			responder.result(actionList);
		}
			
		public function constructActionList(result:SQLResult):ArrayCollection{
			var actionList:ArrayCollection = new ArrayCollection();
			
			if (result != null && result.data != null)
			{
				actionList = new ArrayCollection();
				
				var row:Object;
				var numRows:int = result.data.length;
				var action:Action;
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					action = new Action();	
					action.id= row["idAction"];
					action.actionKey = row["numero"];
					action.libelle = row["action_libelle"];
					action.retained = row["retenu"];
					//action.activityId = row["idACTIVITE"];
					
					var regle:Regle = new Regle();
					regle.id = row["idREGLE"];
					regle.libelle = row["regle_libelle"];
					
					action.regle = regle;
					actionList.addItem(action);
				}
			}
			
			return actionList;
		}
		
		private function updateActionRegleResult(event:SQLEvent):void {
			updateActionRegle(null);
		}
		
		
		public function getStagesTree():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "SELECT m.idMODULE, m.libelle as libelle_mod, m.numero as numero_mod, activ.idACTIVITE, activ.libelle as libelle_activ, activ.numero as numero_activ, actio.idACTION, actio.libelle as libelle_actio, actio.numero, actio.vue "+
								" FROM MODULE m "+
								" LEFT JOIN ACTIVITE activ ON activ.idMODULE=m.idMODULE "+
								" LEFT JOIN ACTION actio ON actio.idACTIVITE=activ.idACTIVITE "+
								" WHERE actio.RETENU=1 "+
								" ORDER BY m.idMODULE, activ.idACTIVITE, actio.idACTION";
			
			_sqlStatement.text = query;	
			_sqlStatement.addEventListener(SQLEvent.RESULT,getStagesTreeResult);
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getStagesTreeResult(event:SQLEvent):void{
			var modules:ArrayCollection = null;
			var result:SQLResult = SQLStatement(event.target).getResult();
			if (result != null && result.data != null)
			{
				modules = new ArrayCollection();
				
				var row:Object;
				var numRows:int = result.data.length;
				var tmpModule:ModuleEbios;
				var tmpActivite:Activite;
				var tmpAction:Action;
				
				var oldModuleId:String = "-1";
				var oldActiviteId:String = "-1";
				var oldActionId:String = "-1";
				
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					
					if(oldModuleId != row["idMODULE"]){
						tmpModule = new ModuleEbios();
						tmpModule.id = row["idMODULE"];
						tmpModule.libelle = row["libelle_mod"];
						tmpModule.numero = row["numero_mod"];
						oldModuleId = tmpModule.id;
						oldActiviteId = "-1";
						oldActionId = "-1";
						modules.addItem(tmpModule);
					}
					
					if(oldActiviteId != row["idACTIVITE"]){
						tmpActivite = new Activite();
						tmpActivite.id = row["idACTIVITE"];
						tmpActivite.libelle = row["libelle_activ"];
						tmpActivite.numero = row["numero_activ"];
						tmpActivite.module = tmpModule;
						tmpModule.activites.addItem(tmpActivite);
						oldActiviteId = tmpActivite.id;
						oldActionId = "-1";
					}
					
					if(oldActionId != row["idACTION"]){
						tmpAction = new Action();
						tmpAction.id = row["idACTION"];
						tmpAction.libelle = row["libelle_actio"];
						tmpAction.actionKey = row["numero"];
						tmpAction.vueTechnique = (row["vue"] != "null")?row["vue"]:"";
						tmpAction.activite = tmpActivite;
						tmpActivite.actions.addItem(tmpAction);
						oldActionId = tmpAction.id;
					}
					
				}
			}
			_sqlStatement.sqlConnection.close();
			responder.result(modules);
		}
		
		
		
		public function isStudyStagesDefined():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "SELECT COUNT(*) as nbActionRetenues FROM ACTION WHERE RETENU=1";
			
			_sqlStatement.text = query;	
			_sqlStatement.addEventListener(SQLEvent.RESULT,isStudyStagesDefinedResult);
			openAndExecStatementInAsyncMode(_sqlStatement);				
		}
		
		private function isStudyStagesDefinedResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var stagesDefined:Boolean = false;
			if (result != null && result.data != null)
			{
				var row:Object;
				var numRows:int = result.data.length;
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					trace('nbActionRetenues:'+row["nbActionRetenues"]);
					if((row["nbActionRetenues"] as Number) > 0) stagesDefined = true;
					break;
				}	
			}
			_sqlStatement.sqlConnection.close();
			responder.result(stagesDefined);
		}
		
		public function getStages():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "SELECT * FROM ACTION WHERE RETENU=1 ORDER BY idACTION";
			
			_sqlStatement.text = query;	
			_sqlStatement.addEventListener(SQLEvent.RESULT, getStagesResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function getStagesResult(event:SQLEvent):void{
			var actions:ArrayCollection = null;
			var result:SQLResult = SQLStatement(event.target).getResult();
			if (result != null && result.data != null)
			{
				actions = new ArrayCollection();
				
				var row:Object;
				var numRows:int = result.data.length;
				var tmpAction:Action;
				
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					tmpAction = new Action();
					tmpAction.id = row["idACTION"];
					tmpAction.libelle = row["libelle"];
					tmpAction.actionKey = row["numero"];
					tmpAction.retained = row["retenu"];
					tmpAction.vueTechnique = (row["vue"] != "null")?row["vue"]:"";
					actions.addItem(tmpAction);
				}
			}
			_sqlStatement.sqlConnection.close();
			responder.result(actions);
		}
		
		
		public function getStageByDeliverable(id:Number):void{
			
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = 
				
				"SELECT ACTION.idACTION as action_idACTION, ACTION.libelle as action_libelle, ACTION.retenu as action_retenue, ACTION.numero as action_numero, R.idLIVRABLE as idLIVRABLE, R.idACTION as requerir_action "+ 
			    "FROM ACTION "+
			    "LEFT OUTER JOIN REQUERIR R ON R.idACTION = ACTION.idACTION and R.idLivrable in ("+id+")";
			
			_sqlStatement.text = query;	
			//_sqlStatement.parameters[":idLIVRABLE"] = id;
			_sqlStatement.addEventListener(SQLEvent.RESULT, getStageByDeliverableResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		
		private function getStageByDeliverableResult(event:SQLEvent):void{
			var actionList:ArrayCollection = new ArrayCollection();
			var result:SQLResult = SQLStatement(event.target).getResult();
			if (result != null && result.data != null)
			{
				
				var row:Object;
				var numRows:int = result.data.length;
				var action:Action;
				
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					action = new Action();
					action.id = row["action_idACTION"];
					action.libelle = row["action_libelle"];
					action.actionKey = row["action_numero"];
					
					action.regle = new Regle();
					
					if (row["idLIVRABLE"] != null){
						action.retained = true;
					}else{
						action.retained = false;
					}				
					
					actionList.addItem(action);
				}
			}
			_sqlStatement.sqlConnection.close();
			responder.result(actionList);
		}
		
		public function updateStages(stageList:ArrayCollection):void{
			var str:String = "";
			for (var i:int = 0; i < stageList.length; i++){
				
				var action:Action = stageList.getItemAt(i) as Action;
				
				if (i==0){
					str += "(" + action.id + ",";
				}
				
				if (i > 0 && i < stageList.length - 1){
					str += action.id + ","
				}
				
				if (i == stageList.length - 1){
					str += action.id + ")";
				}
			}
			
			if (stageList.length > 0){
				_whereInCondition = " WHERE idACTION IN " + str;
				_whereNotInCondition = " WHERE idACTION NOT IN " + str;
			}else{
				//Si la liste est vide il faut mettre retenu à false pour toutes les actions
				_whereNotInCondition = "";
				_whereInCondition = " WHERE idACTION IN ()";
			}
			
						
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = " UPDATE ACTION SET retenu = false, dateModification = :dateModification  " + _whereNotInCondition;
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":dateModification"] = new Date();

			
			_sqlStatement.text = query;	
			_sqlStatement.addEventListener(SQLEvent.RESULT, updateStagesResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function updateStagesResult(event:SQLEvent):void{
			updateRetainedStage();
		}
		
		
		private function updateRetainedStage():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = " UPDATE ACTION SET retenu = true, dateModification = :dateModification  " + _whereInCondition;
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":dateModification"] = new Date();

			
			_sqlStatement.text = query;	
			_sqlStatement.addEventListener(SQLEvent.RESULT, updateRetainedStageResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function updateRetainedStageResult(event:SQLEvent):void{
			_sqlStatement.sqlConnection.close();
			responder.result(null);
		}
		
		/** 1) DELETE de la table REQUERIR de chaque actions pour l'ID Livrable
		 *  2) INSERTION pour chaques actions ayant l'ID livrable affecté
		 *  3) MISE A JOUR de la table ACTION (retenu à true pour chaques actions) */
		public function affectStagesToDeliverable(idDeliverable:Number, stageList:ArrayCollection):void{
			
			_stageList = stageList;
			_idDeliverable = idDeliverable;
			
	
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = " DELETE FROM REQUERIR WHERE idLIVRABLE = :idLIVRABLE ";		 
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idLIVRABLE"] = idDeliverable;
			_sqlStatement.text = query;	
			_sqlStatement.addEventListener(SQLEvent.RESULT, affectStagesToDeliverableResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
			
		}
		
		private function affectStagesToDeliverableResult(event:SQLEvent):void{
			_indexActionToUpdate = -1;
			affectStages();
		}
		
		private function affectStages():void{
			_indexActionToUpdate++;
			var action:Action;
			
			if (_indexActionToUpdate < _stageList.length){
				action = _stageList.getItemAt(_indexActionToUpdate) as Action;
				
				setBDDName();
				_sqlStatement = new SQLStatement();
				_sqlStatement.sqlConnection = this.sqlConnection;
				var query:String = " INSERT INTO REQUERIR (idACTION, idLIVRABLE, dateCreation, dateModification) " +
					" VALUES (:idACTION, :idLIVRABLE, :dateCreation, :dateModification) ";		 
				_sqlStatement.clearParameters();
				
				
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();
				_sqlStatement.parameters[":idACTION"] = action.id;
				_sqlStatement.parameters[":idLIVRABLE"] = _idDeliverable;
				_sqlStatement.text = query;	
				_sqlStatement.addEventListener(SQLEvent.RESULT, affectStagesResult);
				openAndExecStatementInAsyncMode(_sqlStatement);
			}
			else
			{
				_sqlStatement.sqlConnection.close();
				responder.result(null);
			}
		}
		
		private function affectStagesResult(event:SQLEvent):void{
			affectStages();
		}
		
		
		public function getRiskCriteria():void
		{
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = 
				
				"SELECT ifnull(A.libelle,'') as action_libelle, A.idACTION, ifnull(A.numero,'') as action_numero, A.idACTION as idAction, idREGLE , R.libelle as regle_libelle "+
				" from ACTION A "+
				" LEFT OUTER JOIN REGLE R "+
				" ON  A.idAction = R.idAction "+
				" ORDER BY numero desc";
			
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getRiskCriteriaResult);
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getRiskCriteriaResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var riskCriteriaList:ArrayCollection = new ArrayCollection();
			if (result!=null && result.data!=null){
				riskCriteriaList = constructRiskCriteriaList(result);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(riskCriteriaList);
		}
		
		private function constructRiskCriteriaList(result:SQLResult):ArrayCollection{
			
			
			var riskCriteriaList:ArrayCollection = new ArrayCollection();
			
			var row:Object;
			var numRows:int = result.data.length;
			var riskCriteria:RiskCriteria;
			
			for( var i:int=0; i< numRows;i++)
			{
				row=result.data[i];
				
				if(row["idACTION"]>0){
					
					riskCriteria= new RiskCriteria();
					riskCriteria.label=row["regle_libelle"];
					riskCriteria.libelle=row["action_libelle"];
					riskCriteria.actionKey=row["action_numero"];
					riskCriteriaList.addItem(riskCriteria);
					
				}
			}
			
			return riskCriteriaList;
			
		}
		
		public function constructActionQuery(WHERECondition:String = ""):String{
			return "SELECT A.libelle as action_libelle, numero, A.idACTION as idAction, retenu, idREGLE , R.libelle as regle_libelle "+
				"from ACTION A "+
				"LEFT OUTER JOIN REGLE R "+
				"ON  A.idAction = R.idAction";
		} 

	}
}