package com.anssi.ebios.services
{
	import com.anssi.ebios.model.Action;
	import com.anssi.ebios.model.Deliverable;
	
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLEvent;
	
	import mx.collections.ArrayCollection;
	import mx.rpc.IResponder;

	public class DeliverableService extends AppServices
	{
		
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement; 
		private var _deliverableList:ArrayCollection;
		private var _currentIndex:Number = -1;
		
		public function DeliverableService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		
		/********************************************/
		/** Récupération de la liste des livrables **/
		/********************************************/
		public function getDeliverableList():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = 
			"SELECT LIVRABLE.* , REQUERIR.idACTION "+
			"FROM LIVRABLE "+
			"LEFT OUTER JOIN REQUERIR ON REQUERIR.idLIVRABLE = LIVRABLE.idLIVRABLE; ";
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getDeliverableListResult);

			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function getDeliverableListResult(event:SQLEvent):void{
			var deliverableList:ArrayCollection = new ArrayCollection();
			// récupération des résultats
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			// si nous avons des résultats
			
			if (result != null && result.data != null)
			{
				deliverableList = constructDeliverableList(result);
			}			
			
			_sqlStatement.sqlConnection.close();
			responder.result(deliverableList);
		}
		
		private function constructDeliverableList(result:SQLResult):ArrayCollection{
			var deliverableList:ArrayCollection = new ArrayCollection();

			var row:Object;
			var numRows:int = result.data.length;
			var deliverable:Deliverable = null;
			
			var utilIdLivrable:Number = -1;
			
			for (var i:int = 0; i < numRows; i++)
			{
				
				row = result.data[i];
				
				if(utilIdLivrable != row["idLIVRABLE"])
				{
					utilIdLivrable = row["idLIVRABLE"];
					
					deliverable = new Deliverable();
					deliverable.id = row["idLIVRABLE"];
					deliverable.label = row["libelle"];
					deliverable.produce = row["produire"];
					deliverable.trame = row["trame"];
					
					deliverable.actionList = new ArrayCollection();
					
					deliverableList.addItem(deliverable);
				}
				
				if(row["idACTION"] != null)
				{
					var action:Action = new Action();
					action.id = row["idACTION"];
					deliverable.actionList.addItem( action );
				}

				
			}
			return deliverableList;
		}
		
		
		/*******************************************************/
		/** Récupération de la liste des livrables à produire **/
		/*******************************************************/
		public function getDeliverableToProductList():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "SELECT * FROM LIVRABLE WHERE produire = true";
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getDeliverableToProductListResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function getDeliverableToProductListResult(event:SQLEvent):void{
			var deliverableToProductList:ArrayCollection = new ArrayCollection();
			// récupération des résultats
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			// si nous avons des résultats
			
			if (result != null && result.data != null)
			{
				deliverableToProductList = constructDeliverableList(result);
			}			
			
			_sqlStatement.sqlConnection.close();
			responder.result(deliverableToProductList);
		}
		
		/*******************************************/
		/** Mise à jour de la liste des livrables **/
		/*******************************************/
		public function updateDeliverableList(deliverableList:ArrayCollection):void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "UPDATE LIVRABLE SET produire = false, dateModification = :dateModification ";
			
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":dateModification"] = new Date();
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,updateDeliverableListResult);
			
			_deliverableList = deliverableList;
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function updateDeliverableListResult(event:SQLEvent):void{
			_currentIndex = -1
			affectDeliverable();
		}
		
		private function affectDeliverable():void{
			_currentIndex++;
			
			if (_currentIndex < _deliverableList.length){
				var deliverable:Deliverable = _deliverableList.getItemAt(_currentIndex) as Deliverable;
				
				setBDDName();
				
				_sqlStatement = new SQLStatement();
				
				_sqlStatement.sqlConnection = this.sqlConnection;
				var query:String = "UPDATE LIVRABLE SET produire = true, dateModification = :dateModification  WHERE idLIVRABLE = :idLIVRABLE";
				
				_sqlStatement.clearParameters();
				_sqlStatement.parameters[":dateModification"] = new Date();
				_sqlStatement.parameters[":idLIVRABLE"] = deliverable.id;
				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,affectDeliverableResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);
				
				
				
			}else{
				_sqlStatement.sqlConnection.close();
				
				updateActionByStage(_deliverableList)
				
				//responder.result(null);
			}
		}
		private var _whereInCondition:String;
		private function updateActionByStage(deliverableList:ArrayCollection):void
		{
			var str:String = "";
			for each (var deliverable:Deliverable in deliverableList)
			{
				if(deliverable.actionList)
				{
					for (var i:int = 0; i < deliverable.actionList.length; i++){
						
						var action:Action = deliverable.actionList.getItemAt(i) as Action;
						str = str+","+action.id;
					}
				}
				
			}

			if(str.length>0)
			{
				str = str.substr(1);
				
				str = '('+str+')';
				
				var whereInCondition:String = " WHERE idACTION IN " + str;
				
				_sqlStatement = new SQLStatement();
				_sqlStatement.sqlConnection = this.sqlConnection;
				var query:String = " UPDATE ACTION SET retenu = true, dateModification = :dateModification  " + whereInCondition;
				_sqlStatement.clearParameters();
				_sqlStatement.parameters[":dateModification"] = new Date();
				
				
				_sqlStatement.text = query;	
				_sqlStatement.addEventListener(SQLEvent.RESULT, updateRetainedStageResult);
				openAndExecStatementInAsyncMode(_sqlStatement);
			}
			else
			{
				_sqlStatement.sqlConnection.close();
				responder.result(null);
			}
			
		}
		
		private function updateRetainedStageResult(event:SQLEvent):void{
			_sqlStatement.sqlConnection.close();
			responder.result(null);
		}
		
		private function affectDeliverableResult(event:SQLEvent):void{
			affectDeliverable();
		}
		
		public function createDelivrable(delivrable:Deliverable):void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = 
				
				"INSERT INTO LIVRABLE ( libelle, description, trame, dateCreation, produire, dateModification) "+
				" VALUES (:libelle, :description, :trame, :dateCreation, :produire, :dateModification)";
			
			
			_sqlStatement.parameters[":libelle"] = delivrable.label;
			_sqlStatement.parameters[":description"] = delivrable.description;
			_sqlStatement.parameters[":trame"] = delivrable.trame;
			_sqlStatement.parameters[":produire"] = true;
			_sqlStatement.parameters[":dateCreation"] = new Date();
			_sqlStatement.parameters[":dateModification"] = new Date();

			_sqlStatement.text = query;
			
			_sqlStatement.addEventListener(SQLEvent.RESULT,createDelivrableResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		private function createDelivrableResult(event:SQLEvent):void
		{
			
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			var primaryKey:Number;
			if (result != null)
			{
				primaryKey = result.lastInsertRowID;
			}
			_sqlStatement.sqlConnection.close();
			responder.result(primaryKey);
		}
		
		public function updateLivrable(deliverable:Deliverable):void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String =
				
				"UPDATE  LIVRABLE " +
				" SET libelle = :libelle ," +
				" description = :description ," +
				" trame = :trame, " +
				" dateModification = :dateModification" +
				" WHERE LIVRABLE.idLivrable = :id";
			
			
			_sqlStatement.parameters[":id"] = deliverable.id;
			_sqlStatement.parameters[":libelle"] = deliverable.label;
			_sqlStatement.parameters[":description"] = deliverable.description;
			_sqlStatement.parameters[":trame"] = deliverable.trame;
			_sqlStatement.parameters[":dateModification"] = new Date();

			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,updateDeliverableResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function updateDeliverableResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			var primaryKey:Number;
			primaryKey = SQLStatement(event.target).parameters[":id"];
			
			_sqlStatement.sqlConnection.close();
			responder.result(primaryKey);
		}
		
		public function getDeliverableById(id:Number):void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = 
				
				"SELECT *  " +
				" FROM LIVRABLE" +
				" WHERE LIVRABLE.idLIVRABLE = :id";
			
			_sqlStatement.parameters[":id"] = id;
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getDeliverableByIdResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function getDeliverableByIdResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			if (result != null && result.data != null)
			{
				var row:Object= result.data[0];
				
				
				var deliverable:Deliverable = new Deliverable();
				deliverable.id = row["idLIVRABLE"];
				deliverable.label = row["libelle"];
				deliverable.description = row["description"];
				deliverable.trame = row["trame"];
			}
			_sqlStatement.sqlConnection.close();
			responder.result(deliverable);
		}
		
	}
}