package com.anssi.ebios.services
{
	import com.anssi.ebios.model.AppModelLocator;
	import com.anssi.ebios.model.FearedEvent;
	import com.anssi.ebios.model.FearedEventLight;
	import com.anssi.ebios.model.GravityLevel;
	import com.anssi.ebios.model.Impact;
	import com.anssi.ebios.model.PrimaryAsset;
	import com.anssi.ebios.model.SecurityCriteria;
	import com.anssi.ebios.model.SecurityNeed;
	import com.anssi.ebios.model.ThreatSource;
	import com.logica.fwk.component.layout.flipbook.rubenswieringa.book.limited;
	
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.Event;
	import flash.events.SQLErrorEvent;
	import flash.events.SQLEvent;
	
	import mx.collections.ArrayCollection;
	import mx.controls.Alert;
	import mx.rpc.IResponder;
	import mx.utils.ObjectUtil;

	public class FearedEventService extends AppServices
	{
			
		private var _responder:IResponder;
		private var _sqlStatement:SQLStatement;
		private var _fearedEvent:FearedEvent;
		private var _threatSourceList:ArrayCollection;
		private var _impactList:ArrayCollection;
		private var _indexToUpdate:Number = -1;
		
		public function FearedEventService(responder:IResponder)
		{
			_responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
	
		/**
		 * 
		 * La méthode updateFearedEvent gère les opérations suivantes: 
		 * 
		 * updateFearedEvent
		 *
		 * updateFearedEventResult
		 *
		 * deleteFearedEventImpact
		 * deleteFearedEventImpactResult
		 *
		 * addImpactToFearedEvent --> recursif
		 * addImpactToFearedEventResult
		 *
		 * deleteFearedEventThreatSource
		 * deleteFearedEventThreatSourceResult
		 *
		 * addThreatSourceToFearedEvent --> recursif
		 * addThreatSourceToFearedEventResult
		 * 
		 **/
		public function updateFearedEvent(fearedEvent:FearedEvent):void{
			
			_fearedEvent = fearedEvent;
			
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = 
				
				" UPDATE  ER " +
				" SET libelle= :libelle ," +
				" idCRITERE = ( SELECT idCRITERE FROM NCRITERE WHERE idNCRITERE = :idNCRITERE ) ," +
				" idNCRITERE = :idNCRITERE ," +
				" idNGRISQUE = :idNGRISQUE ," +
				" justification = :justification, " +
				" dateModification = :dateModification " +
				" WHERE ER.idER = :id";
			
			
			_sqlStatement.parameters[":libelle"] = _fearedEvent.label;
			_sqlStatement.parameters[":idNCRITERE"] = _fearedEvent.securityNeed.id;
			_sqlStatement.parameters[":idNGRISQUE"] = _fearedEvent.gravityLevel.id;
			_sqlStatement.parameters[":justification"] = _fearedEvent.justification;
			_sqlStatement.parameters[":dateModification"] = new Date();
			_sqlStatement.parameters[":id"] = _fearedEvent.id;
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT, updateFearedEventResult);
			
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
			
		}
		
		private function updateFearedEventResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null)
			{
				deleteFearedEventImpact();
			}
		}
		
		private function deleteFearedEventImpact():void
		{	
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = 
				
			"DELETE FROM ENGENDRER"+               
			" WHERE ENGENDRER.[idBE] = :idBE"+     
			" AND ENGENDRER.[idCRITERE] = :idCRITERE";
			
			
			_sqlStatement.parameters[":idBE"] = _fearedEvent.primaryAsset.id;
			_sqlStatement.parameters[":idCRITERE"] = _fearedEvent.securityCriteria.id;
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,deleteFearedEventImpactResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function deleteFearedEventImpactResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null)
			{
				addImpactToFearedEvent(_fearedEvent.impactList);
			}
		}
		
		private function addImpactToFearedEvent(impactList:ArrayCollection):void
		{
			if(impactList)
				_impactList = impactList;
			
			_indexToUpdate ++
			if (_indexToUpdate >= _impactList.length ) {
				
				_indexToUpdate = -1;
				_sqlStatement.sqlConnection.close();
				deleteFearedEventThreatSource();
				
				return;
			}
			
			
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			
			var impact:Impact = _impactList.getItemAt(_indexToUpdate) as Impact;
			
			var sql:String;
			
				sql = 
					
					"INSERT INTO ENGENDRER (idCRITERE, idBE, idIMPACT, dateCreation, dateModification) " +
					" VALUES (:idCRITERE, :idBE, :idIMPACT, :dateCreation, :dateModification)";

			
			_sqlStatement.text = sql;
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idCRITERE"] = _fearedEvent.securityCriteria.id;
			_sqlStatement.parameters[":idBE"] =_fearedEvent.primaryAsset.id;
			_sqlStatement.parameters[":idIMPACT"] = impact.id;
			_sqlStatement.parameters[":dateCreation"] = new Date();
			_sqlStatement.parameters[":dateModification"] = new Date();
			
			_sqlStatement.addEventListener(SQLEvent.RESULT,addImpactToFearedEventResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		
			
			
		}
		
		
		private function addImpactToFearedEventResult(event:SQLEvent):void
		{
			addImpactToFearedEvent(null);
		}
		
		
		
		private function deleteFearedEventThreatSource():void
		{	
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = 
				
				"DELETE FROM INITIER"+               
				" WHERE INITIER.[idBE] = :idBE"+     
				" AND INITIER.[idCRITERE] = :idCRITERE";
			
			
			_sqlStatement.parameters[":idBE"] = _fearedEvent.primaryAsset.id;
			_sqlStatement.parameters[":idCRITERE"] = _fearedEvent.securityCriteria.id;
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,deleteFearedEventThreatSourceResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function deleteFearedEventThreatSourceResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null)
			{
				addThreatSourceToFearedEvent(_fearedEvent.threatSourceList,_fearedEvent);
			}
		}
		//Ce service est public car il peut être utilisé dans l'écran détail 
		//d'un risque (4.1.1) pour la fusion des souces de menaces
		public function addThreatSourceToFearedEvent(threatSourceList:ArrayCollection,fearedEvent:FearedEvent):void
		{
			if(threatSourceList)
			{
				_threatSourceList = threatSourceList;
				_fearedEvent = fearedEvent;
			}
				
			
			_indexToUpdate ++
			if (_indexToUpdate >= _threatSourceList.length ) {

				_indexToUpdate = -1;
				_sqlStatement.sqlConnection.close();
				_responder.result(_fearedEvent.id);
				
				return;
			}
			
			
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			
			var threatSource:ThreatSource = _threatSourceList.getItemAt(_indexToUpdate) as ThreatSource;
			
			var sql:String;
			
			sql = 
				
				"INSERT INTO INITIER (idCRITERE, idBE, idSOURCE, dateCreation, dateModification) " +
				" VALUES (:idCRITERE, :idBE, :idSOURCE, :dateCreation, :dateModification)";
			trace("insertion dans iintier sql"+sql);
			
			_sqlStatement.text = sql;
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idCRITERE"] = _fearedEvent.securityCriteria.id;
			_sqlStatement.parameters[":idBE"]= _fearedEvent.primaryAsset.id;
			_sqlStatement.parameters[":idSOURCE"] = threatSource.id;
			_sqlStatement.parameters[":dateCreation"] = new Date();
			_sqlStatement.parameters[":dateModification"] = new Date();
			
			_sqlStatement.addEventListener(SQLEvent.RESULT,addThreatSourceToFearedEventResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		

		}
		
		private function addThreatSourceToFearedEventResult(event:SQLEvent):void
		{
			addThreatSourceToFearedEvent(null,_fearedEvent);
		}
		
		public function getFearedEventById(id:Number):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = constructFearedEventQuery('WHERE ER.idER = '+id)
						
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT, getFearedEventByIdResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		
			
		}
		private function getFearedEventByIdResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null)
			{
				
				var fearEvent:FearedEvent =  constructFearedEventList( result )[0];
			}
			_sqlStatement.sqlConnection.close();
			_responder.result(fearEvent);
		}
		
		
		public function getFearedEvents():void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = constructFearedEventQuery();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT, getFearedEventsResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function getFearedEventsResult(event:SQLEvent):void
		{
			
			var result:SQLResult = SQLStatement(event.target).getResult();
			var fearEventList:ArrayCollection = new ArrayCollection();
			if (result != null && result.data != null)
			{
				
				 fearEventList =  constructFearedEventList( result );
			}
			
			_sqlStatement.sqlConnection.close();
			_responder.result(fearEventList);
		}
		
		public function constructFearedEventList(result:SQLResult):ArrayCollection
		{
			var row:Object;
			var fearEventList:ArrayCollection = new ArrayCollection();
			if(result.data)
			{
				
			
			var numRows:int = result.data.length;
			
			
			var fearedEvent:FearedEvent;
			var utilFearedEventID:Number;
			var utilThreatSourceID:Number;
			
			var countThreatSource:Number = 0;
			
			
			for (var i:int = 0; i < numRows; i++)
			{
				row = result.data[i];
				
				if(utilFearedEventID != row["fearEvent_id"])
				{
					utilFearedEventID = row["fearEvent_id"];
					
					fearedEvent = new FearedEvent();
					
					fearedEvent.threatSourceList = new ArrayCollection();
					fearedEvent.impactList = new ArrayCollection();
					
					fearedEvent.id = row["fearEvent_id"];
					fearedEvent.label = row["fearEvent_libelle"];
					fearedEvent.justification = row["fearEvent_justification"];
					
					var securityCriteria:SecurityCriteria = new SecurityCriteria();
					securityCriteria.id = row["securityCriteria_id"];
					securityCriteria.libelle = row["securityCriteria_libelle"];
					
					var securityNeed:SecurityNeed = new SecurityNeed();
					securityNeed.id = row["securityNeed_id"];
					securityNeed.label = row["securityNeed_libelle"];
					
					var primaryAsset:PrimaryAsset = new PrimaryAsset();
					primaryAsset.id = row["primaryAsset_id"];
					primaryAsset.libelle = row["primaryAsset_libelle"];
					
					var gravityLevel:GravityLevel = new GravityLevel();
					gravityLevel.label = row["gravity_libelle"];
					gravityLevel.id = row["gravity_id"];
					
					fearedEvent.securityCriteria = securityCriteria;
					fearedEvent.securityNeed = securityNeed;
					fearedEvent.primaryAsset = primaryAsset;
					fearedEvent.gravityLevel = gravityLevel;
					
					fearEventList.addItem(fearedEvent);
					
					utilThreatSourceID = -1;
					countThreatSource = 0;
				}	
				
				
				
				
				if(utilThreatSourceID != row["threatSource_id"])
				{
					if(row["threatSource_id"] != null)
					{
						countThreatSource ++
						utilThreatSourceID = row["threatSource_id"];
						var threatSource:ThreatSource = new ThreatSource();
						threatSource.label = row["threatSource_libelle"];
						threatSource.id = row["threatSource_id"];
						fearedEvent.threatSourceList.addItem( threatSource );
					}
					else
					{
						countThreatSource = 1;
					}
				}
				
				if(countThreatSource==1)
				{
					if(row["impact_id"]>0)
					{
						var impact:Impact = new Impact();
						impact.label = row["impact_libelle"];
						impact.id = row["impact_id"];
						fearedEvent.impactList.addItem( impact );
					}
				}
			}
			}
			return fearEventList;
		}
		
		public function getFearedEventByGravity():void
		{
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = 
				
				"SELECT ER.idER as idER, ER.libelle as erLibelle, NGRISQUE.idNGRISQUE, NGRISQUE.libelle , NGRISQUE.ordre as ordre  "+
				"FROM NGRISQUE "+
				"LEFT OUTER JOIN ER ON ER.idNGRISQUE= NGRISQUE.idNGRISQUE " +
				"order by 5 desc ";
			
			
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getFearedEventByGravityResult);
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getFearedEventByGravityResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var fearedEventByGravityList:ArrayCollection = new ArrayCollection();
			if (result!=null && result.data!=null){
				fearedEventByGravityList = constructFearedEventByGravityList(result);
			}
			_sqlStatement.sqlConnection.close();
			_responder.result(fearedEventByGravityList);
		}

		
		private function constructFearedEventByGravityList(result:SQLResult):ArrayCollection{
			
			
			var fearedEventByGravityList:ArrayCollection = new ArrayCollection();
			
			var row:Object;
			var numRows:int = result.data.length;
			var utilGravityLevelID:Number;
			var gravityLevel:GravityLevel;
			var feardEvent:FearedEvent;

			for( var i:int=0; i< numRows;i++)
			{
				row=result.data[i];
				if(utilGravityLevelID !=  row["idNGRISQUE"])
				{
					utilGravityLevelID =  row["idNGRISQUE"];
					
					gravityLevel= new GravityLevel();
					gravityLevel.id=row["idNGRISQUE"];
					gravityLevel.label=row["libelle"];
					gravityLevel.order = row["ordre"];
					
					gravityLevel.fearedEventList=new ArrayCollection();
					fearedEventByGravityList.addItem(gravityLevel);
				}
				if(row["idER"]>0){
					feardEvent = new FearedEvent();
					feardEvent.id=row["idER"];
					feardEvent.label=row["erLibelle"];
					gravityLevel.fearedEventList.addItem(feardEvent);
			 	}
				
			}
			
			return fearedEventByGravityList;
		}

		public function getFearedEventLight():void
		{
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String;
			query= constructFearedEventQuery("");
		
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getFearedEventLightResult);
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getFearedEventLightResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var fearedEventLightList:ArrayCollection = new ArrayCollection();
			if (result!=null && result.data!=null){
				fearedEventLightList = constructFearedEventLightList(result);
			}
			_sqlStatement.sqlConnection.close();
			_responder.result(fearedEventLightList);
		}
		
		private function constructFearedEventLightList(result:SQLResult):ArrayCollection{
			
			
			var fearedEventLightList:ArrayCollection = new ArrayCollection();
			
			var row:Object;
			var numRows:int = result.data.length;
			var fearedEventLight:FearedEventLight; 
		
		for( var i:int=0; i< numRows;i++)
		{
			row=result.data[i];
			
			if(row["fearEvent_id"]>0){
				
				fearedEventLight= new FearedEventLight();
				fearedEventLight.primaryAssetLabel=row["primaryAsset_libelle"];
				fearedEventLight.securityCriteriaLabel=row["securityCriteria_libelle"];
				fearedEventLight.securityNeedLabel=row["securityNeed_libelle"];
				fearedEventLight.threatSourceLabel=row["threatSource_libelle"];
				fearedEventLight.impactLabel=row["impact_libelle"];
				fearedEventLight.gravityLevelLabel=row["gravity_libelle"];
				fearedEventLight.justification=row["fearEvent_justification"];
				
				fearedEventLightList.addItem(fearedEventLight);
			
			}
		}
		
		return fearedEventLightList;
		
		}
		
		public function constructFearedEventQuery(WHERECondition:String = ""):String
		{
			return "SELECT ER.idER as fearEvent_id, ER.libelle as fearEvent_libelle, ER.justification as fearEvent_justification,"
			+" BE.libelle as primaryAsset_libelle, BE.idBE as primaryAsset_id,"
			+" CRITERE.libelle as securityCriteria_libelle, CRITERE.idCRITERE as securityCriteria_id,"
			+" NCRITERE.libelle as securityNeed_libelle, NCRITERE.idNCRITERE as securityNeed_id," 
			+" NGRISQUE.libelle as gravity_libelle, NGRISQUE.idNGRISQUE as gravity_id,"
			+" SOURCE.idSOURCE as threatSource_id, SOURCE.libelle as threatSource_libelle,"
			+" IMPACT.libelle as impact_libelle, IMPACT.idIMPACT as impact_id"
			+" FROM ER"
			+" LEFT OUTER JOIN ENGENDRER ON (ENGENDRER.idBE = ER.idBE"
			+" AND ENGENDRER.idCRITERE = ER.idCRITERE)"
			+" LEFT OUTER JOIN INITIER ON (INITIER.idBE = ER.idBE"
			+" AND INITIER.idCRITERE = ER.idCRITERE)"
			+" LEFT OUTER JOIN IMPACT ON (ENGENDRER.idIMPACT = IMPACT.idIMPACT)"
			+" LEFT OUTER JOIN SOURCE ON (INITIER.idSOURCE = SOURCE.idSOURCE)"
			+" LEFT OUTER JOIN BE ON (ER.idBE = BE.idBE)"
			+" LEFT OUTER JOIN CRITERE ON (ER.idCRITERE = CRITERE.idCRITERE)"
			+" LEFT OUTER JOIN NCRITERE ON (ER.idNCRITERE = NCRITERE.idNCRITERE)"
			+" LEFT OUTER JOIN NGRISQUE ON (ER.idNGRISQUE = NGRISQUE.idNGRISQUE)"
			+ " "+WHERECondition
			+" ORDER by ER.idER, SOURCE.idSOURCE, IMPACT.idIMPACT";
		}
		
		
		public function addOneImpactToFearedEvent(idImpact:Number, myFearedEvent:FearedEvent):void{
			_fearedEvent = new FearedEvent();
			_fearedEvent = myFearedEvent;
			
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var sql:String = 
				"INSERT INTO ENGENDRER (idCRITERE, idBE, idIMPACT, dateCreation, dateModification) " +
				" VALUES (:idCRITERE, :idBE, :idIMPACT, :dateCreation, :dateModification)";
			
			
			_sqlStatement.text = sql;
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idCRITERE"] = _fearedEvent.securityCriteria.id;
			_sqlStatement.parameters[":idBE"] =_fearedEvent.primaryAsset.id;
			_sqlStatement.parameters[":idIMPACT"] = idImpact+"";
			_sqlStatement.parameters[":dateCreation"] = new Date();
			_sqlStatement.parameters[":dateModification"] = new Date();
			
			_sqlStatement.addEventListener(SQLEvent.RESULT,addOneImpactToFearedEventResult);
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function addOneImpactToFearedEventResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			_sqlStatement.sqlConnection.close();
			_responder.result(_fearedEvent.id);
		}
	}
}