package com.anssi.ebios.services
{
	import com.anssi.ebios.model.GravityLevel;
	import com.anssi.ebios.model.GravityLevelLight;
	import com.anssi.ebios.utils.CompareCollectionUtil;
	import com.anssi.ebios.utils.Resources;
	
	import flash.data.SQLMode;
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLEvent;
	import flash.filesystem.File;
	
	import mx.collections.ArrayCollection;
	import mx.rpc.IResponder;
	

	public class GravityLevelService extends AppServices
	{
		
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement; 
		private var _gravityLevelList:ArrayCollection;
		private var _gravityLevelListToDelete:ArrayCollection;
		private var _currentIndex:Number=-1;
		
		public function GravityLevelService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		/*****************************************************/
		/** Récupération de la liste des niveaux de gravité **/
		/*****************************************************/
		public function getGravityLevelList():void{
			
			constructSelectGravityList();
			_sqlStatement.addEventListener(SQLEvent.RESULT,getGravityLevelListResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function getGravityLevelListResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var resultCol:ArrayCollection = constructGravityLevelListResult(result)
			_sqlStatement.sqlConnection.close();
			responder.result(resultCol);
		}
		
		private function constructSelectGravityList():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "SELECT * FROM NGRISQUE ORDER BY ORDRE";
			
			_sqlStatement.text = query;
		}
		
		public function constructGravityLevelListResult(result:SQLResult):ArrayCollection{
			var gravityLevelList:ArrayCollection = new ArrayCollection();
			// si nous avons des résultats
			if (result != null && result.data != null)
			{								
				var row:Object;
				var numRows:int = result.data.length;
				var gravityLevel:GravityLevel;
				
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					gravityLevel = new GravityLevel();
					gravityLevel.id = row["idNGRISQUE"];
					gravityLevel.label = row["libelle"];
					gravityLevel.description = row["description"];
					gravityLevel.order = row["ordre"];
					gravityLevelList.addItem(gravityLevel);
				}
			}
			//_sqlStatement.sqlConnection.close();
			return gravityLevelList;
		}
		
		/****************************************************/
		/** Mise à jour de la liste des niveaux de gravité **/
		/****************************************************/
		public function updateGravityLevelList(gravityLevelList:ArrayCollection):void{
			
			//On stocke la liste des niveaux de gravité saisis dans l'IHM
			_gravityLevelList = gravityLevelList;			
			updateGravityLevel();		
		}
		
			
		private function updateGravityLevel():void{
			var query:String="";
			
			setBDDName();
			_sqlStatement = new SQLStatement();				
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			_currentIndex++
			if (_currentIndex < _gravityLevelList.length){
				var gravityLevel:GravityLevel = _gravityLevelList.getItemAt(_currentIndex) as GravityLevel;
				
				if (Number(gravityLevel.id) <= 0){
					query = "INSERT INTO NGRISQUE (libelle, description, ordre, dateCreation, dateModification) " +
						" VALUES (:libelle, :description, :ordre, :dateCreation, :dateModification)";
					
					_sqlStatement.clearParameters();
					_sqlStatement.parameters[":libelle"] = gravityLevel.label;
					_sqlStatement.parameters[":description"] = gravityLevel.description;
					_sqlStatement.parameters[":ordre"] = gravityLevel.order;
					_sqlStatement.parameters[":dateCreation"] = new Date();
					_sqlStatement.parameters[":dateModification"] = new Date();

				}else{
					query = "UPDATE NGRISQUE SET libelle = :libelle, description = :description, ordre = :ordre, dateModification = :dateModification " +
						" WHERE idNGRISQUE = :idNGRISQUE";
					
					_sqlStatement.clearParameters();
					_sqlStatement.parameters[":libelle"] = gravityLevel.label;
					_sqlStatement.parameters[":description"] = gravityLevel.description;
					_sqlStatement.parameters[":ordre"] = gravityLevel.order;
					_sqlStatement.parameters[":dateModification"] = new Date();
					_sqlStatement.parameters[":idNGRISQUE"] = gravityLevel.id;
					
				}
				
				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,updateGravityLevelResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);	
			}else{
				_sqlStatement.sqlConnection.close();
				responder.result(null);
			}
		}
		
		private function updateGravityLevelResult(event:SQLEvent):void{
			updateGravityLevel();
		}
		
		
		
		/****************************************/
		/** Suppression d'un niveau de gravité **/
		/****************************************/
		
		public function deleteGravityLevel(gravityLevel:GravityLevel):void{
			setBDDName();				
			_sqlStatement = new SQLStatement();				
			_sqlStatement.sqlConnection = this.sqlConnection;
			openInSyncMode(_sqlStatement);
			
			var queryForFeardEventSetting:String = "UPDATE ER SET idNGRISQUE = null, dateModification = :dateModification " +
				" WHERE idNGRISQUE = " + gravityLevel.id;
			
			var queryForRiskSetting1:String = "UPDATE RISQUE SET graviteBrute = null, dateModification = :dateModification " +
				" WHERE graviteBrute = " + gravityLevel.id;
			
			var queryForRiskSetting2:String = "UPDATE RISQUE SET graviteME = null, dateModification = :dateModification " +
				" WHERE graviteME = " + gravityLevel.id;
			
			var queryForRiskSetting3:String = "UPDATE RISQUE SET graviteMC = null, dateModification = :dateModification " +
				" WHERE graviteMC = " + gravityLevel.id;
			
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":dateModification"] = new Date();
			
			
			// remise à NULL de la gravité dans ER
			_sqlStatement.text = queryForFeardEventSetting;
			execStatement(_sqlStatement);
			
			
			// remise à NULL de la gravitéBrute dans RISQUE
			_sqlStatement.text = queryForRiskSetting1;
			execStatement(_sqlStatement);
			
			// remise à NULL de la gravitéME dans RISQUE
			_sqlStatement.text = queryForRiskSetting2;
			execStatement(_sqlStatement);
			
			// remise à NULL de la gravitéMC dans RISQUE
			_sqlStatement.text = queryForRiskSetting3;
			execStatement(_sqlStatement);
			
			var queryForASSOCIERDeleting:String = "DELETE FROM ASSOCIER WHERE idNGRISQUE = " + gravityLevel.id;
			var queryForGravityDeleting:String = "DELETE FROM NGRISQUE WHERE idNGRISQUE = " + gravityLevel.id;
			
			// suppression de NRISQUE dont le idNGRISQUE est dans la liste
			_sqlStatement.clearParameters();
			_sqlStatement.text = queryForASSOCIERDeleting;
			execStatement(_sqlStatement);
			
			// suppression de NVRISQUE dont le idNGRISQUE est dans la liste
			_sqlStatement.text = queryForGravityDeleting;
			execStatement(_sqlStatement);
			
			
			
			_sqlStatement.sqlConnection.close();
			responder.result(null);
			
		}
		
		/***********************************************************/
		/** Récupération de la liste des niveaux de gravité light **/
		/***********************************************************/
		
		public function getGravityLevelLight():void
		{
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = "SELECT * FROM NGRISQUE ORDER BY ORDRE desc";
			
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getGravityLevelLightResult);
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getGravityLevelLightResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var gravityLevelLightList:ArrayCollection = new ArrayCollection();
			if (result!=null && result.data!=null){
				gravityLevelLightList = constructGravityLevelLightList(result);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(gravityLevelLightList);
		}
		
		private function constructGravityLevelLightList(result:SQLResult):ArrayCollection{
			
			
			var gravityLevelLightList:ArrayCollection = new ArrayCollection();
			
			var row:Object;
			var numRows:int = result.data.length;
			var gravityLevelLight:GravityLevelLight;
			
			for( var i:int=0; i< numRows;i++)
			{
				row=result.data[i];
				
				if(row["idNGRISQUE"]>0){
					
					gravityLevelLight= new GravityLevelLight();
					gravityLevelLight.description=row["description"];
					gravityLevelLight.order=row["ordre"];
					
					gravityLevelLightList.addItem(gravityLevelLight);
					
				}
			}
			
			return gravityLevelLightList;
			
		}
		
		public function constructGravityLevelQuery(WHERECondition:String = ""):String
		{
			return  "SELECT * FROM NGRISQUE"
			+ " "+WHERECondition
				+" ORDER BY ORDRE";
			
		}
	}	
}