package com.anssi.ebios.services
{
	import com.anssi.ebios.model.Impact;
	import com.anssi.ebios.model.ImpactType;
	import com.logica.fwk.component.layout.flipbook.rubenswieringa.book.limited;
	
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLEvent;
	
	import mx.collections.ArrayCollection;
	import mx.rpc.IResponder;

	public class ImpactService extends AppServices
	{
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement;
		
		public function ImpactService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		public function getImpact():void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String =
				
			"SELECT IMPACT.libelle as libelle, IMPACT.idIMPACT as id, IMPACT.impactInduit as impactInduit, " +
			" TIMPACTS.idTIMPACTS as idType, TIMPACTS.libelle as libelleType, TIMPACTS.exemples as exemple " +
			" FROM IMPACT, TIMPACTS WHERE IMPACT.idTIMPACTs = TIMPACTS.idTIMPACTS";
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getImpactResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function getImpactResult(event:SQLEvent):void
		{
			var impactList:ArrayCollection  = new ArrayCollection();
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null)
			{
				
				
				var row:Object;
				var numRows:int = result.data.length;
				
				
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					impactList.addItem(constructImpactByRow(row));
				}
			}
			_sqlStatement.sqlConnection.close();
			responder.result(impactList);
		}
		
		public function getImpactById(id:Number):void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String =
				
				"SELECT IMPACT.libelle as libelle, IMPACT.idIMPACT as id, IMPACT.impactInduit as impactInduit, " +
				" TIMPACTS.idTIMPACTS as idType, TIMPACTS.libelle as libelleType, TIMPACTS.exemples as exemple " +
				" FROM IMPACT, TIMPACTS " +
				" WHERE IMPACT.idTIMPACTs = TIMPACTS.idTIMPACTS" +
				" AND IMPACT.idIMPACT= :id";
			
			_sqlStatement.text = query;

			_sqlStatement.parameters[":id"] =id;
			
			_sqlStatement.addEventListener(SQLEvent.RESULT,getImpactByIdResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function getImpactByIdResult(event:SQLEvent):void
		{
			var impactList:ArrayCollection = null;
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null)
			{
				var row:Object= result.data[0];
				var impact:Impact = constructImpactByRow(row) ;
			}
			_sqlStatement.sqlConnection.close();
			responder.result(impact);
		}
	
		private function constructImpactByRow(row:Object):Impact
		{
			
			var impact:Impact = new Impact();	
			impact.id = row["id"];
			impact.label = row["libelle"];
			impact.label = row["libelle"];
			impact.inducedImpact = row["impactInduit"];
			
			impact.type = new ImpactType()
			impact.type.id = row["idType"];
			impact.type.label =  row["libelleType"];
			impact.type.exemple = row["exemple"];
			
			return impact;
		}
		public function createImpact(impact:Impact):void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = 
				
				"INSERT INTO IMPACT ( libelle, idTIMPACTS, impactInduit, dateCreation, dateModification) "+
				" VALUES (:libelle, :idTIMPACTS, :impactInduit, :dateCreation, :dateModification)";
			
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":dateCreation"] = new Date();
			_sqlStatement.parameters[":dateModification"] = new Date();
			_sqlStatement.parameters[":libelle"] = impact.label;
			_sqlStatement.parameters[":idTIMPACTS"] = impact.type.id;
			_sqlStatement.parameters[":impactInduit"] =  impact.inducedImpact;
			
			_sqlStatement.text = query;
			
			_sqlStatement.addEventListener(SQLEvent.RESULT,createImpactResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function createImpactResult(event:SQLEvent):void
		{
			
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			var primaryKey:Number;
			if (result != null)
			{
				primaryKey = result.lastInsertRowID;
			}
			_sqlStatement.sqlConnection.close();
			responder.result(primaryKey);
		}
		
		public function updateImpact(impact:Impact):void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			 
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String =
				
				"UPDATE  IMPACT " +
				" SET libelle= :libelle ," +
				" idTIMPACTS= :idTIMPACTS ," +
				" impactInduit= :impactInduit," +
				" dateModification= :dateModification " +
				" WHERE IMPACT.idIMPACT= :id";
			
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":libelle"] = impact.label;
			_sqlStatement.parameters[":idTIMPACTS"] = impact.type.id;
			_sqlStatement.parameters[":impactInduit"] = impact.inducedImpact;
			_sqlStatement.parameters[":dateModification"] = new Date();
			_sqlStatement.parameters[":id"] = impact.id;
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,updateImpactResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function updateImpactResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			var primaryKey:Number;
			primaryKey = SQLStatement(event.target).parameters[":id"];
			
			_sqlStatement.sqlConnection.close();
			responder.result(primaryKey);
		}
		public function deleteImpact(impact:Impact):void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = 
				
				"DELETE FROM IMPACT " +
				" WHERE IMPACT.idIMPACT= :id";
			
			_sqlStatement.text = query;
			
			_sqlStatement.parameters[":id"] =impact.id;
			_sqlStatement.addEventListener(SQLEvent.RESULT,deleteImpactResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		private function deleteImpactResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			_sqlStatement.sqlConnection.close();
			responder.result(null);
		}
	}
	
	
	
	
	
}