package com.anssi.ebios.services
{
	import com.adobe.cairngorm.control.CairngormEventDispatcher;
	import com.anssi.ebios.event.primaryassetevent.GetPrimaryAssetsXMLEvent;
	import com.anssi.ebios.event.primaryassetevent.SavePrimaryAssetsEvent;
	import com.anssi.ebios.event.supportassetevent.GetSupportAssetsXMLEvent;
	import com.anssi.ebios.event.supportassetevent.SaveSupportAssetsEvent;
	import com.anssi.ebios.model.PrimaryAsset;
	import com.anssi.ebios.model.SupportAssetType;
	import com.anssi.ebios.model.SupportingAsset;
	import com.anssi.ebios.utils.Constants;
	import com.anssi.ebios.utils.Properties;
	import com.anssi.ebios.utils.Resources;
	
	import flash.data.SQLStatement;
	import flash.filesystem.File;
	import flash.filesystem.FileMode;
	import flash.filesystem.FileStream;
	import flash.utils.unescapeMultiByte;
	
	import mx.collections.ArrayCollection;
	import mx.resources.ResourceManager;
	import mx.rpc.IResponder;
	import mx.utils.UIDUtil;

	public class ImportStudyService extends AppServices
	{
		
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement;
		
		private var _organizationXML:XML;
		private var _ospListXML:XML;
		private var _hyphotesisXML:XML;
		private var _targetSystem:XML;
		private var _stakeList:XML;
		private var _entityRelationTable:XML;
		private var _securityNeedsSynthesis:XML;
		private var _criteriaList:XML;
		private var _impactList:XML;
		private var _securityObjectiveList:XML;
		private var _functionnalRequirementList:XML;
		private var _sensitivityScale:XML;
		
		private var _idCriteriaFromXMLList:ArrayCollection= new ArrayCollection();
		private var _idCriteriaInserted:ArrayCollection= new ArrayCollection();
		
		private var _idBEInserted:ArrayCollection = new ArrayCollection();
		private var _idBSInserted:ArrayCollection = new ArrayCollection();
		
		private var _labelBEInserted:ArrayCollection = new ArrayCollection();
		private var _labelCRITEREInserted:ArrayCollection =  new ArrayCollection();
		
		private var _primaryAssetList:ArrayCollection;
		private var _supportingAssetList:ArrayCollection;
		
		public function ImportStudyService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		public static function cleanString(str:String):String{
			var pattern:RegExp =/\+/g;	
			
			str = unescape(str);
			str =  str.replace(pattern," ");
			
			return str;
		}

		
		public function mapping(studyName:String):void{
			var separator:String = Resources.getInstance().getDirectorySeparator();
			var root_url:String = File.applicationStorageDirectory.nativePath + separator + configs.getValue("app.storage.import.directory") + separator + studyName;
			
			_organizationXML = buildXML(root_url + separator + Constants.XML_ORGANIZATION);
			_ospListXML = buildXML(root_url + separator + Constants.XML_OSPLIST);
			_hyphotesisXML = buildXML(root_url + separator + Constants.XML_HYPOTHESIS_LIST);
			_targetSystem= buildXML(root_url + separator + Constants.XML_TARGET_SYSTEM);
			_stakeList = buildXML(root_url + separator + Constants.XML_STAKE_LIST);
			_entityRelationTable = buildXML(root_url + separator + Constants.XML_ENTITY_RELATION_TABLE);
			_securityNeedsSynthesis = buildXML(root_url + separator + Constants.XML_SECURITY_NEEDS_SYNTHESIS);
			_criteriaList = buildXML(root_url + separator + Constants.XML_CRITERIA_LIST);
			_impactList = buildXML(root_url + separator + Constants.XML_IMPACT_LIST);
			_securityObjectiveList = buildXML(root_url + separator + Constants.XML_SECURITY_OBJECTIVE_LIST);
			_functionnalRequirementList = buildXML(root_url + separator + Constants.XML_FUNCTIONNAL_REQUIREMENT_LIST);
			_sensitivityScale = buildXML(root_url + separator +  Constants.KBASE + separator +Constants.XML_SENSITIVITY_SCALE);
			
			//Ouverture de la connection à la BDD
			openConnection();
			
			//Insert dans la table PARAMETRE
			insertIntoPARAMETRE();
			
			//Insert dans la table BE
			insertIntoBE();
			
			//Insert dans la table BS
			insertIntoBS();
			
			//Insert dans la table CROISER
			insertIntoCROISER();
			
			//Insert dans la table IMPACT
			insertIntoIMPACT();
			
			//Insert dans la table MESURE
			insertIntoMESURE();
			
			//Insert dans la table ETUDE
			insertIntoETUDE()
			
			//Insert dans la table CRITERE
			insertIntoCRITERE();
			
			// Insert dans la table NCRITERE
			insertIntoNCRITERE();
			
			//Insert dans la table ER
			insertIntoER();
			
			//Insert dans la table BE_POSITION
			insertIntoBE_POSITION();
			
			//Insert dans la table BS_POSITION
			insertIntoBS_POSITION();
			
			//Fermeture de la connection
			closeConnection();
		}
		
		private function openConnection():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			openInSyncMode(_sqlStatement);
		}
		
		private function closeConnection():void{
			_sqlStatement.sqlConnection.close();
			responder.result(null);
		}
		
		private function buildXML(url:String):XML{
			var xml:XML = new XML();
			var file:File = File.documentsDirectory.resolvePath(url);
			if (file.exists){
				var fileStream:FileStream = new FileStream();
				fileStream.open(file, FileMode.READ);
				xml = XML(fileStream.readMultiByte(fileStream.bytesAvailable, "iso-8859-1"));
				fileStream.close();					
			}				
			return xml;
		}
		
		private function insertIntoPARAMETRE():void{
			var item:XML;
			var xmlList:XMLList
			var labelList:ArrayCollection = new ArrayCollection;		
			
			xmlList = _organizationXML.children().child(Constants.B_CONSTRAINT);			
			for each (item in xmlList){	
				labelList.addItem(item.attribute(Constants.A_DESCRIPTION).toString());
			}
			
			xmlList = _organizationXML.children().child(Constants.B_REGULATORY_REFERENCE);			
			for each (item in xmlList){	
				labelList.addItem(item.attribute(Constants.A_LONG_LABEL).toString());
			}
			
			xmlList = _hyphotesisXML.child(Constants.B_HYPOTHESIS);
			for each (item in xmlList){	
				labelList.addItem(item.attribute(Constants.A_DESCRIPTION).toString());
			}
			
			xmlList = _ospListXML.child(Constants.B_OSP);
			for each (item in xmlList){	
				labelList.addItem(item.attribute(Constants.A_DESCRIPTION).toString());
			}
					
			
			for (var i:int = 0; i < labelList.length; i++){			
				_sqlStatement.clearParameters();
				_sqlStatement.text= "INSERT INTO PARAMETRE (idTPARAMETRES, libelle, dateCreation, dateModification) VALUES (:idTPARAMETRES, :libelle, :dateCreation, :dateModification)";
				_sqlStatement.parameters[":idTPARAMETRES"] = "1";
				_sqlStatement.parameters[":libelle"] = cleanString(labelList.getItemAt(i) as String);
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();
				execStatement(_sqlStatement);					
			}
		}
		
		
		private function insertIntoBE():void{
			var item:XML;
			var xmlList:XMLList
			var labelList:ArrayCollection = new ArrayCollection;		
			
			_primaryAssetList = new ArrayCollection();
			xmlList = _targetSystem.children().child(Constants.B_FUNCTION);			
			for each (item in xmlList){	
				labelList.addItem(item.attribute(Constants.A_DESCRIPTION).toString());
			}
			
			xmlList = _targetSystem.children().child(Constants.B_INFORMATION);			
			for each (item in xmlList){	
				labelList.addItem(item.attribute(Constants.A_DESCRIPTION).toString());
			}
			
			for (var i:int = 0; i < labelList.length; i++){			
				_sqlStatement.clearParameters();
				_sqlStatement.text= "INSERT INTO BE (libelle, retenu, dateCreation, dateModification) VALUES (:libelle, true, :dateCreation, :dateModification)";
				_sqlStatement.parameters[":libelle"] = cleanString(labelList.getItemAt(i) as String);
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();
				execStatement(_sqlStatement);	
				var lastInsertRowID:Number = _sqlStatement.getResult().lastInsertRowID;
				_idBEInserted.addItem(lastInsertRowID);
				_labelBEInserted.addItem(labelList.getItemAt(i) as String);
				
				var primaryAsset:PrimaryAsset = new PrimaryAsset();
				primaryAsset.id = lastInsertRowID+ "";
				primaryAsset.libelle = cleanString(labelList.getItemAt(i) as String);
				primaryAsset.retenu = true;
				primaryAsset.description = "";
				
				_primaryAssetList.addItem(primaryAsset);
			}			
		}
		
		private function insertIntoBS():void{
			var item:XML;
			var xmlList:XMLList
			var labelList:ArrayCollection = new ArrayCollection;		
			
			_supportingAssetList = new ArrayCollection();
			xmlList = _targetSystem.children().child(Constants.B_ENTITY);			
			for each (item in xmlList){	
				labelList.addItem(item.attribute(Constants.A_DESCRIPTION).toString());
			}
			
			// le type de BS par défaut est LOC donc idTBS = 1
			
			for (var i:int = 0; i < labelList.length; i++){			
				_sqlStatement.clearParameters();
				_sqlStatement.text= "INSERT INTO BS (libelle, retenu, idTBS, dateCreation, dateModification) VALUES (:libelle, true, 1, :dateCreation, :dateModification)";
				_sqlStatement.parameters[":libelle"] = cleanString(labelList.getItemAt(i) as String);
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();
				execStatement(_sqlStatement);
				
				var lastInsertRowID:Number = _sqlStatement.getResult().lastInsertRowID; 
				_idBSInserted.addItem(lastInsertRowID);	
				
				var supportingAsset:SupportingAsset = new SupportingAsset();
				supportingAsset.id = lastInsertRowID + "";
				supportingAsset.label = cleanString(labelList.getItemAt(i) as String);
				supportingAsset.retained = true;
				supportingAsset.description = "";
				supportingAsset.type = new SupportAssetType();
				supportingAsset.type.id = 1+ "";
				
				_supportingAssetList.addItem(supportingAsset);
			}			
		}
		
		private function insertIntoCROISER():void{
			var item:XML;
			var xmlListBE:XMLList
			var i:int = -1;
			var j:int = -1;
			
			//Récupération des lignes du tableau (BE)
			xmlListBE = _entityRelationTable.children()[1].child(Constants.B_ROW);
			
			for each (item in xmlListBE){
				i++;				
				//Récupération de la liste des BS d'un BE
				var xmlListBS:XMLList = item.child(Constants.B_VALUES).children();
				var token:XML;	
				j=-1;
				for each (token in xmlListBS){
					j++;					
					if (token.attribute(Constants.A_VALUE).toString() == "true"){					
						_sqlStatement.clearParameters();
						_sqlStatement.text= "INSERT INTO CROISER (idBS, idBE, dateCreation, dateModification) VALUES (:idBS, :idBE, :dateCreation, :dateModification)";
						_sqlStatement.parameters[":idBS"] = _idBSInserted.getItemAt(j);
						_sqlStatement.parameters[":idBE"] = _idBEInserted.getItemAt(i);
						_sqlStatement.parameters[":dateCreation"] = new Date();
						_sqlStatement.parameters[":dateModification"] = new Date();
						execStatement(_sqlStatement);					
					}
				}
			}
		}
		
		private function insertIntoIMPACT():void{
			var xmlList:XMLList = _impactList.child(Constants.B_IMPACT) ;
			var item:XML;
			
			for each (item in xmlList){
				_sqlStatement.clearParameters();
				_sqlStatement.text= "INSERT INTO IMPACT (idTIMPACTS, libelle, dateCreation, dateModification) VALUES (:idTIMPACTS, :libelle, :dateCreation, :dateModification)";
				_sqlStatement.parameters[":idTIMPACTS"] = "1";
				_sqlStatement.parameters[":libelle"] = cleanString(item.attribute(Constants.A_LABEL).toString());
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();
				execStatement(_sqlStatement);		
			}
			
		}
		
		private function insertIntoMESURE():void{
			var item:XML;
			var xmlList:XMLList
			var labelList:ArrayCollection = new ArrayCollection;
			
			xmlList = _securityObjectiveList.child(Constants.B_SECURITY_OBJECTIVE);
			for each(item in xmlList){
				labelList.addItem(item.attribute(Constants.A_CONTENT).toString());
			}
			
			xmlList = _functionnalRequirementList.child(Constants.B_FUNCTIONNAL_REQUIREMENT);
			for each(item in xmlList){
				labelList.addItem(item.attribute(Constants.A_DESCRIPTION).toString());
			}

			for (var i:int = 0; i < labelList.length; i++){
				_sqlStatement.clearParameters();
				_sqlStatement.text= "INSERT INTO MESURE (idTMESURES, libelle, etat, dateCreation, dateModification) VALUES (:idTMESURES, :libelle, :etat, :dateCreation, :dateModification)";
				_sqlStatement.parameters[":idTMESURES"] = "1";
				_sqlStatement.parameters[":libelle"] = cleanString(labelList.getItemAt(i) as String);
				_sqlStatement.parameters[":etat"] = "E";
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();
				execStatement(_sqlStatement);		
			}
		}
		
		private function insertIntoETUDE():void{

			var contextLabel:String;	
			
			contextLabel = _organizationXML.attribute(Constants.A_PRESENTATION).toString();
			
			// construction de la chaine pour le champ diversPerimetre
			var perimetreLabel:String = "";
			
			perimetreLabel = _targetSystem.attribute(Constants.A_PRESENTATION).toString();
			
			var item:XML;
			var stakeList:XMLList = _stakeList.child(Constants.B_STAKE);
			for each(item in stakeList){
				perimetreLabel += "\n"+item.attribute(Constants.A_DESCRIPTION).toString();
			}
			
			_sqlStatement.clearParameters();
			_sqlStatement.text= "UPDATE ETUDE SET diversContexte = :diversContexte, diversPerimetre = :diversPerimetre, dateModification = :dateModification";
			_sqlStatement.parameters[":diversContexte"] = cleanString(contextLabel);
			_sqlStatement.parameters[":diversPerimetre"] = cleanString(perimetreLabel);
			_sqlStatement.parameters[":dateModification"] = new Date();
			execStatement(_sqlStatement);	
			
		}

		private function insertIntoCRITERE():void{
			var item:XML;
			var xmlList:XMLList;
			
			xmlList = _criteriaList.child(Constants.B_CRITERIA);
			
			
			//On vide la table CRITERE avant de rajouter les nouveaux criteres issus du fichier XML
			_sqlStatement.clearParameters();
			_sqlStatement.text = "SELECT idCRITERE FROM CRITERE";
			execStatement(_sqlStatement);
			var resultIdCriteria:Array=_sqlStatement.getResult().data;
			for (var i:int = 0; i < resultIdCriteria.length; i++){ 
				_sqlStatement.text = "DELETE FROM CRITERE WHERE idCRITERE = :idCRITERE";
				_sqlStatement.parameters[":idCRITERE"] = resultIdCriteria[i].idCRITERE+"";
				execStatement(_sqlStatement);
			}
			
			//On insert dans la table CRITERE les nouveaux Criteres issus du fhicer XML, tout en récupérant l'id en base et l'id dans XML qui correspondent
			for each(item in xmlList){
				_sqlStatement.clearParameters();
				_sqlStatement.text = "INSERT INTO CRITERE (libelle, definition, dateCreation, dateModification) VALUES (:libelle, :definition, :dateCreation, :dateModification)";
				_sqlStatement.parameters[":libelle"] = cleanString(item.attribute(Constants.A_LABEL).toString());
				_sqlStatement.parameters[":definition"] = cleanString(item.attribute(Constants.A_DESCRIPTION).toString());
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();
				execStatement(_sqlStatement);
			
				_idCriteriaInserted.addItem(_sqlStatement.getResult().lastInsertRowID);
				_idCriteriaFromXMLList.addItem(item.attribute(Constants.A_ID).toString());
				_labelCRITEREInserted.addItem(cleanString(item.attribute(Constants.A_LABEL).toString()));
							
			}
		}
		
		private function insertIntoNCRITERE():void{
			var item:XML;
			var sensitivityXMLList:XMLList;
			
			// Vider la table NCRITERE avant de le remplir avec les nouvelles données
			_sqlStatement.clearParameters();
			_sqlStatement.text = "SELECT idNCRITERE FROM NCRITERE";
			execStatement(_sqlStatement);
			var resultIdNCriteria:Array=_sqlStatement.getResult().data;
			for (var i:int = 0; i < resultIdNCriteria.length; i++){ 
				_sqlStatement.text = "DELETE FROM NCRITERE WHERE idNCRITERE = :idNCRITERE";
				_sqlStatement.parameters[":idNCRITERE"] = resultIdNCriteria[i].idNCRITERE+"";
				execStatement(_sqlStatement);
			}
			sensitivityXMLList = _sensitivityScale.child(Constants.B_SENSITIVITY);
			
			for each(item in sensitivityXMLList){
				var gradationDescriptionXMLList:XMLList = item.children().child(Constants.B_GRADATION_DESCRIPTION);
				var itemGradation:XML;
				for each (itemGradation in gradationDescriptionXMLList){
					_sqlStatement.clearParameters();
					_sqlStatement.text = "INSERT INTO NCRITERE (libelle, description, ordre, idCRITERE, dateCreation, dateModification) " +
						" VALUES (:libelle, :description, :ordre, :idCRITERE, :dateCreation, :dateModification)";
					_sqlStatement.parameters[":libelle"] = cleanString(itemGradation.attribute(Constants.A_LABEL).toString());
					_sqlStatement.parameters[":description"] = cleanString(itemGradation.attribute(Constants.A_DESCRIPTION).toString());
					_sqlStatement.parameters[":ordre"] = item.attribute(Constants.A_LEVEL).toString();
					
					var index:Number = _idCriteriaFromXMLList.getItemIndex(itemGradation.attribute(Constants.A_CRITERIA).toString());
					
					_sqlStatement.parameters[":idCRITERE"] = _idCriteriaInserted.getItemAt(index);
					_sqlStatement.parameters[":dateCreation"] = new Date();
					_sqlStatement.parameters[":dateModification"] = new Date();
					execStatement(_sqlStatement);

				}
				
			}
		}
		
		private function insertIntoER():void{
			var itemBE:XML;
			var itemCRITERE:XML;
			var xmlBEList:XMLList;
			var xmlCRITEREList:XMLList;
			var i:int = -1;
			var j:int;
			
			//Récupération des lignes du tableau (BE)
			xmlBEList = _securityNeedsSynthesis.children()[1].child(Constants.B_ROW);
	
			for each (itemBE in xmlBEList){
				i++;
				
				//récuperation de la liste de critere sur chaque BE
				xmlCRITEREList = itemBE.children()[0].child(Constants.B_ROW);
				j=-1;
				var tokenValue:String;
				var token:XMLList;
				var index:int = -1;
				for each(itemCRITERE in xmlCRITEREList){
					j++;
					//récuperation de lordre du niveau de critere
					//token : la liste de enfant de la balise <Values>;
					// on  a besoin de l'avant dernier enfant dont on récupére la valeur de l'attribut "value"
					token= itemCRITERE.children()[1].children();
					index = token.length() -2;
					tokenValue =  token[index].attribute(Constants.A_VALUE).toString();
					
					//Recherche de l'idNCRITERE du niveau de critere
					_sqlStatement.clearParameters();
					_sqlStatement.text = "SELECT idNCRITERE FROM NCRITERE WHERE idCRITERE = :idCRITERE AND ordre = :ordre";
					_sqlStatement.parameters[":idCRITERE"] = _idCriteriaInserted.getItemAt(j);
					_sqlStatement.parameters[":ordre"] = tokenValue;
					execStatement(_sqlStatement);
					
					var resultArray:Array = _sqlStatement.getResult().data;
					var idNCRITERE:String = resultArray[0].idNCRITERE;
					
					//insertion dans la table ER
					_sqlStatement.clearParameters();
					_sqlStatement.text = "INSERT INTO ER (libelle, idCRITERE, idNCRITERE, idBE, dateCreation, dateModification) VALUES (:libelle, :idCRITERE, :idNCRITERE, :idBE, :dateCreation, :dateModification)";
					_sqlStatement.parameters[":libelle"] = cleanString(_labelBEInserted.getItemAt(i)+" "+ _labelCRITEREInserted.getItemAt(j));
					_sqlStatement.parameters[":idCRITERE"] = _idCriteriaInserted.getItemAt(j);
					_sqlStatement.parameters[":idNCRITERE"] = idNCRITERE;
					_sqlStatement.parameters[":idBE"] = _idBEInserted.getItemAt(i);
					_sqlStatement.parameters[":dateCreation"] = new Date();
					_sqlStatement.parameters[":dateModification"] = new Date();
					execStatement(_sqlStatement);

				}
				
			}
		}

		private function insertIntoBE_POSITION():void{
			
			var getPrimaryAssetXMLEvent:GetPrimaryAssetsXMLEvent = new GetPrimaryAssetsXMLEvent(insertIntoBE_POSITIONSuccessHandler);
			CairngormEventDispatcher.getInstance().dispatchEvent(getPrimaryAssetXMLEvent);
		}	
		
		private function insertIntoBE_POSITIONSuccessHandler(back:*):void{
			var bePositionXML:XML ;
			
			if(back != null){
				bePositionXML = back as XML ;
				var x:Number = 200000;
				var y:Number = 200000;
				var decalageX:Number = 100;
				var decalageY:Number = 15;
				var nbBE:int = 0;
				var nivBE:int = 0;
				for each(var primaryAsset:PrimaryAsset in _primaryAssetList){
					nbBE++;
					createBENodeEntity(primaryAsset, x, y, bePositionXML);
					if(nbBE == 8){
						nbBE = 0;
						nivBE++;
						y = 200000 + (150*nivBE);
						x = 200000;
					}else{
						x += decalageX;
						y += decalageY;
					}
				}
				
				var savePrimaryAssetsEvent:SavePrimaryAssetsEvent = new SavePrimaryAssetsEvent(bePositionXML, savePrimaryAssestsSuccessHandler);
				CairngormEventDispatcher.getInstance().dispatchEvent(savePrimaryAssetsEvent);
			}
		}
		
		private function savePrimaryAssestsSuccessHandler():void{
			
		}
		
		private function createBENodeEntity(primaryAsset:PrimaryAsset, x:Number, y:Number, bePositionXML:XML):String{
			var entityStr:String;
			
			// construction de la chaine
			entityStr = "<entity id=\""+ primaryAsset.id +"\" iid=\""+ UIDUtil.createUID() +"\" type=\"com.anssi.ebios.view.primaryasset.block.PrimaryAssetDraggableEntity\" " +
				"x=\""+ x +"\" y=\""+ y +"\" idEntity=\"Entity0\" title=\""+ primaryAsset.libelle +"\" description=\"\" retenu=\"true\" depositaire=\"-1\" />";
			
			// conversion au format xml puis ajout à 
			var entityXML:XML = new XML(entityStr);
			
			bePositionXML.entities.appendChild(entityXML);
			return bePositionXML;
		}

		private function insertIntoBS_POSITION():void{
			var getSupportAssetsXMLEvent:GetSupportAssetsXMLEvent = new GetSupportAssetsXMLEvent(insertIntoBS_POSITIONSuccessHandler);
			CairngormEventDispatcher.getInstance().dispatchEvent(getSupportAssetsXMLEvent);
		}
		
		private function insertIntoBS_POSITIONSuccessHandler(back:*):void{	
			var bsPositionXML:XML;
			
			if(back != null){
				
				bsPositionXML = back as XML;
				var x:Number = 200000;
				var y:Number = 200000;
				var decalageX:Number = 100;
				var decalageY:Number = 15;
				var nbBS:int = 0;
				var nivBS:int = 0;
				for each(var supportingAsset:SupportingAsset in _supportingAssetList){
					nbBS++;
					createBSNodeEntity(supportingAsset, x, y, bsPositionXML);
					if(nbBS == 8){
						nbBS = 0;
						nivBS++;
						y = 200000 + (190*nivBS);
						x = 200000;
					}else{
						x += decalageX;
						y += decalageY;
					}
				}
				
				var saveSupportAssetsEvent:SaveSupportAssetsEvent = new SaveSupportAssetsEvent(bsPositionXML, saveSupportAssetsSuccessHandler);
				CairngormEventDispatcher.getInstance().dispatchEvent(saveSupportAssetsEvent);
			}
			
		}
	
		private function saveSupportAssetsSuccessHandler():void{
			
		}

		
		private function createBSNodeEntity(supportingAsset:SupportingAsset, x:Number, y:Number, bsPositionXML:XML):String{
			 var entityStr:String;
			 
			 // le type est "com.anssi.ebios.view.supportasset.block.SupportAssetLOC" car par défaut le type du BS est LOC
			 //construction de la chaine:
			 entityStr = "<entity id=\""+ supportingAsset.id +"\" iid=\""+ UIDUtil.createUID() +"\" type=\"com.anssi.ebios.view.supportasset.block.SupportAssetLOC\" " +
				 "x=\""+ x +"\" y=\""+ y +"\" idEntity=\"Entity0\" title=\""+ supportingAsset.label +"\" description=\"\" retenu=\"true\" proprietaire=\"-1\" typeid=\""+supportingAsset.type.id+"\" />";
			 var entityXML:XML = new XML(entityStr);
			 
			 bsPositionXML.entities.appendChild(entityXML);
			return bsPositionXML;
		}
	}
}