package com.anssi.ebios.services
{
	import com.anssi.ebios.model.Indicator;
	import com.anssi.ebios.model.IndicatorLevel;
	import com.anssi.ebios.utils.CompareCollectionUtil;
	
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLErrorEvent;
	import flash.events.SQLEvent;
	
	import mx.collections.ArrayCollection;
	import mx.collections.ArrayList;
	import mx.controls.List;
	import mx.rpc.IResponder;
	
	public class IndicatorService extends AppServices
	{
		
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement;
		private var _indicator:Indicator;
		private var _currentIndex:Number=-1;
		private var _primaryKey:Number;
		private var _indicatorLevelListToDelete:ArrayCollection;
		
		public function IndicatorService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		
		/*******************************************************/
		/** Récupération de la liste des Indicateurs **/
		/*******************************************************/
		public function getIndicator():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = "SELECT I.idINDICATEUR, I.libelle as i_libelle, NI.idNINDICATEUR, NI.libelle as ni_libelle, NI.ordre " +
				" FROM INDICATEUR I LEFT OUTER JOIN NINDICATEUR NI " +
				" ON I.idINDICATEUR = NI.idINDICATEUR " +
				" ORDER BY I.libelle, NI.ordre";
	
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getIndicatorResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function getIndicatorResult(event:SQLEvent):void
		{
			var indicatorList:ArrayCollection = new ArrayCollection();
			// récupération des résultats
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			// si nous avons des résultats
			if (result != null && result.data != null){
				indicatorList = formatIndicatorResult(result);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(indicatorList);
		}
		
		public function formatIndicatorResult(result:SQLResult):ArrayCollection{
			var listResult:ArrayCollection=new ArrayCollection();
			// variables temporaires

			if (result.data){
			
				var row:Object;
				var numRows:int = result.data.length;
				var tempIndicator:Indicator;
				var tempIndicatorLevel:IndicatorLevel;
				var idIND:Number;
				
				for( var i:int=0; i< numRows;i++)
				{
					row=result.data[i];
					if(idIND !=  row["idINDICATEUR"])
					{
						idIND =  row["idINDICATEUR"];
						
						tempIndicator= new Indicator();
						tempIndicator.id=row["idINDICATEUR"];
						tempIndicator.libelle=row["i_libelle"];
						tempIndicator.export_id='i' + row["idINDICATEUR"];
						
						tempIndicator.indicatorLevelList=new ArrayCollection();
						listResult.addItem(tempIndicator);
					}
					if(row["idNINDICATEUR"]>0){
						tempIndicatorLevel = new IndicatorLevel();
						tempIndicatorLevel.id=row["idNINDICATEUR"];
						tempIndicatorLevel.label=row["ni_libelle"];
						tempIndicatorLevel.ordre=row["ordre"];
						tempIndicator.indicatorLevelList.addItem(tempIndicatorLevel);
					}
					
				}
			}	
			return listResult;
		}
		
		
		/******************************************************/
		/** Récupération d'un critère de sécurité via son ID **/
		/******************************************************/
		
		public function getIndicatorById(id:Number):void
		{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "SELECT I.idINDICATEUR, I.libelle as i_libelle, I.definition, " +
				" NI.idNINDICATEUR, NI.libelle as ni_libelle, NI.ordre, NI.description  " +
				" FROM INDICATEUR I LEFT OUTER JOIN NINDICATEUR NI " +
				" ON I.idINDICATEUR = NI.idINDICATEUR " +
				" WHERE I.idINDICATEUR = :idINDICATEUR" +
				" ORDER BY I.libelle, NI.ordre";
			
			
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idINDICATEUR"] = id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getIndicatorByIdResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getIndicatorByIdResult(event:SQLEvent):void
		{
			// récupération des résultats
			var result:SQLResult = SQLStatement(event.target).getResult();
			var tmpIndL:IndicatorLevel = null;
			
			// si nous avons des résultats
			if (result != null && result.data != null)
			{
				var indicator:Indicator = new Indicator();
				var row:Object;
				var row0:Object;
				var numRows:int = result.data.length;
				
				// On récupère le libelle et la description de la premiere ligne pour l'indicateur
				// Toutes ces infos sont identiques pour chaque ligne (on ramène les niveaux d'un indicateur)
				row0 = result.data[0];
				indicator.id = row0["idINDICATEUR"];
				indicator.libelle = row0["i_libelle"];
				indicator.definition = row0["definition"];
				
				// on récupère les niveaux de l'indicateur
				
				for(var i:int = 0;i<numRows;i++){
					row = result.data[i];
					
					// on remet bien à NULL l'objet associé pour éviter de prendre l'objet du tour de boucle précédent
					tmpIndL = null;
					if(null != row["idNINDICATEUR"]){
						tmpIndL = new IndicatorLevel();
						tmpIndL.id = row["idNINDICATEUR"];
						tmpIndL.label = row["ni_libelle"];
						tmpIndL.ordre = row["ordre"];
						tmpIndL.description = row["description"];
						indicator.indicatorLevelList.addItem(tmpIndL);
					}
				}
				
				_sqlStatement.sqlConnection.close();
				responder.result(indicator);
			}
		}
		
		/******************************************/
		/** Suppression d'un Indicateur			 **/
		/******************************************/
		
/*		public function deleteIndicator(indicator:Indicator):void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM INDICATEUR " +
				" WHERE idINDICATEUR= :idINDICATEUR";
			
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idINDICATEUR"] = indicator.id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,deleteIndicatorResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function deleteIndicatorResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			_sqlStatement.sqlConnection.close();
			responder.result(null);
		}*/
		
		/**
		 * Pour la suppression d'un indicateur , il faut le faire en cascade.
		 * 1) on supprime dans un premier temps les liaisons dans la table suivre, avec cet indicateur
		 * 2) puis les niveaux d'indicateur liés à cet indicateur
		 * 3) enfin on supprime l'indicateur en question
		 * tout ceci en mode synchrone
		 * */
		
		public function deleteIndicator(indicator:Indicator):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			openInSyncMode(_sqlStatement);
			
			var query:String="";
			
			query="DELETE FROM SUIVRE WHERE idINDICATEUR= :idINDICATEUR ";
			_sqlStatement.text=query;
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idINDICATEUR"] = indicator.id;
			execStatement(_sqlStatement);
			
			query="DELETE FROM NINDICATEUR WHERE idINDICATEUR= :idINDICATEUR ";
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			
			query="DELETE FROM INDICATEUR WHERE idINDICATEUR= :idINDICATEUR ";
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			
			_sqlStatement.sqlConnection.close();
			responder.result(null);
		}
		
		
		/******************************************/
		/** Mise à jour d'un indicateur 		 **/
		/******************************************/
		
		public function updateIndicator(indicator:Indicator):void
		{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String="UPDATE INDICATEUR SET libelle = :libelle , definition = :definition, dateModification = :dateModification" +
				" WHERE idINDICATEUR = :idINDICATEUR";
			
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":libelle"] = indicator.libelle;
			_sqlStatement.parameters[":definition"] = indicator.definition;
			_sqlStatement.parameters[":idINDICATEUR"] = indicator.id;
			_sqlStatement.parameters[":dateModification"] = new Date();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,updateIndicatorResult);
			
			_indicator = indicator;
			
			openAndExecStatementInAsyncMode(_sqlStatement);	
			
		}
		
		private function updateIndicatorResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			_primaryKey = SQLStatement(event.target).parameters[":idINDICATEUR"];
			
			_sqlStatement.sqlConnection.close();
			
			/*Appel de la fonction qui récupère la liste des niveaux en base, pour pouvoir ensuite supprimer les niveaux
			existants en base mais supprimer de l'IHM*/			
			getListIndicatorLevel();
		}
		
		
		private function updateIndicatorLevel():void
		{
			var query:String="";
			
			_currentIndex++;
			
			if(_indicator.indicatorLevelList != null){
				if(_currentIndex < _indicator.indicatorLevelList.length){
					
					var indicatorLevel:IndicatorLevel = _indicator.indicatorLevelList.getItemAt(_currentIndex) as IndicatorLevel;
					setBDDName();
					_sqlStatement = new SQLStatement();				
					_sqlStatement.sqlConnection = this.sqlConnection;
					
					if (Number(indicatorLevel.id) <= 0){
						query="INSERT INTO NINDICATEUR (libelle, description, ordre, idINDICATEUR, dateCreation, dateModification) " +
							" VALUES (:libelle, :description, :ordre, :idINDICATEUR, :dateCreation, :dateModification)";
						
						_sqlStatement.clearParameters();
						_sqlStatement.parameters[":libelle"] = indicatorLevel.label;
						_sqlStatement.parameters[":description"] = indicatorLevel.description;
						_sqlStatement.parameters[":ordre"] = indicatorLevel.ordre;
						_sqlStatement.parameters[":idINDICATEUR"] = _indicator.id;
						_sqlStatement.parameters[":dateCreation"] = new Date();
						_sqlStatement.parameters[":dateModification"] = new Date();

					}else {
						
						query = "UPDATE NINDICATEUR SET libelle = :libelle, description = :description, ordre = :ordre, dateModification= :dateModification " +
							" WHERE idNINDICATEUR = :idNINDICATEUR ";
						
						_sqlStatement.clearParameters();
						_sqlStatement.parameters[":libelle"] = indicatorLevel.label;
						_sqlStatement.parameters[":description"] = indicatorLevel.description;
						_sqlStatement.parameters[":ordre"] = indicatorLevel.ordre;
						_sqlStatement.parameters[":idNINDICATEUR"] = indicatorLevel.id;
						_sqlStatement.parameters[":dateModification"] = new Date();
					}
					
					_sqlStatement.text = query;
					_sqlStatement.addEventListener(SQLEvent.RESULT,updateIndicatorLevelResult);
					
					openAndExecStatementInAsyncMode(_sqlStatement);	
				}else{
					finish();
				}
			}
			
		}
		
		private function updateIndicatorLevelResult(event:SQLEvent):void
		{
			updateIndicatorLevel();
		}
		
		private function getListIndicatorLevel():void
		{
			setBDDName();			
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String ="SELECT * FROM NINDICATEUR WHERE idINDICATEUR = :idINDICATEUR ";
			
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idINDICATEUR"] = _indicator.id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getListIndicatorLevelResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getListIndicatorLevelResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null)
			{
				var row:Object;
				var numRows:int = result.data.length;
				var indicatorLevel:IndicatorLevel;
				var indicatorLevelList:ArrayCollection = new ArrayCollection();
				
				//On récupère les niveaux du critère
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					indicatorLevel = new IndicatorLevel();
					indicatorLevel.id = row["idNINDICATEUR"];
					indicatorLevel.label = row["libelle"];
					indicatorLevel.ordre = row["ordre"];
					indicatorLevel.description = row["description"];
					
					indicatorLevelList.addItem(indicatorLevel);
				}
			}
			_currentIndex = -1;
			_sqlStatement.sqlConnection.close();
			updateIndicatorLevel();
		}

		
		private function finish():void{
			_sqlStatement.sqlConnection.close();
			responder.result(_primaryKey);
		}
		
		/******************************************/
		/** Suppression d'un niveau d'indicateur **/
		/******************************************/
		
		
		public function deleteIndicatorLevel(indicatorLevel:IndicatorLevel):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			openInSyncMode(_sqlStatement);
			
			var query:String=" DELETE FROM SUIVRE WHERE idNINDICATEUR= :idNINDICATEUR";
			_sqlStatement.text=query;
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idNINDICATEUR"] = indicatorLevel.id;
			execStatement(_sqlStatement);
			
			query=" DELETE FROM NINDICATEUR WHERE idNINDICATEUR= :idNINDICATEUR";
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			_sqlStatement.sqlConnection.close();
			responder.result(null);
		}

		
		/******************************************/
		/** Création d'un indicateur	 		 **/
		/******************************************/
		
		public function createIndicator(indicator:Indicator):void
		{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String="INSERT INTO INDICATEUR (libelle, definition, dateCreation, dateModification) " +
				" VALUES (:libelle, :definition, :dateCreation, :dateModification)";
			
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":libelle"] = indicator.libelle;
			_sqlStatement.parameters[":definition"] = indicator.definition;
			_sqlStatement.parameters[":dateCreation"] = new Date();
			_sqlStatement.parameters[":dateModification"] = new Date();
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,createIndicatorResult);
			
			_indicator = new Indicator();
			_indicator = indicator;
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function createIndicatorResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null)
			{
				_primaryKey = result.lastInsertRowID;
			}
			
			_indicator.id = String(_primaryKey);
			
			_sqlStatement.sqlConnection.close();
			
			//Appel de la fonction qui réalise la création des niveaux du critère de sécurité
			_currentIndex = -1;
			createIndicatorLevel();
		}
		
		private function createIndicatorLevel():void
		{
			_currentIndex++;
			if( _currentIndex < _indicator.indicatorLevelList.length){
					
				var indicatorLevel:IndicatorLevel = _indicator.indicatorLevelList.getItemAt(_currentIndex) as IndicatorLevel;
				setBDDName();				
				_sqlStatement = new SQLStatement();				
				_sqlStatement.sqlConnection = this.sqlConnection;
				
				var query:String = "INSERT INTO NINDICATEUR (libelle, description, ordre, idINDICATEUR, dateCreation, dateModification) " +
					" VALUES(:libelle, :description, :ordre, :idINDICATEUR, :dateCreation, :dateModification)";
				
				_sqlStatement.clearParameters();
				_sqlStatement.parameters[":libelle"] = indicatorLevel.label;
				_sqlStatement.parameters[":description"] = indicatorLevel.description;
				_sqlStatement.parameters[":ordre"] = indicatorLevel.ordre;
				_sqlStatement.parameters[":idINDICATEUR"] = _indicator.id;
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();
				
				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,createIndicatorLevelResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);	
			}else{
				_sqlStatement.sqlConnection.close();
				responder.result(_primaryKey);
			}
		}
		private function createIndicatorLevelResult(event:SQLEvent):void
		{
			createIndicatorLevel();
		}
		
		public function constructIndicatorQuery():String
		{
			return  "SELECT I.idINDICATEUR, I.libelle as i_libelle, NI.idNINDICATEUR, NI.libelle as ni_libelle, NI.ordre " +
				" FROM INDICATEUR I LEFT OUTER JOIN NINDICATEUR NI " +
				" ON I.idINDICATEUR = NI.idINDICATEUR " +
				" ORDER BY I.libelle, NI.ordre";
			
		}
	}
}