package com.anssi.ebios.services
{
	import com.anssi.ebios.model.LikelihoodLevel;
	import com.anssi.ebios.model.LikelihoodLevelLight;
	import com.anssi.ebios.utils.CompareCollectionUtil;
	import com.anssi.ebios.utils.Resources;
	
	import flash.data.SQLMode;
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLEvent;
	import flash.filesystem.File;
	
	import mx.collections.ArrayCollection;
	import mx.rpc.IResponder;
	
	public class LikelihoodService extends AppServices
	{
		private var _responder:IResponder;
		private var _sqlStatement:SQLStatement;
		private var _likelihoodLevelList:ArrayCollection;
		private var _likelihoodLevelListToDelete:ArrayCollection;
		private var _currentIndex:Number = -1;
		
		public function LikelihoodService(responder:IResponder)
		{
			_responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		/***********************************************************/
		/** Récupération de la liste des niveaux de vraisemblance **/
		/***********************************************************/
		
		public function constructLikelihoodLevelQuery(WHERECondition:String = ""):String
		{
			return  "SELECT * FROM NVRISQUE"
			+ " "+WHERECondition
			+" ORDER BY ORDRE";
			
		}
		
		public function getLikelihoodLevel():void
		{
			constructSelectLikelihoodLevelList();
			_sqlStatement.addEventListener(SQLEvent.RESULT,getLikelihoodLevelResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function constructSelectLikelihoodLevelList():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String;
				query = constructLikelihoodLevelQuery("");
			
			_sqlStatement.text = query;
		}
		
		private function getLikelihoodLevelResult(event:SQLEvent):void
		{
			
			var likelihoodList:ArrayCollection = new ArrayCollection();
			var result:SQLResult = SQLStatement(event.target).getResult();
			_sqlStatement.sqlConnection.close();
			_responder.result(constructLikelihoodLevelListResult(result));
		}
		
		public function constructLikelihoodLevelListResult(result:SQLResult):ArrayCollection{
			var likelihoodList:ArrayCollection = new ArrayCollection();			
			
			if (result != null && result.data != null)
			{
				var row:Object;
				var numRows:int = result.data.length;
				var likelihoodLevel:LikelihoodLevel;
				
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					likelihoodLevel = new LikelihoodLevel();	
					likelihoodLevel.id = row["idNVRISQUE"];
					likelihoodLevel.label = row["libelle"];
					likelihoodLevel.description = row["description"];
					likelihoodLevel.order = row["ordre"];
					
					likelihoodList.addItem(likelihoodLevel);
				}
			}
			return likelihoodList
		}
		
		
		/**********************************************************/
		/** Mise à jour de la liste des niveaux de vraisemblance **/
		/**********************************************************/
		public function updateLikelihoodLevelList(likelihoodLevelList:ArrayCollection):void{
			
			//On stocke la liste des niveaux de gravité saisis dans l'IHM
			_likelihoodLevelList = likelihoodLevelList;
			updateLikelihoodLevel();	
		}
		
		private function updateLikelihoodLevel():void{
			var query:String="";
			
			setBDDName();
			_sqlStatement = new SQLStatement();				
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			_currentIndex++
			if (_currentIndex < _likelihoodLevelList.length){
				var likelihoodLevel:LikelihoodLevel = _likelihoodLevelList.getItemAt(_currentIndex) as LikelihoodLevel;
				
				if (Number(likelihoodLevel.id) <= 0){
					query = "INSERT INTO NVRISQUE (libelle, description, ordre, dateCreation, dateModification)" +
						" VALUES (:libelle, :description, :ordre, :dateCreation, :dateModification)";
					
					_sqlStatement.clearParameters();
					_sqlStatement.parameters[":libelle"] = likelihoodLevel.label;
					_sqlStatement.parameters[":description"] = likelihoodLevel.description;
					_sqlStatement.parameters[":ordre"] = likelihoodLevel.order;
					_sqlStatement.parameters[":dateCreation"] = new Date();
					_sqlStatement.parameters[":dateModification"] = new Date();

				}else{
					query = "UPDATE NVRISQUE SET libelle = :libelle, description = :description, ordre = :ordre, dateModification = :dateModification " +
						" WHERE idNVRISQUE = :idNVRISQUE";
					
					_sqlStatement.clearParameters();
					_sqlStatement.parameters[":libelle"] = likelihoodLevel.label;
					_sqlStatement.parameters[":description"] = likelihoodLevel.description;
					_sqlStatement.parameters[":ordre"] = likelihoodLevel.order;
					_sqlStatement.parameters[":dateModification"] = new Date();
					_sqlStatement.parameters[":idNVRISQUE"] = likelihoodLevel.id;
				}
				
				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,updateLikelihoodLevelResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);	
			}else{
				_sqlStatement.sqlConnection.close();
				_responder.result(null);
			}
		}
		
		private function updateLikelihoodLevelResult(event:SQLEvent):void{
			updateLikelihoodLevel();
		}
		
		
		/**********************************************/
		/** Suppression d'un niveau de vraisemblance **/
		/**********************************************/
		
		public function deleteLikelihoodLevel(likelihoodLevel:LikelihoodLevel):void{
			setBDDName();				
			_sqlStatement = new SQLStatement();				
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			openInSyncMode(_sqlStatement);

			var queryForThreatScenarioSetting:String = "UPDATE SM SET idNVRISQUE = null, dateModification = :dateModification " +
				" WHERE idNVRISQUE = " + likelihoodLevel.id;
			
			var queryForRiskSetting1:String = "UPDATE RISQUE SET vraisemblanceBrute = null, dateModification = :dateModification " +
				" WHERE vraisemblanceBrute = " + likelihoodLevel.id;
			
			var queryForRiskSetting2:String = "UPDATE RISQUE SET vraisemblanceME = null, dateModification = :dateModification " +
				" WHERE vraisemblanceME = " + likelihoodLevel.id;
			
			var queryForRiskSetting3:String = "UPDATE RISQUE SET vraisemblanceMC = null, dateModification = :dateModification " +
				" WHERE vraisemblanceMC = " + likelihoodLevel.id;
			
			
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":dateModification"] = new Date();
			
			// remise à NULL de la vraisemblance dans SM
			_sqlStatement.text = queryForThreatScenarioSetting;
			trace("requete: "+queryForThreatScenarioSetting);
			execStatement(_sqlStatement);
			
			// remise à NULL de la vraisemblanceBrute dans RISQUE
			_sqlStatement.text = queryForRiskSetting1;
			trace("requete: "+queryForRiskSetting1);
			execStatement(_sqlStatement);
			
			// remise à NULL de la vraisemblanceME dans RISQUE
			_sqlStatement.text = queryForRiskSetting2;
			trace("requete: "+queryForRiskSetting2);
			execStatement(_sqlStatement);
			
			// remise à NULL de la vraisemblanceMC dans RISQUE
			_sqlStatement.text = queryForRiskSetting3;
			trace("requete: "+queryForRiskSetting3);
			execStatement(_sqlStatement);
			
			var queryForASSOCIERDeleting:String = "DELETE FROM ASSOCIER WHERE idNVRISQUE = " + likelihoodLevel.id;
			var queryForLikelihoodDeleting:String = "DELETE FROM NVRISQUE WHERE idNVRISQUE = " + likelihoodLevel.id;
			_sqlStatement.clearParameters();
			// suppression de NRISQUE dont le idNVRISQUE est dans la liste
			_sqlStatement.text = queryForASSOCIERDeleting;
			trace("requete: "+queryForASSOCIERDeleting);
			execStatement(_sqlStatement);
			
			// suppression de NVRISQUE dont le idNVRISQUE est dans la liste
			_sqlStatement.text = queryForLikelihoodDeleting;
			trace("requete: "+queryForLikelihoodDeleting);
			execStatement(_sqlStatement);
			
			_sqlStatement.sqlConnection.close();
			_responder.result(null);
		} 
		
		/*****************************************************************/
		/** Récupération de la liste des niveaux de vraisemblance light **/
		/*****************************************************************/
		
		public function getLikelihoodLevelLight():void
		{
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String;
				query = constructLikelihoodLevelQuery("");
			
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getLikelihoodLevelLightResult);
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getLikelihoodLevelLightResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var likelihoodLevelLightList:ArrayCollection = new ArrayCollection();
			if (result!=null && result.data!=null){
				likelihoodLevelLightList = constructLikelihoodLevelLightList(result);
			}
			_sqlStatement.sqlConnection.close();
			_responder.result(likelihoodLevelLightList);
		}
		
		private function constructLikelihoodLevelLightList(result:SQLResult):ArrayCollection{
			
			
			var likelihoodLevelLightList:ArrayCollection = new ArrayCollection();
			
			var row:Object;
			var numRows:int = result.data.length;
			var likelihoodLevelLight:LikelihoodLevelLight;
			
			for( var i:int=0; i< numRows;i++)
			{
				row=result.data[i];
				
				if(row["idNVRISQUE"]>0){
					
					likelihoodLevelLight= new LikelihoodLevelLight();
					likelihoodLevelLight.description=row["description"];
					likelihoodLevelLight.order=row["ordre"];
					
					likelihoodLevelLightList.addItem(likelihoodLevelLight);
					
				}
			}
			
			return likelihoodLevelLightList;
			
		}
	}
}