package com.anssi.ebios.services
{
	import com.anssi.ebios.model.Parameter;
	import com.anssi.ebios.model.ParameterType;
	import com.anssi.ebios.model.Status;
	
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLEvent;
	
	import mx.collections.ArrayCollection;
	import mx.graphics.shaderClasses.SaturationShader;
	import mx.rpc.IResponder;

	public class ParameterService extends AppServices
	{
		
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement; 
		private var _currentIndex:Number = -1;
		private var _parameterList:ArrayCollection;
		
		public function ParameterService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		/*********************************************/
		/** Récupération de la liste des paramètres **/
		/*********************************************/		
		public function getParameter():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "SELECT P.idPARAMETRE, P.libelle as p_libelle, P.idTPARAMETRES, P.justification, P.idSTATUT as idSTATUT, " +
							   " TP.libelle as tp_libelle, " +
							   " STATUT.libelle as status_libelle " +
							   " FROM PARAMETRE P " +
							   " LEFT OUTER JOIN TPARAMETRES TP ON P.idTPARAMETRES = TP.idTPARAMETRES " +
							   " LEFT OUTER JOIN STATUT ON P.idSTATUT = STATUT.idSTATUT";
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getParameterResult);
			
			// Open and Execute the SQL Statement in an aync mode
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		public function getParameterResult(event:SQLEvent):void{
			
			var parameterList:ArrayCollection = new ArrayCollection();
			var result:SQLResult = SQLStatement(event.target).getResult();
			if (result != null && result.data != null){
				parameterList = constructParameterList(result);	
			}
			_sqlStatement.sqlConnection.close();
			responder.result(parameterList);
		}
		
		public function constructParameterList(result:SQLResult):ArrayCollection{
				var parameterList:ArrayCollection = new ArrayCollection();
			
				if (result.data){
					var row:Object;
					var numRows:int = result.data.length;
					var parameter:Parameter = null;
					var parameterType:ParameterType = null;
					var status:Status = null;
					
					for (var i:int = 0; i < numRows; i++)
					{
						row = result.data[i];
						parameterType = null;
						if (null != row["idTPARAMETRES"]){
							parameterType = new ParameterType();
							parameterType.id = row["idTPARAMETRES"];
							parameterType.libelle = row["tp_libelle"];
						}	
						
						status = new Status();
						if (null != row["idSTATUT"]){
							//status = new Status();
							status.id = row["idSTATUT"];
							status.label = row ["status_libelle"];
						}
						
						parameter = new Parameter();
						parameter.id = row["idPARAMETRE"];
						parameter.libelle = row["p_libelle"];
						parameter.parameterType = parameterType;
						parameter.status = status;
						parameter.justification = row["justification"];
						
						parameterList.addItem(parameter);
					}
				}
			
			return parameterList;
		}	
		
		/******************************************************/
		/** Récupération de la liste des types de paramètres **/
		/******************************************************/
		public function getParameterType():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "SELECT * FROM TPARAMETRES";
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getParameterTypeResult);

			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function getParameterTypeResult(event:SQLEvent):void{
			var parameterTypeList:ArrayCollection = null;
			// récupération des résultats
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			// si nous avons des résultats
			if (result != null && result.data != null)
			{
				parameterTypeList = new ArrayCollection();
				
				var row:Object;
				var numRows:int = result.data.length;
				var parameterType:ParameterType;
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					parameterType = new ParameterType();
					parameterType.id = row["idTPARAMETRES"];
					parameterType.libelle = row["libelle"];
					
					parameterTypeList.addItem(parameterType);
				}
			}
			
			_sqlStatement.sqlConnection.close();
			responder.result(parameterTypeList);
		}
		

		/********************************************/
		/** Récupération d'un paramètre via son ID **/
		/********************************************/
		public function getParameterById(id:Number):void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "SELECT P.idPARAMETRE, P.libelle as p_libelle, P.idTPARAMETRES, TP.libelle as tp_libelle" +
				" FROM PARAMETRE P LEFT OUTER JOIN TPARAMETRES TP" +
				" ON P.idTPARAMETRES = TP.idTPARAMETRES" +
				" WHERE idPARAMETRE= :idPARAMETRE";
				
			_sqlStatement.parameters[":idPARAMETRE"] = id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getParameterByIdResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getParameterByIdResult(event:SQLEvent):void{
			// récupération des résultats
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			// si nous avons des résultats
			if (result != null && result.data != null)
			{		
				var row:Object;
				var parameter:Parameter = new Parameter();
				var parameterType:ParameterType = new ParameterType();
				
				row = result.data[0];
				parameterType.id = row["idTPARAMETRES"];
				parameterType.libelle = row["tp_libelle"];
				
				parameter.id = row["idPARAMETRE"];
				parameter.libelle = row["p_libelle"];
				parameter.parameterType = parameterType;
				
			}
			
			_sqlStatement.sqlConnection.close();
			responder.result(parameter);
		}
		
		/*****************************/
		/** Création d'un paramètre **/
		/*****************************/
		public function createParameter(parameter:Parameter):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "INSERT INTO PARAMETRE (idTPARAMETRES, libelle, dateCreation, dateModification) " +
				" VALUES (:idTPARAMETRES, :libelle, :dateCreation, :dateModification)";

			_sqlStatement.parameters[":idTPARAMETRES"] = parameter.parameterType.id;
			_sqlStatement.parameters[":libelle"] = parameter.libelle;
			_sqlStatement.parameters[":dateCreation"] = new Date();
			_sqlStatement.parameters[":dateModification"] = new Date();

			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,createParameterResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		} 
		
		private function createParameterResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			var primaryKey:Number;
			if (result != null)
			{
				primaryKey = result.lastInsertRowID;
			}
			_sqlStatement.sqlConnection.close();
			responder.result(primaryKey);
		}		
		
		/********************************/
		/** Suppression d'un paramètre **/
		/********************************/
		public function deleteParameter(parameter:Parameter):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM PARAMETRE WHERE idPARAMETRE = :idPARAMETRE";
			
			_sqlStatement.parameters[":idPARAMETRE"] = parameter.id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,deleteParameterResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		

		private function deleteParameterResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			_sqlStatement.sqlConnection.close();
			responder.result(null);
		}
		
		
		/********************************/
		/** Mise à jour d'un paramètre **/
		/********************************/
		public function updateParameter(parameter:Parameter):void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "UPDATE PARAMETRE SET libelle = :libelle, idTPARAMETRES = :idTPARAMETRES, dateModification = :dateModification " +
				" WHERE idPARAMETRE= :idPARAMETRE";
			
		   _sqlStatement.parameters[":idTPARAMETRES"] = parameter.parameterType.id;
		   _sqlStatement.parameters[":libelle"] = parameter.libelle;
		   _sqlStatement.parameters[":idPARAMETRE"] = parameter.id;
		   _sqlStatement.parameters[":dateModification"] = new Date();
		   
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,updateParameterResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function updateParameterResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			var primaryKey:Number;
			primaryKey = SQLStatement(event.target).parameters[":idPARAMETRE"];
			
			_sqlStatement.sqlConnection.close();
			responder.result(primaryKey);
		}
		
		/*******************************************/
		/** Mise à jour d'une liste de paramètres **/
		/*******************************************/
		public function updateParameterList(parameterList:ArrayCollection):void{
			_parameterList = parameterList;
			_currentIndex = -1;	
			executeUpdateParameterListQuery();
		}
		
		private function executeUpdateParameterListQuery():void{
			
			_currentIndex++;				
				
			setBDDName();			
			_sqlStatement = new SQLStatement();			
			_sqlStatement.sqlConnection = this.sqlConnection;
				
			if (_currentIndex < _parameterList.length){
				
				var parameter:Parameter = _parameterList.getItemAt(_currentIndex) as Parameter;

				var query:String = "UPDATE PARAMETRE SET justification = :justification, idSTATUT = :idSTATUT, dateModification = :dateModification " +
					" WHERE idPARAMETRE= :idPARAMETRE";
				
				_sqlStatement.parameters[":justification"] = parameter.justification;
				_sqlStatement.parameters[":idSTATUT"] = parameter.status.id;
				_sqlStatement.parameters[":idPARAMETRE"] = parameter.id;
				_sqlStatement.parameters[":dateModification"] = new Date();
				
				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,executeUpdateParameterListQueryResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);	
			}else{
				_sqlStatement.sqlConnection.close();
				responder.result(null);
			}
		}
		
		private function executeUpdateParameterListQueryResult(event:SQLEvent):void{
			executeUpdateParameterListQuery();
		}
		
		public function constructParameterQuery(WHERECondition:String = ""):String{
			return "SELECT P.idPARAMETRE, P.libelle as p_libelle, P.idTPARAMETRES, P.justification, P.idSTATUT as idSTATUT, " +
				" TP.libelle as tp_libelle, " +
				" STATUT.libelle as status_libelle " +
				" FROM PARAMETRE P " +
				" LEFT OUTER JOIN TPARAMETRES TP ON P.idTPARAMETRES = TP.idTPARAMETRES " +
				" LEFT OUTER JOIN STATUT ON P.idSTATUT = STATUT.idSTATUT";
		} 
	}	
}