package com.anssi.ebios.services
{
	import com.anssi.ebios.model.Requirement;
	import com.anssi.ebios.model.ThreatType;
	
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLEvent;
	
	import mx.collections.ArrayCollection;
	import mx.rpc.IResponder;

	public class RequirementService extends AppServices
	{
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement;
		
		public function RequirementService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		
		/*********************************************/
		/** Récupération de la liste des pré-requis **/
		/*********************************************/
		public function getRequirementList():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = constructRequirementListQuery();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getRequirementListResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function constructRequirementListQuery(WHERECondition:String = " "):String{
			return "SELECT PREREQUIS.idPREREQUIS, PREREQUIS.libelle as prerequis_libelle, PREREQUIS.idTMENACES as idTMENACES , TMENACES.libelle as tmenaces_libelle" +
				" FROM PREREQUIS, TMENACES" +
				" WHERE PREREQUIS.idTMENACES = TMENACES.idTMENACES" +
				" " + WHERECondition;
		}
		
		private function getRequirementListResult(event:SQLEvent):void{
			var requirementList:ArrayCollection = new ArrayCollection();
			// récupération des résultats
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			// si nous avons des résultats
			if (result != null && result.data != null)
			{
				requirementList = constructRequirementList(result);
			}
			
			_sqlStatement.sqlConnection.close();
			responder.result(requirementList);
		}
		
		private function constructRequirementList(result:SQLResult):ArrayCollection{
			var row:Object;
			var numRows:int = result.data.length;
			var requirement:Requirement;
			var threatType:ThreatType;
			var requirementList:ArrayCollection = new ArrayCollection();
			
			for (var i:int = 0; i < numRows; i++)
			{
				row = result.data[i];
				
				if (row["idTMENACES"] != null){
					threatType = new ThreatType();
					threatType.id = row["idTMENACES"];
					threatType.label = row["tmenaces_libelle"];
				}
				
				requirement = new Requirement();
				requirement.id = row["idPREREQUIS"];
				requirement.label = row["prerequis_libelle"];
				requirement.threatType = threatType;
				
				requirementList.addItem(requirement);
			}
			return requirementList
		}
		
		/*********************************************/
		/** Récupération d'un pré-requis via son Id **/
		/*********************************************/
		public function getRequirementById(id:Number):void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = constructRequirementListQuery('AND PREREQUIS.idPREREQUIS = '+id);
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getRequirementByIdResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getRequirementByIdResult(event:SQLEvent):void{
			var requirement:Requirement;
			// récupération des résultats
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			// si nous avons des résultats
			if (result != null && result.data != null)
			{
				requirement = constructRequirementList(result)[0];
			}
			
			_sqlStatement.sqlConnection.close();
			responder.result(requirement);
		}
		
		/******************************/
		/** création d'un pré-requis **/
		/******************************/
		public function createRequirement(requirement:Requirement):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "INSERT INTO PREREQUIS (libelle, idTMENACES, dateCreation, dateModification) VALUES (:libelle, :idTMENACES, :dateCreation, :dateModification)";
			
			_sqlStatement.parameters[":libelle"] = requirement.label;
			_sqlStatement.parameters[":idTMENACES"] = requirement.threatType.id;
			_sqlStatement.parameters[":dateCreation"] = new Date();
			_sqlStatement.parameters[":dateModification"] = new Date();

			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,createRequirementResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function createRequirementResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			var primaryKey:Number;
			if (result != null)
			{
				primaryKey = result.lastInsertRowID;
			}
			_sqlStatement.sqlConnection.close();
			responder.result(primaryKey);
		}
		
		
		
		/*********************************/
		/** mise à jour d'un pré-requis **/
		/*********************************/
		public function updateRequirement(requirement:Requirement):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "UPDATE PREREQUIS SET libelle = :libelle, idTMENACES = :idTMENACES , dateModification = :dateModification " +
				" WHERE idPREREQUIS = :idPREREQUIS";
			
			_sqlStatement.parameters[":libelle"] = requirement.label;
			_sqlStatement.parameters[":idTMENACES"] = requirement.threatType.id;
			_sqlStatement.parameters[":idPREREQUIS"] = requirement.id;
			_sqlStatement.parameters[":dateModification"] = new Date();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,updateRequirementResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function updateRequirementResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			var primaryKey:Number;
			primaryKey = SQLStatement(event.target).parameters[":idPREREQUIS"];
			
			_sqlStatement.sqlConnection.close();
			responder.result(primaryKey);
		}
		
		
		/*********************************/
		/** suppression d'un pré-requis **/
		/*********************************/
		public function deleteRequirement(requirement:Requirement):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM PREREQUIS WHERE idPREREQUIS = :idPREREQUIS";
			
			_sqlStatement.parameters[":idPREREQUIS"] = requirement.id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,deleteRequirementResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function deleteRequirementResult(event:SQLEvent):void{
			_sqlStatement.sqlConnection.close();
			responder.result(null);
		}
	}
}