package com.anssi.ebios.services
{
	import com.anssi.ebios.model.RiskEvaluation;
	
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLEvent;
	
	import mx.collections.ArrayCollection;
	import mx.rpc.IResponder;

	public class RiskEvaluationService extends AppServices
	{
		
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement;
		private var _currentIndex:Number = -1;
		private var _riskEvaluationList:ArrayCollection;
		
		public function RiskEvaluationService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		/**********************************************************/
		/** Récupération de la liste des évaluations des risques **/
		/**********************************************************/
		public function getRiskEvaluationList():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "SELECT NRISQUE.idNRISQUE as idNRISQUE, NRISQUE.libelle as libelle, NRISQUE.codeCouleur, " +
							   " ASSOCIER.idNGRISQUE as idNGRISQUE, ASSOCIER.idNVRISQUE as idNVRISQUE " +
							   " FROM NRISQUE " +
							   " LEFT OUTER JOIN ASSOCIER ON ASSOCIER.idNRISQUE = NRISQUE.idNRISQUE";
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getRiskEvaluationListResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function getRiskEvaluationListResult(event:SQLEvent):void{
			var riskEvaluationList:ArrayCollection = new ArrayCollection();
			// récupération des résultats
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			// si nous avons des résultats
			if (result != null && result.data != null)
			{
				
				var row:Object;
				var numRows:int = result.data.length;
				var riskEvaluation:RiskEvaluation;
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					riskEvaluation = new RiskEvaluation();
					riskEvaluation.id = row["idNRISQUE"];
					riskEvaluation.label = row["libelle"];
					riskEvaluation.colorCode = row["codeCouleur"];
					riskEvaluation.idGravityLevel = row["idNGRISQUE"];
					riskEvaluation.idLikelihoodLevel = row["idNVRISQUE"];
					
					riskEvaluationList.addItem(riskEvaluation);
				}
			}
			
			_sqlStatement.sqlConnection.close();
			responder.result(riskEvaluationList);
		}
		
		public function resetColorMatrice():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM ASSOCIER "; 
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,resetColorMatriceResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function resetColorMatriceResult(event:SQLEvent):void{
			_sqlStatement.sqlConnection.close();
			responder.result(null);
		}
		
		public function updateRiskEvaluationColor(riskEvaluationList:ArrayCollection):void{
			
			_currentIndex++;
			_riskEvaluationList = riskEvaluationList;
			
			if (_currentIndex < _riskEvaluationList.length){
				var riskEvaluation:RiskEvaluation = _riskEvaluationList.getItemAt(_currentIndex) as RiskEvaluation;
				
				setBDDName();
				
				_sqlStatement = new SQLStatement();
				
				_sqlStatement.sqlConnection = this.sqlConnection;
				var query:String = "UPDATE NRISQUE SET codeCouleur = :codeCouleur, dateModification = :dateModification " +
					" WHERE idNRISQUE= :idNRISQUE";
				
				_sqlStatement.parameters[":codeCouleur"] = riskEvaluation.colorCode;
				_sqlStatement.parameters[":idNRISQUE"] = riskEvaluation.id;
				_sqlStatement.parameters[":dateModification"] = new Date();
				
				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,updateRiskEvaluationColorResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);	
			}else{
				_sqlStatement.sqlConnection.close();
				responder.result(null);
			}
		}
		
		
		private function updateRiskEvaluationColorResult(event:SQLEvent):void{
			updateRiskEvaluationColor(_riskEvaluationList);
		}
		
		
		public function updateRiskEvaluationAssociation(riskEvaluationList:ArrayCollection):void{
			_riskEvaluationList = riskEvaluationList;
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM ASSOCIER";
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,updateRiskEvaluationAssociationResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function updateRiskEvaluationAssociationResult(event:SQLEvent):void{
			_currentIndex = -1;
			affectEvaluation();
		}
		
		private function affectEvaluation():void{
			_currentIndex++;
			
			if (_currentIndex < _riskEvaluationList.length){
				var riskEvaluation:RiskEvaluation = _riskEvaluationList.getItemAt(_currentIndex) as RiskEvaluation;
				
				setBDDName();
				
				_sqlStatement = new SQLStatement();
				
				_sqlStatement.sqlConnection = this.sqlConnection;
				var query:String = "INSERT INTO ASSOCIER (idNRISQUE, idNGRISQUE, idNVRISQUE, dateCreation, dateModification) VALUES (:idNRISQUE, :idNGRISQUE, :idNVRISQUE, :dateCreation, :dateModification)";
				
				_sqlStatement.parameters[":idNRISQUE"] = riskEvaluation.id;
				_sqlStatement.parameters[":idNGRISQUE"] = riskEvaluation.idGravityLevel;
				_sqlStatement.parameters[":idNVRISQUE"] = riskEvaluation.idLikelihoodLevel;
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();
				
				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,affectEvaluationResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);	
			}else{
				_sqlStatement.sqlConnection.close();
				responder.result(null);
			}
		}
		
		private function affectEvaluationResult(event:SQLEvent):void{
			affectEvaluation();
		}
	}
}