package com.anssi.ebios.services
{
	import com.anssi.ebios.model.FearedEvent;
	import com.anssi.ebios.model.GravityLevel;
	import com.anssi.ebios.model.LikelihoodLevel;
	import com.anssi.ebios.model.Requirement;
	import com.anssi.ebios.model.Risk;
	import com.anssi.ebios.model.ThreatScenario;
	import com.anssi.ebios.model.ThreatSource;
	import com.anssi.ebios.model.ThreatType;
	import com.anssi.ebios.utils.RiskGenerationMethodEnum;
	
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLEvent;
	
	import mx.collections.ArrayCollection;
	import mx.resources.ResourceManager;
	import mx.rpc.IResponder;
	
	public class RiskGenerationService extends AppServices
	{
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement;
		private var _currentGenerationMethod:String;
		private var _utilRisqueIndex:int=-1;
		private var _utilThreatThenarioIndex:int=-1;
		private var _riskList:ArrayCollection;
		private var _threatThenarioList:ArrayCollection;
		private var _lastInsertRisque:Risk;
	
		public function RiskGenerationService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		/**
		 * La méthode generateRisk gère les opérations suivantes: 
		 * 
		 * deleteAllRisk
		 * deleteAllRiskResult
		 *
		 * deleteAllRisqueSM
		 * deleteAllRisqueSMResult
		 *
		 * getRiskListToCreate
		 * getRiskListToCreateResult
		 *
		 * createRisk --> recursif
		 * createRiskResult
		 * 
		 * affectThreatScenarioToRisk --> recursif
		 * affectThreatScenarioToRiskResult 
		 * 
		 **/
		public function generateRisk(generationMethod:String):void
		{
			_currentGenerationMethod = generationMethod;
			deleteAllRisk();
		}
		private function deleteAllRisk():void
		{	
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = 
				
				"DELETE FROM RISQUE";
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,deleteAllRiskResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function deleteAllRiskResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null)
			{
				deleteAllRisqueSM();
			}
		}
		
		private function deleteAllRisqueSM():void
		{
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = 
				
				"DELETE FROM COMPOSER";
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,deleteAllRisqueSMResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function deleteAllRisqueSMResult(event:SQLEvent):void
		{
			getRiskListToCreate();
		}
		
		private function getRiskListToCreate():void
		{
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = "";
			
			
			query = 
			
			"SELECT ER.idER, ER.libelle as libelleER, SM.idSM, ER.libelle ||' '|| SM.libelle libelleCourt, ER.[idNGRISQUE] gravite, " +
			"SM.[idNVRISQUE] vraisemblance, NVRISQUE.[ordre] ,CRITERE.[libelle] as libelleCritere, NCRITERE.libelle as besoinSecurite "+
			"FROM ER, CROISER, NCRITERE "+
			"LEFT OUTER JOIN SM ON ER.[idCRITERE] = SM.[idCRITERE] "+
			"LEFT OUTER JOIN CRITERE ON ER.idCRITERE = CRITERE.idCRITERE "+
			"LEFT OUTER JOIN NVRISQUE ON NVRISQUE.idNVRISQUE= SM.idNVRISQUE " +
			"WHERE CROISER.idBE = ER.idBE AND CROISER.idBS = SM.idBS " +
			"AND NCRITERE.idNCRITERE = ER.idNCRITERE " +
			"AND ER.idNGRISQUE > 1 " +
			"AND SM.idNVRISQUE > 1 ";

			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getRiskListToCreateResult);
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getRiskListToCreateResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();

			var riskList:ArrayCollection = new ArrayCollection();
			

			if (result != null && result.data != null)
			{
				var row:Object;
				var numRows:int = result.data.length;
				
				var risk:Risk;
				var utilERId:Number;
				
				var maxLikelihoodLevel:int;
				
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					
					if( _currentGenerationMethod == RiskGenerationMethodEnum.METHOD_1ERNSM )
					{
						if(utilERId != row["idER"])
						{
							utilERId = row["idER"];
							
							risk = constructRisk( row );
							riskList.addItem( risk );
							maxLikelihoodLevel = 0;
							
						}
						
					}
					else if( _currentGenerationMethod == RiskGenerationMethodEnum.METHOD_1ER1SM )
					{
						risk = constructRisk( row );
						riskList.addItem(risk);
						maxLikelihoodLevel = 0;
						
					}
					
					if(row["ordre"]>= maxLikelihoodLevel)
					{
						maxLikelihoodLevel = row["ordre"];
						risk.gross_likelihood.id = row["vraisemblance"];
					}
					

					var threatScenario:ThreatScenario = new ThreatScenario();
					threatScenario.id = row["idSM"];
					risk.threatScenarioList.addItem( threatScenario );
					
					
				}	
			}
		
		
			_sqlStatement.sqlConnection.close();
			
			createRisk( riskList );
		}
		

		private function createRisk(riskList:ArrayCollection):void
		{
			if(riskList)
				_riskList = riskList;
			
			_utilRisqueIndex ++
			
			if (_utilRisqueIndex >= _riskList.length ) {
				
				_utilRisqueIndex = -1;
				_sqlStatement.sqlConnection.close();
				
				riskGenerationTransactionSuccesHandler();
				
				return;
			}
			
			
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			
			var risk:Risk = _riskList.getItemAt(_utilRisqueIndex) as Risk;
			
			_lastInsertRisque = risk;
			
			var sql:String;
			
			sql = 
				
				"INSERT INTO RISQUE (idER, libelleCourt, libelleLong, graviteBrute, vraisemblanceBrute, dateCreation, dateModification) "+
				" VALUES (:idER, :libelleCourt, :libelleLong, :graviteBrute, :vraisemblanceBrute, :dateCreation, :dateModification)";
			
			
			_sqlStatement.text = sql;
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idER"] = risk.fearedEvent.id;
			_sqlStatement.parameters[":libelleCourt"]= ResourceManager.getInstance().getString('resources', 'risk.short_label_concatenation')+" "+_utilRisqueIndex;
			_sqlStatement.parameters[":libelleLong"]= risk.long_label;
			_sqlStatement.parameters[":graviteBrute"] = risk.gross_gravity.id;
			_sqlStatement.parameters[":vraisemblanceBrute"] = risk.gross_likelihood.id;
			_sqlStatement.parameters[":dateCreation"] = new Date();
			_sqlStatement.parameters[":dateModification"] = new Date();

			_sqlStatement.addEventListener(SQLEvent.RESULT,createRiskResult);
			openAndExecStatementInAsyncMode(_sqlStatement);	
			
		}
		private function createRiskResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var primaryKey:Number;
			if (result != null)
			{
				primaryKey = result.lastInsertRowID;
			}
			_lastInsertRisque.id = primaryKey.toString();
			affectThreatScenarioToRisk(_lastInsertRisque.id,_lastInsertRisque.threatScenarioList);
		}
		private function affectThreatScenarioToRisk(idRisk:String,threatThenarioList:ArrayCollection):void
		{
			if(threatThenarioList)
				_threatThenarioList = threatThenarioList;
			
			_utilThreatThenarioIndex ++
			
			if (_utilThreatThenarioIndex >= _threatThenarioList.length ) 
			{
				
				_utilThreatThenarioIndex = -1;
				_sqlStatement.sqlConnection.close();
				
				createRisk(null);
				
				return;
			}
			
			
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			
			var threatScenario:ThreatScenario = _threatThenarioList.getItemAt(_utilThreatThenarioIndex) as ThreatScenario;
			
			var sql:String;
			
			sql = 	
				
			"INSERT INTO COMPOSER (idRISQUE, idSM, dateCreation, dateModification) "+
			"VALUES (:idRISQUE, :idSM, :dateCreation, :dateModification)";
			
			_sqlStatement.text = sql;
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idRISQUE"] = idRisk;
			_sqlStatement.parameters[":idSM"]= threatScenario.id;
			_sqlStatement.parameters[":dateCreation"] = new Date();
			_sqlStatement.parameters[":dateModification"] = new Date();

			
			_sqlStatement.addEventListener(SQLEvent.RESULT,affectThreatScenarioToRiskResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		private function affectThreatScenarioToRiskResult(event:SQLEvent):void
		{
			affectThreatScenarioToRisk(_lastInsertRisque.id,null);
		}
		
		private function riskGenerationTransactionSuccesHandler():void
		{
			responder.result(new Object());
		}
		
		private function constructRisk(row:Object):Risk
		{
			var risk:Risk = new Risk();
			risk.long_label  = ResourceManager.getInstance().getString('resources', 'risk.long_label_concatenation')+" "+ row["libelleER"] +" "+row["besoinSecurite"] ; // todo: externaliser la chaine
			
			risk.gross_gravity = new GravityLevel();
			risk.gross_gravity.id = row["gravite"];
			
			risk.gross_likelihood = new LikelihoodLevel();
			//risk.gross_likelihood.id =  row["vraisemblance"]; // Max de l'ensemble de ses SM: Ne peut être géré ici
			
			risk.fearedEvent = new FearedEvent();
			risk.fearedEvent.id = row["idER"];
			
			risk.threatScenarioList = new ArrayCollection();
			
			
			return risk;
		}
		
		
		public function getRiskNumber():void{
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = "";
			
			
			query = 
				
				"SELECT ER.idER, ER.libelle as libelleER, SM.idSM, ER.libelle ||' '|| SM.libelle libelleCourt, ER.[idNGRISQUE] gravite, SM.[idNVRISQUE] vraisemblance, NVRISQUE.[ordre] ,CRITERE.[libelle] as libelleCritere "+
				"FROM ER, CROISER "+
				"LEFT OUTER JOIN SM ON ER.[idCRITERE] = SM.[idCRITERE] "+
				"LEFT OUTER JOIN CRITERE ON ER.idCRITERE = CRITERE.idCRITERE "+
				"LEFT OUTER JOIN NVRISQUE ON NVRISQUE.idNVRISQUE= SM.idNVRISQUE " +
				"WHERE CROISER.idBE = ER.idBE AND CROISER.idBS = SM.idBS " +
				"AND ER.idNGRISQUE > 1 " +
				"AND SM.idNVRISQUE > 1 ";
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getRiskNumberResult);
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getRiskNumberResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			var riskList_1ERNSM:ArrayCollection = new ArrayCollection();
			var riskList_1ER1SM:ArrayCollection = new ArrayCollection();
			
			if (result != null && result.data != null)
			{
				var row:Object;
				var numRows:int = result.data.length;
				
				var risk_1ERNSM:Risk;
				var risk_1ER1SM:Risk;
				
				var utilERId:Number;
				
				var maxLikelihoodLevel:int;
				
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					
					if(utilERId != row["idER"])
					{
						utilERId = row["idER"];
						
						risk_1ERNSM = constructRisk( row );
						riskList_1ERNSM.addItem( risk_1ERNSM );
						
					}

					risk_1ER1SM = constructRisk( row );
					riskList_1ER1SM.addItem(risk_1ER1SM);

				}	
			}			
			_sqlStatement.sqlConnection.close();
			
			var resultList:ArrayCollection = new ArrayCollection();
			resultList.addItem(riskList_1ERNSM.length),
			resultList.addItem(riskList_1ER1SM.length);
			
			responder.result(resultList);
			
		}
		
	}	
}