package com.anssi.ebios.services
{

	import com.anssi.ebios.event.fearedevent.GetFearedEventByIdEvent;
	import com.anssi.ebios.event.securitymeasureevent.GetSecurityMeasureByIdEvent;
	import com.anssi.ebios.event.threatscenarioevent.GetThreatScenarioByIdEvent;
	import com.anssi.ebios.model.FearedEvent;
	import com.anssi.ebios.model.GravityLevel;
	import com.anssi.ebios.model.LikelihoodLevel;
	import com.anssi.ebios.model.Objective;
	import com.anssi.ebios.model.PrimaryAsset;
	import com.anssi.ebios.model.ResidualRiskLight;
	import com.anssi.ebios.model.Risk;
	import com.anssi.ebios.model.RiskCriteria;
	import com.anssi.ebios.model.RiskExp;
	import com.anssi.ebios.model.RiskLight;
	import com.anssi.ebios.model.RiskMapping;
	import com.anssi.ebios.model.SecurityCriteria;
	import com.anssi.ebios.model.SecurityMeasure;
	import com.anssi.ebios.model.SupportingAsset;
	import com.anssi.ebios.model.ThreatScenario;
	import com.logica.fwk.utils.ArrayCollectionTool;
	
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLEvent;
	
	import mx.collections.ArrayCollection;
	import mx.core.mx_internal;
	import mx.rpc.IResponder;
	
	public class RiskService extends AppServices
	{
		
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement;
		private var _currentIndex:Number = -1;
		private var _riskList:ArrayCollection;
		private var _unretainedResidualRiskList:ArrayCollection;
		
		public function RiskService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		/************************************************************************/
		/** Récupération de la listes des risques avec seulement leur objectif **/
		/************************************************************************/
		public function constructObjectiveRiskQuery():String{
			return "SELECT RISQUE.idRISQUE, RISQUE.libelleLong, RISQUE.libelleCourt, " +
				" RISQUE.graviteME, RISQUE.vraisemblanceME, RISQUE.objectif, ifnull(RISQUE.commentaireObjectif, '') as commentaireObjectif, " +
				" ifnull(TOBJECTIFS.libelle, '') as obj_libelle, NGRISQUE.libelle as g_libelle, NVRISQUE.libelle as v_libelle " +
				" FROM RISQUE " +
				" LEFT OUTER JOIN TOBJECTIFS ON TOBJECTIFS.idTOBJECTIFS = RISQUE.objectif " +
				" LEFT OUTER JOIN NGRISQUE ON NGRISQUE.idNGRISQUE = RISQUE.graviteME " +
				" LEFT OUTER JOIN NVRISQUE ON NVRISQUE.idNVRISQUE = RISQUE.vraisemblanceME " +
				" WHERE NGRISQUE.ordre <> 0 AND NVRISQUE.ordre <> 0 ";
		}
		
		public function getObjectiveRiskList():void{			
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "SELECT RISQUE.idRISQUE, RISQUE.libelleLong, RISQUE.libelleCourt, " +
							   " RISQUE.graviteME, RISQUE.vraisemblanceME, RISQUE.objectif, RISQUE.commentaireObjectif , " +
							   " TOBJECTIFS.libelle as obj_libelle, NGRISQUE.libelle as g_libelle, NVRISQUE.libelle as v_libelle " +
							   " FROM RISQUE " +
							   " LEFT OUTER JOIN TOBJECTIFS ON TOBJECTIFS.idTOBJECTIFS = RISQUE.objectif " +
							   " LEFT OUTER JOIN NGRISQUE ON NGRISQUE.idNGRISQUE = RISQUE.graviteME " +
							   " LEFT OUTER JOIN NVRISQUE ON NVRISQUE.idNVRISQUE = RISQUE.vraisemblanceME " +
							   " WHERE NGRISQUE.ordre <> 0 AND NVRISQUE.ordre <> 0 ";
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getObjectiveRiskListResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function getObjectiveRiskListResult(event:SQLEvent):void{
			var riskList:ArrayCollection = new ArrayCollection();
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null)
			{
				riskList = constructObjectiveRiskList(result);	
			}
			_sqlStatement.sqlConnection.close();
			responder.result(riskList);
		}
		
		public function constructObjectiveRiskList(result:SQLResult):ArrayCollection{
			var riskList:ArrayCollection = new ArrayCollection();
				
			if (result.data){
			
				var row:Object;
				var numRows:int = result.data.length;
				var risk:Risk = null;
				var objective:Objective = null;
				var gravityME:GravityLevel = null;
				var likelihoodME:LikelihoodLevel = null;
				
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					risk = new Risk();
					risk.id = row["idRISQUE"];
					risk.short_label = row["libelleCourt"];
					risk.long_label = row["libelleLong"];
					risk.objectiveComment = row["commentaireObjectif"];
					
					objective = new Objective();
					objective.label = row["obj_libelle"];
					if (row["objectif"] != null){						
						objective.id = row["objectif"];												
					}
					
					if (row["graviteME"] != null){
						gravityME = new GravityLevel();
						gravityME.id = row["graviteME"];
						gravityME.label = row["g_libelle"];						
					}
					
					if (row["vraisemblanceME"] != null){
						likelihoodME = new LikelihoodLevel();
						likelihoodME.id = row["vraisemblanceME"]
						likelihoodME.label = row["v_libelle"];						
					}
					
					risk.objective = objective;
					risk.gravityME = gravityME;
					risk.likelihoodME = likelihoodME;
					
					riskList.addItem(risk);
				}
			}

			return riskList;
		}

		
		/********************************************************/
		/** Mise à jour des objectifs choisis pour les risques **/
		/********************************************************/
		public function updateObjectiveRiskList(riskList:ArrayCollection):void{
			_riskList = riskList;
			_currentIndex = -1;
			
			recursiveUpdateObjectiveRiskList();
		}
			
			
		private function recursiveUpdateObjectiveRiskList():void{
			
			setBDDName();
			_sqlStatement = new SQLStatement();			
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			_currentIndex++
				
			if (_currentIndex < _riskList.length){
				var risk:Risk = _riskList.getItemAt(_currentIndex) as Risk;

				var query:String = "UPDATE RISQUE SET objectif = :objectif, " +
					" commentaireObjectif = :commentaireObjectif, " +
					" dateModification = :dateModification " +
					" WHERE idRISQUE = :idRISQUE";
				
				_sqlStatement.parameters[":objectif"]= risk.objective.id;
				_sqlStatement.parameters[":commentaireObjectif"]= risk.objectiveComment;
				_sqlStatement.parameters[":idRISQUE"] = risk.id;
				_sqlStatement.parameters[":dateModification"] = new Date();
				
				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,recursiveUpdateObjectiveRiskListResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);
			}else{
				_sqlStatement.sqlConnection.close();
				responder.result(null);
			}
		}
		
		private function recursiveUpdateObjectiveRiskListResult(event:SQLEvent):void{
			recursiveUpdateObjectiveRiskList();
		}
		
		
		public function getRiskList(condition:String):void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
		
			switch(condition){
				case "withOutCondition":
					condition="";
					break;
				case "withConditionME":
					condition=" WHERE RISQUE.graviteME > 1 AND RISQUE.vraisemblanceME > 1 " +
						" AND RISQUE.graviteME not null AND RISQUE.vraisemblanceME not null ";
					break;
			}
			
			var query:String = buildGetRiskQuery(condition);
				
			_sqlStatement.text = query;	
			_sqlStatement.addEventListener(SQLEvent.RESULT,getRiskResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		
		/**
		 * 
		 * La méthode getRiskById gère les opérations suivantes: 
		 * 
		 * getRiskById
		 * 
		 * getFearedEventById
		 *
		 * getThreatScenarioByIdEvent --> Recursif
		 *
		 * GetSecurityMeasureByIdEvent --> Recursif
		 * 
		 * 
		 **/
		public function getRiskById(id:Number):void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = buildGetRiskQuery("WHERE RISQUE.idRISQUE= "+id);
			
			_sqlStatement.text = query;	
			_sqlStatement.addEventListener(SQLEvent.RESULT,getRiskByIdResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private var _curentRisk:Risk;
		private function getRiskByIdResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			if (result != null && result.data != null)
			{
				_curentRisk = buildRiskList(result.data)[0] as Risk;				
			}
			_sqlStatement.sqlConnection.close();			
			responder.result( _curentRisk );
		}
		
		
		
		

		
		
	

		
		
		
		private function getRiskResult(event:SQLEvent):void
		{
			var riskList:ArrayCollection = new ArrayCollection();
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null)
			{
				riskList = buildRiskList(result.data);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(riskList);
		}
		
		public function constructCartoRiskList(result:SQLResult):ArrayCollection{
			var riskList:ArrayCollection = new ArrayCollection();
			
			if (result != null && result.data != null)
			{
				riskList = buildRiskList(result.data);
			}
			return riskList;
		}
		
		public function buildRiskList(resultData:Array):ArrayCollection
		{
			var riskList:ArrayCollection = new ArrayCollection();
			var row:Object;
			var numRows:int = resultData.length;
			var risk:Risk;
			var utilRiskID:Number;
			
			for (var i:int = 0; i < numRows; i++)
			{
				
				row = resultData[i];
				if(utilRiskID != row["idRISQUE"])
				{
					utilRiskID = row["idRISQUE"]
					
					risk = buildRiskObject(row);
					riskList.addItem(risk);
					
				}
				
				var threatScenario:ThreatScenario = new ThreatScenario()
				threatScenario.id = row["idSM"];
				threatScenario.label = row["libelleSM"];
				
				risk.threatScenarioList.addItem( threatScenario );
				
			}
			return riskList;
		}
		
		public function updateRisk(risk:Risk):void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String =
				
				"UPDATE  RISQUE " +
				" SET libelleLong= :libelleLong ," +
				" libelleCourt= :libelleCourt ," +
				" graviteBrute= :graviteBrute ," +
				" vraisemblanceBrute= :vraisemblanceBrute ," +
				" graviteME= :graviteME ," +
				" vraisemblanceME= :vraisemblanceME ," +
				" graviteMC= :graviteMC ," +
				" risqueResiduel = :risqueResiduel ," +
				" vraisemblanceMC= :vraisemblanceMC ," +
				" dateModification = :dateModification " +
				" WHERE RISQUE.idRISQUE= :id";
			
			
			_sqlStatement.parameters[":libelleLong"] = risk.long_label;
			_sqlStatement.parameters[":libelleCourt"] = risk.short_label;
			_sqlStatement.parameters[":graviteBrute"] = risk.gross_gravity.id;
			_sqlStatement.parameters[":vraisemblanceBrute"] = risk.gross_likelihood.id;
			_sqlStatement.parameters[":graviteME"] = risk.gravityME.id;
			_sqlStatement.parameters[":vraisemblanceME"] = risk.likelihoodME.id;
			_sqlStatement.parameters[":graviteMC"] = risk.gravityMC.id;
			_sqlStatement.parameters[":vraisemblanceMC"] = risk.likelihoodMC.id;
			_sqlStatement.parameters[":id"] = risk.id;
			_sqlStatement.parameters[":dateModification"] = new Date();
			_sqlStatement.parameters[":risqueResiduel"] = risk.residualRiskLibelle;
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,updateRiskResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function updateRiskResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var primaryKey:Number;	
			primaryKey = SQLStatement(event.target).parameters[":id"];
			_sqlStatement.sqlConnection.close();
			responder.result(primaryKey);
		}
		
		
		// pour risque pour delivrale
		private function buildRiskObjectForDelivrable(row:Object):Risk
		{
			var gravityBrut:GravityLevel;
			var gravityME:GravityLevel;
			var gravityMC:GravityLevel;
			
			var likelihoodBrut:LikelihoodLevel;
			var likelihoodME:LikelihoodLevel;
			var likelihoodMC:LikelihoodLevel;
			
			var risk:Risk = new Risk();
			
			risk.id = row["idRISQUE"];
			risk.long_label = row["libelleLong"];
			risk.short_label = row["libelleCourt"];
			
			gravityBrut = new GravityLevel();
			gravityBrut.label = row["graviteBrute"];
			gravityBrut.id = row["graviteBruteID"];
			
			gravityME = new GravityLevel();
			gravityME.label = row["graviteME"];
			gravityME.id = row["graviteMEID"];
			
			gravityMC= new GravityLevel();
			gravityMC.label = row["graviteMC"];
			gravityMC.id = row["graviteMCID"];
			
			likelihoodBrut= new LikelihoodLevel();
			likelihoodBrut.label = row["vraisemblanceBrute"];
			likelihoodBrut.id = row["vraisemblanceBruteID"];
			
			likelihoodME= new LikelihoodLevel();
			likelihoodME.label = row["vraisemblanceME"];
			likelihoodME.id = row["vraisemblanceMEID"];
			
			likelihoodMC= new LikelihoodLevel();
			likelihoodMC.label = row["vraisemblanceMC"];
			likelihoodMC.id = row["vraisemblanceMCID"];
			
			var fearedEvent:FearedEvent = new FearedEvent();
			fearedEvent.id = row["idER"];
			fearedEvent.label =  row["libelleER"];
			
			risk.gross_gravity=gravityBrut;
			risk.gravityME=gravityME;
			risk.gravityMC=gravityMC;
			
			risk.gross_likelihood=likelihoodBrut;
			risk.likelihoodME=likelihoodME;
			risk.likelihoodMC=likelihoodMC;
			
			risk.fearedEvent = fearedEvent;
			
			risk.threatScenarioList = new ArrayCollection();
			risk.supportingAssetList = new ArrayCollection();
			risk.securityMeasureList = new ArrayCollection();
			//utile pour le risque pour le delivrable:
			var securityCriteria:SecurityCriteria = new SecurityCriteria();
			securityCriteria.id = row["criteria_id"];
			securityCriteria.libelle = row["criteria_label"];
			risk.securityCriteria = securityCriteria;
			
			var primaryAsset:PrimaryAsset = new PrimaryAsset();
			primaryAsset.id = row["BE_id"];
			primaryAsset.libelle = row["primaryAsset_libelle"];
			risk.primaryAssetForDelivrable = primaryAsset;
			
			return risk;
		}
		
		
		private function buildRiskObject(row:Object):Risk
		{
			var gravityBrut:GravityLevel;
			var gravityME:GravityLevel;
			var gravityMC:GravityLevel;
			
			var likelihoodBrut:LikelihoodLevel;
			var likelihoodME:LikelihoodLevel;
			var likelihoodMC:LikelihoodLevel;
			
			var risk:Risk = new Risk();
			
			risk.id = row["idRISQUE"];
			risk.long_label = row["libelleLong"];
			risk.short_label = row["libelleCourt"];
			
			gravityBrut = new GravityLevel();
			gravityBrut.label = row["graviteBrute"];
			gravityBrut.id = row["graviteBruteID"];
			
			gravityME = new GravityLevel();
			gravityME.label = row["graviteME"];
			gravityME.id = row["graviteMEID"];
			
			gravityMC= new GravityLevel();
			gravityMC.label = row["graviteMC"];
			gravityMC.id = row["graviteMCID"];
			
			likelihoodBrut= new LikelihoodLevel();
			likelihoodBrut.label = row["vraisemblanceBrute"];
			likelihoodBrut.id = row["vraisemblanceBruteID"];
			
			likelihoodME= new LikelihoodLevel();
			likelihoodME.label = row["vraisemblanceME"];
			likelihoodME.id = row["vraisemblanceMEID"];
			
			likelihoodMC= new LikelihoodLevel();
			likelihoodMC.label = row["vraisemblanceMC"];
			likelihoodMC.id = row["vraisemblanceMCID"];
			
			var fearedEvent:FearedEvent = new FearedEvent();
			fearedEvent.id = row["idER"];
			fearedEvent.label =  row["libelleER"];
			
			risk.gross_gravity=gravityBrut;
			risk.gravityME=gravityME;
			risk.gravityMC=gravityMC;
			
			risk.gross_likelihood=likelihoodBrut;
			risk.likelihoodME=likelihoodME;
			risk.likelihoodMC=likelihoodMC;
			
			risk.fearedEvent = fearedEvent;
			
			risk.threatScenarioList = new ArrayCollection();
			
			risk.residualRiskLibelle = row["myResidualRisk"];
			
			return risk;
		}
		
		public function buildGetRiskQuery(arg:String):String
		{
			var query:String = "SELECT RISQUE.idRISQUE, RISQUE.libelleCourt, RISQUE.libelleLong, " +
			"NGRISQUE_BRUT.libelle as graviteBrute ,NGRISQUE_ME.libelle as graviteME ,NGRISQUE_MC.libelle as graviteMC, " +
			"NGRISQUE_BRUT.idNGRISQUE as graviteBruteID ,NGRISQUE_ME.idNGRISQUE as graviteMEID ,NGRISQUE_MC.idNGRISQUE as graviteMCID, " +
			"NVRISQUE_BRUT.libelle as vraisemblanceBrute ,NVRISQUE_ME.libelle as vraisemblanceME ,NVRISQUE_MC.libelle as vraisemblanceMC, " +
			"NVRISQUE_BRUT.idNVRISQUE as vraisemblanceBruteID ,NVRISQUE_ME.idNVRISQUE as vraisemblanceMEID ,NVRISQUE_MC.idNVRISQUE as vraisemblanceMCID, " +
			"ER.libelle as libelleER, ER.idER, " +
			"SM.libelle as libelleSM, SM.idSM, " +
			"RISQUE.risqueResiduel as myResidualRisk " +
			"FROM RISQUE " +
			"LEFT OUTER JOIN NGRISQUE as NGRISQUE_BRUT ON NGRISQUE_BRUT.idNGRISQUE= RISQUE.graviteBrute " +
			"LEFT OUTER JOIN NGRISQUE as NGRISQUE_ME ON NGRISQUE_ME.idNGRISQUE= RISQUE.graviteME " +
			"LEFT OUTER JOIN NGRISQUE as NGRISQUE_MC ON NGRISQUE_MC.idNGRISQUE= RISQUE.graviteMC " +
			"LEFT OUTER JOIN NVRISQUE as NVRISQUE_BRUT ON NVRISQUE_BRUT.idNVRISQUE= RISQUE.vraisemblanceBrute " +
			"LEFT OUTER JOIN NVRISQUE as NVRISQUE_ME ON NVRISQUE_ME.idNVRISQUE= RISQUE.vraisemblanceME " +
			"LEFT OUTER JOIN NVRISQUE as NVRISQUE_MC ON NVRISQUE_MC.idNVRISQUE= RISQUE.vraisemblanceMC " +
			"LEFT OUTER JOIN COMPOSER  ON COMPOSER.idRISQUE= RISQUE.idRISQUE " +
			"LEFT OUTER JOIN ER  ON RISQUE.idER = ER.idER " +
			"LEFT OUTER JOIN SM  ON COMPOSER.idSM = SM.idSM "+
			arg;
			
			return query;
		}
		
		/*************************************************************************************************/
		/** Récupération de la listes des risques résiduels (gravité et vraisemblance ME <> non retenu) **/
		/*************************************************************************************************/
		public function getResidualRiskList():void{			
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "SELECT RISQUE.idRISQUE, RISQUE.libelleLong, RISQUE.libelleCourt, " +
				" RISQUE.graviteME, RISQUE.vraisemblanceME, " +
				" NGRISQUE.libelle as g_libelle, NGRISQUE.ordre as g_ordre, NVRISQUE.libelle as v_libelle, NVRISQUE.ordre as v_ordre " +
				" FROM RISQUE " +
				" LEFT OUTER JOIN NGRISQUE ON NGRISQUE.idNGRISQUE = RISQUE.graviteME " +
				" LEFT OUTER JOIN NVRISQUE ON NVRISQUE.idNVRISQUE = RISQUE.vraisemblanceME " +
				" WHERE NGRISQUE.ordre <> 0 AND NVRISQUE.ordre <> 0 ";
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getResidualRiskListResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}	
		
		private function getResidualRiskListResult(event:SQLEvent):void{
			var residualRiskList:ArrayCollection = new ArrayCollection();
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null)
			{
				var row:Object;
				var numRows:int = result.data.length;
				var risk:Risk = null;
				var gravityME:GravityLevel = null;
				var likelihoodME:LikelihoodLevel = null;
				
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					risk = new Risk();
					risk.id = row["idRISQUE"];
					risk.short_label = row["libelleCourt"];
					risk.long_label = row["libelleLong"];
					risk.isResidualRiskSelected = true;
					
					if (row["graviteME"] != null){
						gravityME = new GravityLevel();
						gravityME.id = row["graviteME"];
						gravityME.label = row["g_libelle"];	
						gravityME.order = row["g_ordre"];
						risk.gravityME = gravityME;
					}
					
					if (row["vraisemblanceME"] != null){
						likelihoodME = new LikelihoodLevel();
						likelihoodME.id = row["vraisemblanceME"]
						likelihoodME.label = row["v_libelle"];
						likelihoodME.order = row["v_ordre"];
						risk.likelihoodME = likelihoodME;
					}

					residualRiskList.addItem(risk);
				}
			}
			
			_sqlStatement.sqlConnection.close();
			responder.result(residualRiskList);
		}
		
		/***************************************************************/
		/** Mise à jour de la liste des risques résiduels non retenus **/
		/***************************************************************/
		public function updateUnretainedResidualRisk(unretainedResidualRiskList:ArrayCollection):void{
			_unretainedResidualRiskList = unretainedResidualRiskList;
			_currentIndex = -1;
			
			setBDDName();			
			_sqlStatement = new SQLStatement();			
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			executeUpdateQuery();
		}
		
		private function executeUpdateQuery():void{
			_currentIndex++;
			
			if (_currentIndex < _unretainedResidualRiskList.length){
				
				var risk:Risk = _unretainedResidualRiskList.getItemAt(_currentIndex) as Risk;
				

				var query:String = "UPDATE RISQUE SET graviteME = :graviteME ," +
					" vraisemblanceME = :vraisemblanceME ," +
					" dateModification = :dateModification" +
					" WHERE idRISQUE = :idRISQUE ";
				
				_sqlStatement.parameters[":graviteME"] = "1";
				_sqlStatement.parameters[":vraisemblanceME"] = "1";
				_sqlStatement.parameters[":dateModification"] = new Date();
				_sqlStatement.parameters[":idRISQUE"] = risk.id;
				
				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,executeUpdateQueryResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);	
			}else{
				_sqlStatement.sqlConnection.close();
				responder.result(null);
			}
		}
		
		private function executeUpdateQueryResult(event:SQLEvent):void{
			executeUpdateQuery();
		}
		
		public function getRiskResidList():void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
					
			var query:String = buildGetRiskQuery(" WHERE RISQUE.graviteMC > 1 AND RISQUE.vraisemblanceMC > 1 AND RISQUE.graviteMC not null AND RISQUE.vraisemblanceMC not null ");
			_sqlStatement.text = query;	
			_sqlStatement.addEventListener(SQLEvent.RESULT,getRiskResidResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function getRiskResidResult(event:SQLEvent):void
		{
			var riskResidList:ArrayCollection = new ArrayCollection();
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null)
			{
				riskResidList = buildRiskResidList(result.data);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(riskResidList);
		}
		private function buildRiskResidList(resultData:Array):ArrayCollection
		{
			var riskResidList:ArrayCollection = new ArrayCollection();
			var row:Object;
			var numRows:int = resultData.length;
			var risk:Risk;
			var utilRiskID:Number;
			
			for (var i:int = 0; i < numRows; i++)
			{
				
				row = resultData[i];
				if(utilRiskID != row["idRISQUE"])
				{
					utilRiskID = row["idRISQUE"]
					
					risk = buildRiskObject(row);
					riskResidList.addItem(risk);
					
				}
				
				var threatScenario:ThreatScenario = new ThreatScenario()
				threatScenario.id = row["idSM"];
				threatScenario.label = row["libelleSM"];
				
				risk.threatScenarioList.addItem( threatScenario );
				
			}
			return riskResidList;
		}
		
		public function getRiskLightList():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "SELECT * FROM RISQUE ";
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getRiskLightListResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getRiskLightListResult(event:SQLEvent):void{
			var riskLightList:ArrayCollection = new ArrayCollection();
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null)
			{
				var row:Object;
				var numRows:int = result.data.length;
				var risk:RiskLight = null;
				
				/* 
				On construit la liste des risques qui seront affichés dans l'écran 4.1.2
				A partir du résultat de la requête, on récupère 2 types de risques :s
					1) Les risques bruts (couple G/V estimé)
					2) Les risques avec ME (couple G/V estimé) 
				*/
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					
					//On ajoute les risques dont le couple G/V brute est estimé
					if (row["graviteBrute"] > 1 &&  row["vraisemblanceBrute"] > 1){
						risk = new RiskLight();
						risk.id = row["idRISQUE"];
						risk.short_label = row["libelleCourt"];
						risk.long_label = row["libelleLong"];
						risk.gross_gravity = row["graviteBrute"];
						risk.gross_likelihood = row["vraisemblanceBrute"];
						risk.isRiskWithME = false;
						riskLightList.addItem(risk);
					}
					
					//On ajoute les risques dont le couple G/V avec ME est estimé
					if (row["graviteME"] > 1 && row["vraisemblanceME"] > 1){
						risk = new RiskLight();
						risk.id = row["idRISQUE"];
						risk.short_label = row["libelleCourt"];
						risk.long_label = row["libelleLong"];
						risk.gravityME = row["graviteME"];
						risk.likelihoodME = row["vraisemblanceME"];
						risk.isRiskWithME = true;
						riskLightList.addItem(risk);
					}
					
		

				}				
			}
			
			_sqlStatement.sqlConnection.close();
			responder.result(riskLightList);
		}
		
		
		public function buildRiskFromMeasureQuery():String
		{
			return "SELECT * FROM RISQUE";
		}
		
		public function getRiskFromMeasureList():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = buildRiskFromMeasureQuery();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getRiskFromMeasureListResult);
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getRiskFromMeasureListResult(event:SQLEvent):void{
			var riskFromMeasureList:ArrayCollection = new ArrayCollection();
			// récupération des résultats
			var result:SQLResult = SQLStatement(event.target).getResult();
			// si nous avons des résultats
			if (result != null && result.data != null)
			{
				riskFromMeasureList = buildRiskFromMeasureList(result);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(riskFromMeasureList);
		}
		
		
		public function buildRiskFromMeasureList(result:SQLResult):ArrayCollection
		{
				var riskFromMeasureList:ArrayCollection = new ArrayCollection();	
				
				if (result.data){
				
					var row:Object;
					var numRows:int = result.data.length;
					var risk:Risk = null;
					
					for (var i:int = 0; i < numRows; i++)
					{
						row = result.data[i];
						
						risk = new Risk();
						risk.id = row["idRISQUE"];
						risk.short_label = row["libelleCourt"];
						risk.long_label = row["libelleLong"];
						riskFromMeasureList.addItem(risk);
					}
				}
				return riskFromMeasureList;	
		}
			
		
		public function getRiskExportList():void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = buildRiskExportQuery();
			
			_sqlStatement.text = query;	
			_sqlStatement.addEventListener(SQLEvent.RESULT,getRiskExportResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function getRiskExportResult(event:SQLEvent):void
		{
			var riskExportList:ArrayCollection = new ArrayCollection();
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null)
			{
				riskExportList = constructRiskExportList(result);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(riskExportList);
		}
		
		public function constructRiskListForDelivrable(result:SQLResult):ArrayCollection{
			var riskExportList:ArrayCollection = new ArrayCollection();
			
			if (result != null  && result.data != null){
				
				var row:Object;
				var numRows:int = result.data.length;
				var risk:Risk;
				var utilRiskID:Number;
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					if(utilRiskID != row["idRISQUE"])
					{
						utilRiskID = row["idRISQUE"]
						
						risk = buildRiskObjectForDelivrable(row);
						riskExportList.addItem(risk);
						
					}
					var threatScenario:ThreatScenario = new ThreatScenario()
					threatScenario.id = row["idSM"];
					threatScenario.label = row["libelleSM"];
					risk.threatScenarioList.addItem( threatScenario );
					
					var securityMeasure:SecurityMeasure = new SecurityMeasure();
					securityMeasure.id = row["idMESURE"];
					securityMeasure.label = row["mesure_libelle"];
					risk.securityMeasureList.addItem(securityMeasure);
					
					var supportingAsset:SupportingAsset = new SupportingAsset();
					supportingAsset.id = row["idBS"];
					supportingAsset.label = row["bs_libelle"];
					risk.supportingAssetList.addItem(supportingAsset);
				}
				
				
			}
			
			return riskExportList;
		}
		
		public function constructRiskExportList(result:SQLResult):ArrayCollection{
			
			
			var riskExportList:ArrayCollection = new ArrayCollection();
			
			if (result.data){
			
				var row:Object;
				var numRows:int = result.data.length;
				var riskExport:RiskExp;
				
				for( var i:int=0; i< numRows;i++)
				{
					row=result.data[i];
					
					if(row["idRISQUE"]>0){
						
						riskExport= new RiskExp();
						riskExport.primaryAssetlabel=row["primaryAsset_libelle"];
						riskExport.supportingAssetlabel=row["bs_libelle"];
						riskExport.short_label=row["libelleCourt"];
						riskExport.long_label=row["libelleLong"];
						riskExport.securityMeasurelabel=row["mesure_libelle"];
						riskExport.fearedEventlabel=row["libelleER"];
						riskExport.securityCriterialabel=row["criteria_label"];
						riskExport.threatScenariolabel=row["libelleSM"];
						riskExport.gravityMClabel=row["graviteMC"];
						riskExport.gravityMElabel=row["graviteME"];
						riskExport.gross_gravitylabel=row["graviteBrute"];
						riskExport.likelihoodMClabel=row["vraisemblanceMC"];
						riskExport.likelihoodMElabel=row["vraisemblanceME"];
						riskExport.gross_likelihoodlabel=row["vraisemblanceBrute"];
						
						
						riskExportList.addItem(riskExport);
						
					}
				}
			}
			return riskExportList;
		}
		
		public function getResidualRiskLightList():void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = buildResidualRiskExportQuery();
			
			_sqlStatement.text = query;	
			_sqlStatement.addEventListener(SQLEvent.RESULT,getResidualRiskLightResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function getResidualRiskLightResult(event:SQLEvent):void
		{
			var residualRiskLightList:ArrayCollection = new ArrayCollection();
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null)
			{
				residualRiskLightList = constructResidualRiskLightList(result);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(residualRiskLightList);
		}
		
		public function constructResidualRiskLightList(result:SQLResult):ArrayCollection{
			
			
			var residualRiskLightList:ArrayCollection = new ArrayCollection();
			
			if (result.data){
			
				var row:Object;
				var numRows:int = result.data.length;
				var residualRiskLight:ResidualRiskLight;
				
				for( var i:int=0; i< numRows;i++)
				{
					row=result.data[i];
					
					if(row["idRISQUE"]>0){
						
						residualRiskLight= new ResidualRiskLight();
						residualRiskLight.residualRiskLabel=row["risqueResiduel"];
						residualRiskLight.fearedEventLabel=row["libelleER"];
						residualRiskLight.threatScenarioLabel=row["libelleSM"];
						residualRiskLight.securityMeasureLabel=row["mesure_libelle"];			
						
						residualRiskLightList.addItem(residualRiskLight);
						
					}
				}
			}
			return residualRiskLightList;
		}
		
		public function constructResidualRiskForDelivrable(result:SQLResult):ArrayCollection{
			
			var residualRiskList:ArrayCollection =  new ArrayCollection();
			
			if(result != null && result.data != null){
				var row:Object;
				var numRows:int = result.data.length;
				var residualRiskLight:ResidualRiskLight;
				var utilResidualRisk:String;
				
				for (var i:int = 0;i<numRows; i++){
					
					row = result.data[i];
					
					if(utilResidualRisk != row["residualRisk"]){
						
						utilResidualRisk = row["residualRisk"];
						residualRiskLight = new ResidualRiskLight();
						residualRiskLight.residualRiskLabel = utilResidualRisk;
						residualRiskLight.fearedEventLabel = row["libelleER"];
						residualRiskLight.threatScenarioLabel =  new String();
						residualRiskLight.securityMeasureLabel =  new String();
						
						residualRiskList.addItem(residualRiskLight);
					}
					
					residualRiskLight.threatScenarioLabel += "- "+ row["libelleSM"] + "\n\n";
					residualRiskLight.securityMeasureLabel += "- "+ row["mesure_libelle"] + "\n\n";
				}
				
			}
			
			return residualRiskList;
		}
		public function getRiskMappingList():void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = buildRiskExportQuery();
			
			_sqlStatement.text = query;	
			_sqlStatement.addEventListener(SQLEvent.RESULT,getRiskMappingResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function getRiskMappingResult(event:SQLEvent):void
		{
			var riskMappingList:ArrayCollection = new ArrayCollection();
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null)
			{
				riskMappingList = constructRiskMappingList(result);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(riskMappingList);
		}
		
		private function constructRiskMappingList(result:SQLResult):ArrayCollection{
			
			
			var riskMappingList:ArrayCollection = new ArrayCollection();
			
			var row:Object;
			var numRows:int = result.data.length;
			var riskMapping:RiskMapping;
			
			for( var i:int=0; i< numRows;i++)
			{
				row=result.data[i];
				
				if(row["idRISQUE"]>0){
					
					riskMapping= new RiskMapping();
					riskMapping.short_label=row["libelleCourt"];
					riskMapping.long_label=row["libelleLong"];
					riskMapping.gross_gravityLabel=row["graviteBrute"];
					riskMapping.gross_likelihoodLabel=row["vraisemblanceBrute"];	
					riskMapping.gravityMELabel=row["graviteME"];
					riskMapping.likelihoodMELabel=row["vraisemblanceME"];
					
					riskMappingList.addItem(riskMapping);
					
				}
			}
			return riskMappingList;
		}
		
		public function buildRiskQueryForDelivrable():String{
			return  " SELECT RISQUE.idRISQUE as idRISQUE, RISQUE.libelleCourt, RISQUE.libelleLong, " +
				" NGRISQUE_BRUT.libelle as graviteBrute ,ifnull(NGRISQUE_ME.libelle, '') as graviteME , ifnull(NGRISQUE_MC.libelle, '') as graviteMC, " +
				" NGRISQUE_BRUT.idNGRISQUE as graviteBruteID ,NGRISQUE_ME.idNGRISQUE as graviteMEID ,NGRISQUE_MC.idNGRISQUE as graviteMCID, " +
				" NVRISQUE_BRUT.libelle as vraisemblanceBrute ,ifnull(NVRISQUE_ME.libelle, '') as vraisemblanceME ,ifnull(NVRISQUE_MC.libelle, '') as vraisemblanceMC, " +
				" NVRISQUE_BRUT.idNVRISQUE as vraisemblanceBruteID ,NVRISQUE_ME.idNVRISQUE as vraisemblanceMEID ,NVRISQUE_MC.idNVRISQUE as vraisemblanceMCID, " +
				" ER.libelle as libelleER, ER.idER as idER, " +
				" BS.libelle as bs_libelle, BS.idBS as idBS, " +
				" BE.libelle as primaryAsset_libelle, BE.idBE as BE_id, " +       
				" SM.libelle as libelleSM, SM.idSM as idSM, " +
				" ifnull(MESURE.libelle, '') as mesure_libelle, MESURE.idMESURE as idMESURE, " +
				" CRITERE.libelle as criteria_label, CRITERE.idCRITERE as criteria_id  " +				
				" FROM RISQUE " +
				" LEFT OUTER JOIN NGRISQUE as NGRISQUE_BRUT ON NGRISQUE_BRUT.idNGRISQUE= RISQUE.graviteBrute " +
				" LEFT OUTER JOIN NGRISQUE as NGRISQUE_ME ON NGRISQUE_ME.idNGRISQUE= RISQUE.graviteME " +
				" LEFT OUTER JOIN NGRISQUE as NGRISQUE_MC ON NGRISQUE_MC.idNGRISQUE= RISQUE.graviteMC " +
				" LEFT OUTER JOIN NVRISQUE as NVRISQUE_BRUT ON NVRISQUE_BRUT.idNVRISQUE= RISQUE.vraisemblanceBrute " +
				" LEFT OUTER JOIN NVRISQUE as NVRISQUE_ME ON NVRISQUE_ME.idNVRISQUE= RISQUE.vraisemblanceME " +
				" LEFT OUTER JOIN NVRISQUE as NVRISQUE_MC ON NVRISQUE_MC.idNVRISQUE= RISQUE.vraisemblanceMC " +
				" LEFT OUTER JOIN ER ON RISQUE.idER = ER.idER " +
				" LEFT OUTER JOIN BE ON BE.idBE = ER.idBE " +
				" LEFT OUTER JOIN CRITERE ON CRITERE.idCRITERE = ER.idCRITERE " +
				" LEFT OUTER JOIN COMPOSER ON COMPOSER.idRISQUE = RISQUE.idRISQUE " +   
				" LEFT OUTER JOIN SM ON SM.idSM = COMPOSER.idSM " +      
				" LEFT OUTER JOIN BS ON BS.idBS = SM.idBS " +       
				" LEFT OUTER JOIN PORTER ON PORTER.idBS = BS.idBS " +        
				" LEFT OUTER JOIN MESURE ON MESURE.idMESURE = PORTER.idMESURE " +
				" ORDER BY idRISQUE asc ";
		}
		
		public function buildRiskExportQuery():String
		{
			/*return "SELECT RISQUE.idRISQUE, RISQUE.libelleCourt, RISQUE.libelleLong, " +
				"NGRISQUE_BRUT.libelle as graviteBrute ,NGRISQUE_ME.libelle as graviteME ,NGRISQUE_MC.libelle as graviteMC, " +
				"NGRISQUE_BRUT.idNGRISQUE as graviteBruteID ,NGRISQUE_ME.idNGRISQUE as graviteMEID ,NGRISQUE_MC.idNGRISQUE as graviteMCID, " +
				"NVRISQUE_BRUT.libelle as vraisemblanceBrute ,NVRISQUE_ME.libelle as vraisemblanceME ,NVRISQUE_MC.libelle as vraisemblanceMC, " +
				"NVRISQUE_BRUT.idNVRISQUE as vraisemblanceBruteID ,NVRISQUE_ME.idNVRISQUE as vraisemblanceMEID ,NVRISQUE_MC.idNVRISQUE as vraisemblanceMCID, " +
				"ER.libelle as libelleER, ER.idER, " +
				"BS.idBS as idBS, BS.libelle as bs_libelle, " +
				"MESURE.idMESURE as idMESURE, MESURE.libelle as mesure_libelle, MESURE.etat, " +
				"CRITERE.idCRITERE, CRITERE.libelle as criteria_label, BE.idBE, BE.libelle as primaryAsset_libelle, " +
				"SM.libelle as libelleSM, SM.idSM " +
				"FROM MESURE " +
				"LEFT OUTER JOIN BE ON BE.idBE = ER.idBE " +   
				"LEFT OUTER JOIN CRITERE ON CRITERE.idCRITERE = ER.idCRITERE " +
				"LEFT OUTER JOIN PORTER ON PORTER.idMESURE = MESURE.idMESURE " +
				"LEFT OUTER JOIN BS ON BS.idBS = PORTER.idBS " +
				"LEFT OUTER JOIN CONTRIBUER ON CONTRIBUER.idMESURE = MESURE.idMESURE "	+					 
				"LEFT OUTER JOIN RISQUE ON CONTRIBUER.idRISQUE = RISQUE.idRISQUE " +
				"LEFT OUTER JOIN NGRISQUE as NGRISQUE_BRUT ON NGRISQUE_BRUT.idNGRISQUE= RISQUE.graviteBrute " +
				"LEFT OUTER JOIN NGRISQUE as NGRISQUE_ME ON NGRISQUE_ME.idNGRISQUE= RISQUE.graviteME " +
				"LEFT OUTER JOIN NGRISQUE as NGRISQUE_MC ON NGRISQUE_MC.idNGRISQUE= RISQUE.graviteMC " +
				"LEFT OUTER JOIN NVRISQUE as NVRISQUE_BRUT ON NVRISQUE_BRUT.idNVRISQUE= RISQUE.vraisemblanceBrute " +
				"LEFT OUTER JOIN NVRISQUE as NVRISQUE_ME ON NVRISQUE_ME.idNVRISQUE= RISQUE.vraisemblanceME " +
				"LEFT OUTER JOIN NVRISQUE as NVRISQUE_MC ON NVRISQUE_MC.idNVRISQUE= RISQUE.vraisemblanceMC " +
				"LEFT OUTER JOIN COMPOSER  ON COMPOSER.idRISQUE= RISQUE.idRISQUE " +
				"LEFT OUTER JOIN ER  ON RISQUE.idER = ER.idER " +
				"LEFT OUTER JOIN SM  ON COMPOSER.idSM = SM.idSM " +
				"ORDER BY libelleLong asc ";*/
			
			return  " SELECT RISQUE.idRISQUE, RISQUE.libelleCourt, RISQUE.libelleLong, " +
					" NGRISQUE_BRUT.libelle as graviteBrute ,ifnull(NGRISQUE_ME.libelle, '') as graviteME , ifnull(NGRISQUE_MC.libelle, '') as graviteMC, " +
					" NVRISQUE_BRUT.libelle as vraisemblanceBrute ,ifnull(NVRISQUE_ME.libelle, '') as vraisemblanceME ,ifnull(NVRISQUE_MC.libelle, '') as vraisemblanceMC, " +
					" ER.libelle as libelleER, " +
					" BS.libelle as bs_libelle, " +
					" BE.libelle as primaryAsset_libelle, " +       
					" SM.libelle as libelleSM, " +
					" ifnull(MESURE.libelle, '') as mesure_libelle, " +
					" CRITERE.libelle as criteria_label " +				
					" FROM RISQUE " +
					" LEFT OUTER JOIN NGRISQUE as NGRISQUE_BRUT ON NGRISQUE_BRUT.idNGRISQUE= RISQUE.graviteBrute " +
					" LEFT OUTER JOIN NGRISQUE as NGRISQUE_ME ON NGRISQUE_ME.idNGRISQUE= RISQUE.graviteME " +
					" LEFT OUTER JOIN NGRISQUE as NGRISQUE_MC ON NGRISQUE_MC.idNGRISQUE= RISQUE.graviteMC " +
					" LEFT OUTER JOIN NVRISQUE as NVRISQUE_BRUT ON NVRISQUE_BRUT.idNVRISQUE= RISQUE.vraisemblanceBrute " +
					" LEFT OUTER JOIN NVRISQUE as NVRISQUE_ME ON NVRISQUE_ME.idNVRISQUE= RISQUE.vraisemblanceME " +
					" LEFT OUTER JOIN NVRISQUE as NVRISQUE_MC ON NVRISQUE_MC.idNVRISQUE= RISQUE.vraisemblanceMC " +
					" LEFT OUTER JOIN ER ON RISQUE.idER = ER.idER " +
					" LEFT OUTER JOIN BE ON BE.idBE = ER.idBE " +
					" LEFT OUTER JOIN CRITERE ON CRITERE.idCRITERE = ER.idCRITERE " +
					" LEFT OUTER JOIN COMPOSER ON COMPOSER.idRISQUE = RISQUE.idRISQUE " +   
					" LEFT OUTER JOIN SM ON SM.idSM = COMPOSER.idSM " +      
					" LEFT OUTER JOIN BS ON BS.idBS = SM.idBS " +       
					" LEFT OUTER JOIN PORTER ON PORTER.idBS = BS.idBS " +        
					" LEFT OUTER JOIN MESURE ON MESURE.idMESURE = PORTER.idMESURE " +
					" ORDER BY libelleLong asc ";
		}


		public function buildResidualRiskExportQuery():String
		{
			return " SELECT RISQUE.idRISQUE, RISQUE.libelleCourt, RISQUE.libelleLong, RISQUE.risqueResiduel, " +
				" ER.libelle as libelleER, " +
				" SM.libelle as libelleSM, " +
				" ifnull(MESURE.libelle, '') as mesure_libelle " +
				" FROM RISQUE " +
				" LEFT OUTER JOIN ER  ON RISQUE.idER = ER.idER " +
				" LEFT OUTER JOIN COMPOSER ON COMPOSER.idRISQUE = RISQUE.idRISQUE " +   
				" LEFT OUTER JOIN SM ON SM.idSM = COMPOSER.idSM " + 
				" LEFT OUTER JOIN BS ON BS.idBS = SM.idBS " +       
				" LEFT OUTER JOIN PORTER ON PORTER.idBS = BS.idBS " +        
				" LEFT OUTER JOIN MESURE ON MESURE.idMESURE = PORTER.idMESURE " +
				" WHERE risqueResiduel != '' ";
		}
		
		public function builResidualRiskForDelivrable():String{
			return " SELECT RISQUE.idRISQUE, RISQUE.libelleCourt, RISQUE.libelleLong, RISQUE.risqueResiduel as residualRisk,  " +
				" ER.libelle as libelleER, " +
				" SM.libelle as libelleSM, " +
				" ifnull(MESURE.libelle, '') as mesure_libelle " +
				" FROM RISQUE " +
				" LEFT OUTER JOIN ER  ON RISQUE.idER = ER.idER " +
				" LEFT OUTER JOIN COMPOSER ON COMPOSER.idRISQUE = RISQUE.idRISQUE " +   
				" LEFT OUTER JOIN SM ON SM.idSM = COMPOSER.idSM " + 
				" LEFT OUTER JOIN BS ON BS.idBS = SM.idBS " +       
				" LEFT OUTER JOIN PORTER ON PORTER.idBS = BS.idBS " +        
				" LEFT OUTER JOIN MESURE ON MESURE.idMESURE = PORTER.idMESURE " +
				" WHERE risqueResiduel != '' " +
				" ORDER BY residualRisk asc ";
		}
		
	}		
}