package com.anssi.ebios.services
{
	import com.anssi.ebios.model.SecurityCriteria;
	import com.anssi.ebios.model.SecurityCriteriaLight;
	import com.anssi.ebios.model.SecurityNeed;
	import com.anssi.ebios.utils.CompareCollectionUtil;
	import com.anssi.ebios.utils.Resources;
	
	import flash.data.SQLMode;
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLErrorEvent;
	import flash.events.SQLEvent;
	import flash.filesystem.File;
	
	import mx.collections.ArrayCollection;
	import mx.collections.ArrayList;
	import mx.controls.List;
	import mx.rpc.IResponder;

	public class SecurityCriteriaService extends AppServices
	{
		
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement;
		private var _securityCriteria:SecurityCriteria;
		private var _currentIndex:Number=-1;
		private var _primaryKey:Number;
		private var _securityNeedListToDelete:ArrayCollection;
		
		public function SecurityCriteriaService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		/*******************************************************/
		/** Récupération de la liste des critères de sécurité **/
		/*******************************************************/
		
		public function constructSecurityCriteriaQuery(WHERECondition:String = ""):String
		{
			return "SELECT C.idCRITERE, C.libelle as c_libelle, C.definition, NC.idNCRITERE, NC.libelle as nc_libelle, NC.ordre, NC.description, NC.ordre "  +
				" FROM CRITERE C LEFT OUTER JOIN NCRITERE NC " +
				" ON C.idCRITERE = NC.idCRITERE " +
				" "+WHERECondition +
				"ORDER BY C.libelle, NC.ordre ";
		}
		
		public function getSecurityCriteria():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
		
			var query:String;
				query = constructSecurityCriteriaQuery("");
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getSecurityCriteriaResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		
		private function getSecurityCriteriaResult(event:SQLEvent):void{
			var securityCriteriaList:ArrayCollection = new ArrayCollection();
			// récupération des résultats
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			// si nous avons des résultats
			if (result != null && result.data != null){
				securityCriteriaList = formatSecurityCriteriaResult(result);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(securityCriteriaList);
		}
		
		public function formatSecurityCriteriaResult(result:SQLResult):ArrayCollection{

			var list:ArrayCollection = new ArrayCollection();
			// variables temporaires
			var tmpSC:SecurityCriteria = null;
			var tmpSN:SecurityNeed = null;
			var iDSC:int = -1;
			var numIdSC:int = -1;
			
			var row:Object;
			var numRows:int = result.data.length;			
			
			for (var i:int = 0; i < numRows; i++)
			{
				row = result.data[i];
				// on remet bien à NULL l'objet associé pour éviter de prendre l'objet du tour de boucle précédent
				tmpSN = null;
				if(null != row["idNCRITERE"]){
					tmpSN = new SecurityNeed();
					tmpSN.id = row["idNCRITERE"];
					tmpSN.label = row["nc_libelle"];
					tmpSN.ordre = row["ordre"];
				}
				
				//si l'ID du critere est différent de celui de la ligne précédente, on créé un nouveau critère
				if (iDSC != row["idCRITERE"]){
					iDSC =	row["idCRITERE"];
					numIdSC++;
					tmpSC = new SecurityCriteria();					  
					tmpSC.id = row["idCRITERE"];
					tmpSC.libelle = row["c_libelle"];
					tmpSC.securityNeed.addItem(tmpSN);
					list.addItem(tmpSC);
					/* Sinon, on ajoute seulement le niveau dans la liste des niveaux du critère précédemment créé
					et on met à jour la liste des criteres avec les niveaux ajoutés */
				}else{
					tmpSC.securityNeed.addItem(tmpSN);
					list.setItemAt(tmpSC,numIdSC);
				}
			}
			return list;
		}
		
			
		/******************************************************/
		/** Récupération d'un critère de sécurité via son ID **/
		/******************************************************/
		public function getSecurityCriteriaById(id:Number):void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "SELECT C.idCRITERE, C.libelle as c_libelle, C.definition, NC.idNCRITERE, NC.libelle as nc_libelle, NC.ordre, NC.description"  +
				" FROM CRITERE C LEFT OUTER JOIN NCRITERE NC " +
				" ON C.idCRITERE = NC.idCRITERE " + 
				" WHERE C.idCRITERE = :idCRITERE" +
				" ORDER BY NC.ordre";			
			
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idCRITERE"] = id;			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getSecurityCriteriaByIdResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function getSecurityCriteriaByIdResult(event:SQLEvent):void{
			// récupération des résultats
			var result:SQLResult = SQLStatement(event.target).getResult();
			var tmpSN:SecurityNeed = null;
			
			// si nous avons des résultats
			if (result != null && result.data != null)
			{		
				var row:Object;
				var row0:Object;
				var numRows:int = result.data.length;
				var securityCriteria:SecurityCriteria = new SecurityCriteria();
				
				// On récupère le libelle et la description de la premiere ligne pour le critère de sécurité
				// Toutes ces infos sont identiques pour chaque ligne (on ramène les niveaux d'un critère)
				row0 = result.data[0];
				securityCriteria.id = row0["idCRITERE"];
				securityCriteria.libelle = row0["c_libelle"];
				securityCriteria.definition = row0["definition"];
				
				//On récupère lesniveaux du critère
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					
					// on remet bien à NULL l'objet associé pour éviter de prendre l'objet du tour de boucle précédent
					tmpSN = null;
					if(null != row["idNCRITERE"]){
						tmpSN = new SecurityNeed();
						tmpSN.id = row["idNCRITERE"];
						tmpSN.label = row["nc_libelle"];
						tmpSN.ordre = row["ordre"];
						tmpSN.description = row["description"];
						securityCriteria.securityNeed.addItem(tmpSN);
					}
				}
			
			_sqlStatement.sqlConnection.close();
			responder.result(securityCriteria);
			}
		}
		
		
		/******************************************/
		/** Suppression d'un critère de sécurité **/
		/******************************************/		
		// suppression en cascade d'un CRITERE de sécurité
		public function deleteSecurityCriteria(securityCriteria:SecurityCriteria):void{
			
			var idSMList:String= "";
			var idERList:String= "";
			var idRiskList:String = "";
			var query:String ="";
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			openInSyncMode(_sqlStatement);
			// a. récupération de la liste idERList de idER dans ER de tous ceux qui ont idCRITERE = :idCRITERE 
			query="SELECT idER as id FROM ER WHERE idCRITERE = :idCRITERE ";
			_sqlStatement.text=query;
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idCRITERE"] = securityCriteria.id;
			execStatement(_sqlStatement);
			idERList=constructStringResultId(_sqlStatement.getResult());
			
			// b. récuperation de la liste idSMList de idSM de SM dont idCRITERE = :idCRITERE dans SM
			query="SELECT idSM as id FROM SM WHERE idCRITERE = :idCRITERE ";
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			idSMList=constructStringResultId(_sqlStatement.getResult());
			
			
			//c. récupération de la liste idRiskList de idRISQUE de RISQUE dont idRisque est dans idERList
			query="SELECT idRISQUE as id " +
				" FROM RISQUE WHERE idER IN ("+ idERList +");";
			_sqlStatement.clearParameters();
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			idRiskList=constructStringResultId(_sqlStatement.getResult());
			
			// d. On supprime dans COMPOSER tous ceux qui ont idRISQUE dans idRiskList,
			query = "DELETE FROM COMPOSER WHERE idRISQUE IN ("+ idRiskList +");";
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			// e. on supprime dans COMPOSER tous ceux qui ont idSM dans idSMList,
			query = "DELETE FROM COMPOSER WHERE idSM IN ("+ idSMList +");";
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			
			//e'. on supprime dans POUVOIR tous ceux qui ont idSM dans idSMList
			query = "DELETE FROM POUVOIR WHERE idSM IN ("+ idSMList +");";
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			
			// f. suppression dans CONTRIBUER de tous ceux qui ont idRISQUE dans idRiskList
			query = "DELETE FROM CONTRIBUER WHERE idRISQUE IN ("+ idRiskList +");";
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			
			// g. On supprime dans RISQUE tous ceux qui ont idRISQUE dans idRiskList
			query = "DELETE FROM RISQUE WHERE idRISQUE IN ("+ idRiskList +");";
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			
			// h. suppression des ER ayant cet idCRITERE
			query = "DELETE FROM ER WHERE idCRITERE = :idCRITERE";	
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idCRITERE"] = securityCriteria.id;
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			
			// i. suppression des SM ayant cet idCRITERE
			query = "DELETE FROM SM WHERE idCRITERE = :idCRITERE";	
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			
			// j. suppression dans AFFECTER  tous ceux qui ont idCRITERE = id,
			query = "DELETE FROM AFFECTER WHERE idCRITERE = :idCRITERE";
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			
			// k. suppression dans INITIER tous ceux qui ont idCRITERE  = id,
			query="DELETE FROM INITIER WHERE idCRITERE = :idCRITERE";
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			
			// l. suppression dans ENGENDRER tous ceux qui ont idCRITERE  = id,
			query="DELETE FROM ENGENDRER WHERE idCRITERE = :idCRITERE";
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			
			// m. suppression des NCritere avec cet id
			query = "DELETE FROM NCRITERE WHERE idCRITERE = :idCRITERE";			
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			
			// n. suppression du critere ayant cet idCRITERE
			query = "DELETE FROM CRITERE " +
				" WHERE idCRITERE= :idCRITERE";
			
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			
			/*
			_sqlStatement.text = query;
			
			_sqlStatement.addEventListener(SQLEvent.RESULT,deleteSecurityCriteriaResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
			*/
			_sqlStatement.sqlConnection.close();
			responder.result(null);
		}
		
		private function constructStringResultId(result:SQLResult):String{
			var resultList:Array = result.data;
			var strResult:String="";
			
			if (resultList != null){
				if(resultList.length != 0){
					for(var i:int=0; i < resultList.length; i++){
						if(i < resultList.length-1){
							strResult +=resultList[i].id +", ";
						}else{
							strResult +=resultList[i].id;
						}
					}
				}
			}
			return strResult;
		}
		
		private function deleteSecurityCriteriaResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			_sqlStatement.sqlConnection.close();
			responder.result(null);
		}
		
		
		/***************************************/
		/** Création d'un critère de sécurité **/
		/***************************************/
		public function createSecurityCriteria(securityCriteria:SecurityCriteria):void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "INSERT INTO CRITERE (libelle, definition, dateCreation, dateModification) " +
				" VALUES (:libelle, :definition, :dateCreation, :dateModification)";
			
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":libelle"] = securityCriteria.libelle;
			_sqlStatement.parameters[":definition"] = securityCriteria.definition;
			_sqlStatement.parameters[":dateCreation"] = new Date();
			_sqlStatement.parameters[":dateModification"] = new Date();

			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,createSecurityCriteriaResult);
			
			_securityCriteria = new SecurityCriteria();
			_securityCriteria = securityCriteria;
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function createSecurityCriteriaResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null)
			{
				_primaryKey = result.lastInsertRowID;
			}
			
			_securityCriteria.id = String(_primaryKey);
			
			_sqlStatement.sqlConnection.close();
			
			//Appel de la fonction qui réalise la création des niveaux du critère de sécurité
			_currentIndex = -1;
			createSecurityNeed();
		}
		
		private function createSecurityNeed():void{
			
			_currentIndex++
				
				setBDDName();				
			_sqlStatement = new SQLStatement();				
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			
			if (_currentIndex < _securityCriteria.securityNeed.length){
				var securityNeed:SecurityNeed = _securityCriteria.securityNeed.getItemAt(_currentIndex) as SecurityNeed;
	
				var query:String = "INSERT INTO NCRITERE (libelle, description, ordre, idCRITERE, dateCreation, dateModification) " +
					" VALUES(:libelle, :description, :ordre, :idCRITERE, :dateCreation, :dateModification)";
				
				_sqlStatement.clearParameters();
				_sqlStatement.parameters[":libelle"] = securityNeed.label;
				_sqlStatement.parameters[":description"] = securityNeed.description;
				_sqlStatement.parameters[":ordre"] = securityNeed.ordre;
				_sqlStatement.parameters[":idCRITERE"] = _securityCriteria.id;
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();

				
				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,createSecurityNeedResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);	
			}else{
				//_sqlStatement.sqlConnection.close();
				//responder.result(_primaryKey);
				createER();
			}
		}
			
		private function createSecurityNeedResult(event:SQLEvent):void{
			createSecurityNeed();
		}
		
		
		private function createER():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "INSERT INTO ER (libelle, idCRITERE, idBE, dateCreation, dateModification) " +
				" SELECT (BE.libelle || \" - \" || \"" +  _securityCriteria.libelle + "\"), :idCRITERE,BE.idBE, date('now'), date('now') " +
				" FROM BE"
				
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idCRITERE"] = _securityCriteria.id;
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,createERResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function createERResult(event:SQLEvent):void{
			createSM();
		}
		
		private function createSM():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "INSERT INTO SM (libelle, idCRITERE, idBS, dateCreation, dateModification) " +
				" SELECT (BS.libelle || \" - \" || \"" +  _securityCriteria.libelle + "\"), :idCRITERE, BS.idBS, date('now'), date('now') " +
				" FROM BS"
			
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idCRITERE"] = _securityCriteria.id;
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,createSMResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function createSMResult(event:SQLEvent):void{
			_sqlStatement.sqlConnection.close();
			responder.result(_primaryKey);
		}
		
		/******************************************/
		/** Mise à jour d'un critère de sécurité **/
		/******************************************/
		public function updateSecurityCriteria(securityCriteria:SecurityCriteria):void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "UPDATE CRITERE SET libelle = :libelle, definition = :definition,  dateModification = :dateModification " +
				" WHERE idCRITERE= :idCRITERE";
			
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":libelle"] = securityCriteria.libelle;
			_sqlStatement.parameters[":definition"] =securityCriteria.definition;
			_sqlStatement.parameters[":idCRITERE"] = securityCriteria.id;
			_sqlStatement.parameters[":dateModification"] = new Date();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,updateSecurityCriteriaResult);
			
			_securityCriteria = securityCriteria;
			
			openAndExecStatementInAsyncMode(_sqlStatement);			
		}
		
		private function updateSecurityCriteriaResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			_primaryKey = SQLStatement(event.target).parameters[":idCRITERE"];
			
			_sqlStatement.sqlConnection.close();
			
			updateSecurityNeed();
			
		}
		
		private function updateSecurityNeed():void{
			var query:String="";
			
			setBDDName();
			_sqlStatement = new SQLStatement();				
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			_currentIndex++
			if (_securityCriteria.securityNeed != null){
				if (_currentIndex < _securityCriteria.securityNeed.length){
					var securityNeed:SecurityNeed = _securityCriteria.securityNeed.getItemAt(_currentIndex) as SecurityNeed;
	
					if (Number(securityNeed.id) <= 0){
						query = "INSERT INTO NCRITERE (libelle, description, ordre, idCRITERE, dateCreation, dateModification) " +
							" VALUES (:libelle, :description, :ordre, :idCRITERE, :dateCreation, :dateModification)";
	
						_sqlStatement.clearParameters();
						_sqlStatement.parameters[":libelle"] = securityNeed.label;
						_sqlStatement.parameters[":description"] = securityNeed.description;
						_sqlStatement.parameters[":ordre"] = securityNeed.ordre;
						_sqlStatement.parameters[":idCRITERE"] = _securityCriteria.id;
						_sqlStatement.parameters[":dateCreation"] = new Date();
						_sqlStatement.parameters[":dateModification"] = new Date();

					}else{
						query = "UPDATE NCRITERE SET libelle = :libelle, description = :description, ordre = :ordre,  dateModification = :dateModification " +
							" WHERE idNCRITERE = :idNCRITERE";
							
						_sqlStatement.clearParameters();
						_sqlStatement.parameters[":libelle"] = securityNeed.label;
						_sqlStatement.parameters[":description"] = securityNeed.description;
						_sqlStatement.parameters[":ordre"] = securityNeed.ordre;
						_sqlStatement.parameters[":idNCRITERE"] = securityNeed.id;
						_sqlStatement.parameters[":dateModification"] = new Date();
					}
					
					_sqlStatement.text = query;
					_sqlStatement.addEventListener(SQLEvent.RESULT,updateSecurityNeedResult);
					
					openAndExecStatementInAsyncMode(_sqlStatement);	
				}else{
					_sqlStatement.sqlConnection.close();
					responder.result(_primaryKey);
				}
			}
		}
		
		private function updateSecurityNeedResult(event:SQLEvent):void{
			updateSecurityNeed();
		}

		
		/*************************************************************/
		/** Récupération de la liste des critères de sécurité light **/
		/*************************************************************/
		
		public function getSecurityCriteriaLight():void
		{
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String;
				query = constructSecurityCriteriaQuery("");
			
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getSecurityCriteriaLightResult);
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getSecurityCriteriaLightResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var securityCriteriaLightList:ArrayCollection = new ArrayCollection();
			if (result!=null && result.data!=null){
				securityCriteriaLightList = constructSecurityCriteriaLightList(result);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(securityCriteriaLightList);
		}
		
		public function constructSecurityCriteriaLightList(result:SQLResult):ArrayCollection{
			
			
			var securityCriteriaLightList:ArrayCollection = new ArrayCollection();
			
			if (result.data){
			
				var row:Object;
				var numRows:int = result.data.length;
				var securityCriteriaLight:SecurityCriteriaLight;
				
				for( var i:int=0; i< numRows;i++)
				{
					row=result.data[i];
					
					if(row["idCRITERE"]>0){
						
						securityCriteriaLight= new SecurityCriteriaLight();
						securityCriteriaLight.libelle=row["c_libelle"];
						securityCriteriaLight.definition=row["definition"];
						securityCriteriaLight.level=row["nc_libelle"];
						
						securityCriteriaLightList.addItem(securityCriteriaLight);
						
					}
				}
			}
			
			return securityCriteriaLightList;
			
		}
		
		public function constructSecurityCriteriaForDelivrable(result:SQLResult):ArrayCollection{
			
			var securityCriteriaList:ArrayCollection = new ArrayCollection();
			
			if (result != null && result.data != null ){
				
				var row:Object;
				var numRows:int = result.data.length;
				var securityCriteriaLight:SecurityCriteriaLight;
				var utilSecurityCriteria:Number;
				
				for( var i:int=0; i< numRows;i++)
				{
					row=result.data[i];
					
					if(utilSecurityCriteria != row["idCRITERE"]){
						
						utilSecurityCriteria = row["idCRITERE"];
						securityCriteriaLight= new SecurityCriteriaLight();
						securityCriteriaLight.libelle=row["c_libelle"];
						securityCriteriaLight.definition=row["definition"];
						securityCriteriaLight.level = new String();
						securityCriteriaList.addItem(securityCriteriaLight);
						
					}
					
					
					securityCriteriaLight.level += "- " + row["nc_libelle"] + "\t";
				}
			}
			
			return securityCriteriaList;
			
		}
	}
}