package com.anssi.ebios.services
{
	import com.anssi.ebios.model.DefenceLine;
	import com.anssi.ebios.model.Indicator;
	import com.anssi.ebios.model.IndicatorLevel;
	import com.anssi.ebios.model.People;
	import com.anssi.ebios.model.Risk;
	import com.anssi.ebios.model.SecurityMeasure;
	import com.anssi.ebios.model.SecurityMeasureType;
	import com.anssi.ebios.model.SupportingAsset;
	import com.logica.fwk.utils.ArrayCollectionTool;
	
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLEvent;
	
	import mx.collections.ArrayCollection;
	import mx.rpc.IResponder;
	
	import org.springextensions.actionscript.ioc.factory.xml.parser.support.nodeparsers.NullNodeParser;

	public class SecurityMeasureService extends AppServices
	{
		
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement;
		private var _securityMeasure:SecurityMeasure;
		private var _primaryKey:Number;
		private var _currentIndex:Number = -1;
		private var _index:Number = -1;
		
		private var _complementaryLisl:ArrayCollection;
		private var _importSecurityMeasureList:ArrayCollection;
		private var _state:String = new String();
		
		public function SecurityMeasureService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		/*****************************************************************************/
		/** Récupération de la liste des mesures de sécurité correspondants à Etude **/
		/*****************************************************************************/
		public function getSecurityMeasureList():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = constructSecurityMesureQuery('AND  TMESURES.idREFERENTIEL = 1 ');
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT, getSecurityMeasureListResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
			
		private function getSecurityMeasureListResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var securityMeasureList:ArrayCollection = new ArrayCollection();
			if (result != null && result.data != null)
			{
				securityMeasureList =  constructSecurityMesureList(result);				
			}
			_sqlStatement.sqlConnection.close();
			responder.result(securityMeasureList);
		}
		
		/********************************************************************/
		/** Récupération de la liste des mesures de sécurité avec l'état E **/
		/********************************************************************/
		public function getSecurityMeasureListStateE():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = constructSecurityMesureQuery('AND  TMESURES.idREFERENTIEL = 1 AND MESURE.etat = "E" ');
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT, getSecurityMeasureStateEListResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function getSecurityMeasureStateEListResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var securityMeasureList:ArrayCollection = new ArrayCollection();
			if (result != null && result.data != null)
			{
				securityMeasureList =  constructSecurityMesureList(result);				
			}
			_sqlStatement.sqlConnection.close();
			responder.result(securityMeasureList);
		}
		
		/******************************************************/
		/** Récupération de la liste des mesures de sécurité **/
		/******************************************************/
		public function getSecurityMeasureRefList():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = constructSecurityMesureQuery('AND  TMESURES.idREFERENTIEL != 1 ');
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT, getSecurityMeasureRefListResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function getSecurityMeasureRefListResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var securityMeasureList:ArrayCollection = new ArrayCollection();
			if (result != null && result.data != null)
			{
				securityMeasureList =  constructSecurityMesureList(result);				
			}
			_sqlStatement.sqlConnection.close();
			responder.result(securityMeasureList);
		}
		
		
		/*****************************************************/
		/** Récupération d'un mesure de sécurité via son ID **/
		/*****************************************************/
		public function getSecurityMeasureById(id:Number):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = constructSecurityMesureQuery('AND MESURE.idMESURE = '+id );
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT, getSecurityMeasureByIdResult);
			openAndExecStatementInAsyncMode(_sqlStatement);		
			
		}
		
		private function getSecurityMeasureByIdResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var securityMeasure:SecurityMeasure = new SecurityMeasure();
			if (result != null && result.data != null)
			{
				securityMeasure =  constructSecurityMesureList(result)[0];				
			}
			_sqlStatement.sqlConnection.close();
			responder.result(securityMeasure);
		}
		
		
		/***************************************/
		/** Création d'une mesure de sécurité **/
		/***************************************/
		/** 1) Insertion dans la table MESURE
		 *  2) Insertion dans la table DEFENDRE pour chaque lignes de défense
		 *  3) Insertion dans la table PORTER pour chaque BS*/
		public function createSecurityMeasure(securityMeasure:SecurityMeasure):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_securityMeasure = new SecurityMeasure();
			_securityMeasure = securityMeasure;
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "INSERT INTO MESURE (libelle, etat, idTMESURES, dateCreation, dateModification) " +
				" VALUES (:libelle, :etat, :idTMESURES, :dateCreation, :dateModification)";
			
			_sqlStatement.parameters[":libelle"] = _securityMeasure.label;
			_sqlStatement.parameters[":etat"] = _securityMeasure.state;
			_sqlStatement.parameters[":idTMESURES"] = _securityMeasure.securityMeasureType.id;
			_sqlStatement.parameters[":dateCreation"] = new Date();
			_sqlStatement.parameters[":dateModification"] = new Date();

			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,createSecurityMeasureResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function createSecurityMeasureResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null)
			{
				_securityMeasure.id = String(result.lastInsertRowID);
			}
			_currentIndex = -1;
			affectDefenceLine();
		}
		
		private function affectDefenceLine():void{
			_currentIndex++;
				
			if (_currentIndex < _securityMeasure.defenceLineList.length){
				
				var defenceLine:DefenceLine = _securityMeasure.defenceLineList.getItemAt(_currentIndex) as DefenceLine;
				setBDDName();
				_sqlStatement = new SQLStatement();
				
				_sqlStatement.sqlConnection = this.sqlConnection;
				var query:String = "INSERT INTO DEFENDRE (idMESURE, idLIGNE, dateCreation, dateModification) " +
					" VALUES (:idMESURE, :idLIGNE, :dateCreation, :dateModification)";
				
				_sqlStatement.parameters[":idMESURE"] = _securityMeasure.id;
				_sqlStatement.parameters[":idLIGNE"] = defenceLine.id;
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();

				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,affectDefenceLineResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);
			}else{
				_currentIndex = -1;
				affectSupportingAsset();
			}
		}
		
		private function affectDefenceLineResult(event:SQLEvent):void{
			affectDefenceLine();
		}
		
		private function affectSupportingAsset():void{
			_currentIndex++;
			
			if (_currentIndex < _securityMeasure.supportingAssetList.length){
				
				var supportingAsset:SupportingAsset = _securityMeasure.supportingAssetList.getItemAt(_currentIndex) as SupportingAsset;
				setBDDName();
				_sqlStatement = new SQLStatement();
				
				_sqlStatement.sqlConnection = this.sqlConnection;
				var query:String = "INSERT INTO PORTER (idMESURE, idBS, dateCreation, dateModification) " +
					" VALUES (:idMESURE, :idBS, :dateCreation, :dateModification)";
				
				_sqlStatement.parameters[":idMESURE"] = _securityMeasure.id;
				_sqlStatement.parameters[":idBS"] = supportingAsset.id;
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();
				
				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,affectSupportingAssetResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);
			}else{
				_sqlStatement.sqlConnection.close();
				responder.result(_securityMeasure.id);
			}
		}
		
		
		private function affectSupportingAssetResult(event:SQLEvent):void{
			affectSupportingAsset();
		}			
		
		/******************************************************/
		/** Création d'une mesure de sécurité complementaire **/
		/******************************************************/
		
		public function createComplementarySecurityMeasure(securityMeasureList:ArrayCollection):void{
			
			_complementaryLisl = securityMeasureList;
			_index++;
			
			if (_index < _complementaryLisl.length){
				
				var sm:SecurityMeasure = _complementaryLisl.getItemAt(_index) as SecurityMeasure;
			
				setBDDName();
				_sqlStatement = new SQLStatement();
			
				_sqlStatement.sqlConnection = this.sqlConnection;
				var query:String = "INSERT INTO MESURE (libelle, etat, idTMESURES, dateCreation, dateModification) " +
					" VALUES (:libelle, :etat, :idTMESURES, :dateCreation, :dateModification)";
			
				_sqlStatement.parameters[":libelle"] = sm.label;
				_sqlStatement.parameters[":etat"] = "C";
				_sqlStatement.parameters[":idTMESURES"] = "2";
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();
				
				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,createComplementarySecurityMeasureResult);
			
				openAndExecStatementInAsyncMode(_sqlStatement);
			}else{
				_sqlStatement.sqlConnection.close();
				responder.result(null);
			}
		}
		
		private function createComplementarySecurityMeasureResult(event:SQLEvent):void{
			createComplementarySecurityMeasure(_complementaryLisl);
		}
		
		/******************************************************************/
		/** Création d'une mesure IMPORT ( Complémentaire et existante ) **/
		/******************************************************************/
		
		public function createImportSecurityMeasure(securityMeasureList:ArrayCollection, state:String):void{
			
			_importSecurityMeasureList = securityMeasureList;
			_state = state;
			_index++;
			
			if (_index < _importSecurityMeasureList.length){
				
				var sm:SecurityMeasure = _importSecurityMeasureList.getItemAt(_index) as SecurityMeasure;
				
				setBDDName();
				_sqlStatement = new SQLStatement();
				
				_sqlStatement.sqlConnection = this.sqlConnection;
				var query:String = "INSERT INTO MESURE (libelle, etat, idTMESURES, dateCreation, dateModification) " +
					" VALUES (:libelle, :etat, :idTMESURES, :dateCreation, :dateModification)";
				
				_sqlStatement.parameters[":libelle"] = sm.label;
				_sqlStatement.parameters[":etat"] = state;
				_sqlStatement.parameters[":idTMESURES"] = "2";
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();
				
				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,createImportSecurityMeasureResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);
			}else{
				_sqlStatement.sqlConnection.close();
				responder.result(null);
			}
		}
		
		private function createImportSecurityMeasureResult(event:SQLEvent):void{
			createImportSecurityMeasure(_importSecurityMeasureList,_state);
		}
		
		
		/******************************************/
		/** Suppression d'une mesure de sécurité **/
		/******************************************/
		/** 1)Suppression de la table MESURE
		 *  2)Suppression de la table DEFENDRE 
		 *  3)Suppression de la table PORTER */
		
		public function deleteSecurityMeasure(securityMeasure:SecurityMeasure):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_securityMeasure = new SecurityMeasure();
			_securityMeasure = securityMeasure;
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM MESURE WHERE idMESURE = :idMESURE";
			
			_sqlStatement.parameters[":idMESURE"] = _securityMeasure.id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,deleteSecurityMeasureResult);
						
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function deleteSecurityMeasureResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null){
				unaffectDefenceLine();
			}
		}
		
		private function unaffectDefenceLine():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM DEFENDRE WHERE idMESURE = :idMESURE";
			
			_sqlStatement.parameters[":idMESURE"] = _securityMeasure.id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,unaffectDefenceLineResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function unaffectDefenceLineResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null){
				unaffectSupportingAsset();
			}
		}
		
		private function unaffectSupportingAsset():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM PORTER WHERE idMESURE = :idMESURE";
			
			_sqlStatement.parameters[":idMESURE"] = _securityMeasure.id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,unaffectSupportingAssetResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function unaffectSupportingAssetResult(event:SQLEvent):void{
			_sqlStatement.sqlConnection.close();
			responder.result(null);
		}
		
		/******************************************/
		/** Mise à jour d'une mesure de sécurité **/
		/******************************************/
		/** 1) Mise à jour de la table MESURE
		 *  2) Suppression de la table DEFENDRE (on désaffecte les lignes de défense concernant la mesure)
		 *  3) Insertion dans la table DEFENDRE (on affecte les lignes de défenses sélectionnées dans l'IHM) 
		 *  4) Suppression de la table PORTER (on désaffecte les BS concernant la mesure)
		 *  5) Insertion dans la table PORTER (on affecte les BS sélectionnés dans l'IHM) */
		public function updateSecurityMeasure(securityMeasure:SecurityMeasure):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_securityMeasure = new SecurityMeasure();
			_securityMeasure = securityMeasure;
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "UPDATE MESURE set libelle = :libelle, etat = :etat, idTMESURES = :idTMESURES, dateModification = :dateModification " +
				" WHERE idMESURE = :idMESURE ";
			
			_sqlStatement.parameters[":idMESURE"] = _securityMeasure.id;
			_sqlStatement.parameters[":libelle"] = _securityMeasure.label;
			_sqlStatement.parameters[":etat"] = _securityMeasure.state;
			_sqlStatement.parameters[":idTMESURES"] = _securityMeasure.securityMeasureType.id;
			_sqlStatement.parameters[":dateModification"] = new Date();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,updateSecurityMeasureResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function updateSecurityMeasureResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null){
				_primaryKey = SQLStatement(event.target).parameters[":idMESURE"];
				unaffectDefenceLineOnUpdate();
			}			
		}
		
		private function unaffectDefenceLineOnUpdate():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM DEFENDRE WHERE idMESURE = :idMESURE";
			
			_sqlStatement.parameters[":idMESURE"] = _securityMeasure.id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,unaffectDefenceLineOnUpdateResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function unaffectDefenceLineOnUpdateResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null){
				_currentIndex = -1; 
				affectDefenceLineOnUpdate();
			}
		}
		
		private function affectDefenceLineOnUpdate():void{
			_currentIndex++;
			
			if (_currentIndex < _securityMeasure.defenceLineList.length){
				
				var defenceLine:DefenceLine = _securityMeasure.defenceLineList.getItemAt(_currentIndex) as DefenceLine;
				setBDDName();
				_sqlStatement = new SQLStatement();
				
				_sqlStatement.sqlConnection = this.sqlConnection;
				var query:String = "INSERT INTO DEFENDRE (idMESURE, idLIGNE, dateCreation, dateModification) " +
					" VALUES (:idMESURE, :idLIGNE, :dateCreation, :dateModification)";
				
				_sqlStatement.parameters[":idMESURE"] = _securityMeasure.id;
				_sqlStatement.parameters[":idLIGNE"] = defenceLine.id;
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();

				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,affectDefenceLineOnUpdateResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);
			}else{
				unaffectSupportingAssetOnUpdate();
			}
		}
		
		private function affectDefenceLineOnUpdateResult(event:SQLEvent):void{
			affectDefenceLineOnUpdate();
		}
		
		private function unaffectSupportingAssetOnUpdate():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM PORTER WHERE idMESURE = :idMESURE";
			
			_sqlStatement.parameters[":idMESURE"] = _securityMeasure.id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,unaffectSupportingAssetOnUpdateResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function unaffectSupportingAssetOnUpdateResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null){
				_currentIndex = -1; 
				affectSupportingAssetOnUpdate();
			}
		}
		
		private function affectSupportingAssetOnUpdate():void{
			_currentIndex++;
			
			if (_currentIndex < _securityMeasure.supportingAssetList.length){
				
				var supportingAsset:SupportingAsset = _securityMeasure.supportingAssetList.getItemAt(_currentIndex) as SupportingAsset;
				setBDDName();
				_sqlStatement = new SQLStatement();
				
				_sqlStatement.sqlConnection = this.sqlConnection;
				var query:String = "INSERT INTO PORTER (idMESURE, idBS, dateCreation, dateModification) " +
					" VALUES (:idMESURE, :idBS, :dateCreation, :dateModification)";
				
				_sqlStatement.parameters[":idMESURE"] = _securityMeasure.id;
				_sqlStatement.parameters[":idBS"] = supportingAsset.id;
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();

				
				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,affectSupportingAssetOnUpdateResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);
			}else{
				_sqlStatement.sqlConnection.close();
				responder.result(_primaryKey);
			}
		}
		
		
		private function affectSupportingAssetOnUpdateResult(event:SQLEvent):void{
			affectSupportingAssetOnUpdate();
		}			
		
		
		
		
		public function constructSecurityMesureQuery(WHERECondition:String = " "):String{
			return "SELECT MESURE.idMESURE as idMESURE, MESURE.libelle as mesure_libelle, MESURE.etat, "
				+ " TMESURES.idTMESURES as idTMESURES, TMESURES.libelle as tmesures_libelle, "      
				+ " BS.idBS as idBS, BS.libelle as bs_libelle, "       
				+ " LIGNE.idLIGNE as idLIGNE, LIGNE.libelle as ligne_libelle "      
			+ " FROM MESURE, TMESURES "
			+ " LEFT OUTER JOIN PORTER ON PORTER.idMESURE = MESURE.idMESURE "
			+ " LEFT OUTER JOIN BS ON BS.idBS = PORTER.idBS "
			+ " LEFT OUTER JOIN DEFENDRE ON DEFENDRE.idMESURE = MESURE.idMESURE "
			+ " LEFT OUTER JOIN LIGNE ON LIGNE.idLIGNE = DEFENDRE.idLIGNE "
			+ " WHERE TMESURES.idTMESURES = MESURE.idTMESURES "
			+ " " + WHERECondition
			+ " ORDER BY MESURE.idMESURE, BS.idBS, LIGNE.idLIGNE ";
			
		}
		
		
		public function constructSecurityMesureList(result:SQLResult):ArrayCollection{
			var row:Object;
			var numRows:int = result.data.length;
			
			var securityMeasureList:ArrayCollection = new ArrayCollection();
			var securityMeasure:SecurityMeasure;
			
			var tmpIdMesure:Number;
			var tmpIdLigne:Number;
			var tmpIdBS:Number;
			
			for (var i:int = 0; i < numRows; i++)
			{
				row = result.data[i];
				
				if (tmpIdMesure != row["idMESURE"]){
					
					tmpIdMesure = row["idMESURE"];
					
					securityMeasure = new SecurityMeasure();
					securityMeasure.id = row["idMESURE"];
					securityMeasure.label = row["mesure_libelle"];
					securityMeasure.state = row["etat"];
					
					var securityMeasureType:SecurityMeasureType = new SecurityMeasureType();
					securityMeasureType.id = row["idTMESURES"];
					securityMeasureType.label = row["tmesures_libelle"];
					securityMeasure.securityMeasureType = securityMeasureType;
					
					securityMeasure.defenceLineList = new ArrayCollection();
					securityMeasure.supportingAssetList = new ArrayCollection();
					
					securityMeasureList.addItem(securityMeasure);
					
					tmpIdBS = -1;
					tmpIdLigne = -1;
				}
				
				if (tmpIdBS != row["idBS"] && ArrayCollectionTool.findIndexForId(securityMeasure.supportingAssetList, row["idBS"])==-1 && row["idBS"]>0){
					
					tmpIdBS = row["idBS"];
					
					var supportingAsset:SupportingAsset = new SupportingAsset();
					supportingAsset.id = row["idBS"];
					supportingAsset.label = row["bs_libelle"];
					securityMeasure.supportingAssetList.addItem(supportingAsset);
				}
				
				if (tmpIdLigne != row["idLIGNE"] && ArrayCollectionTool.findIndexForId(securityMeasure.defenceLineList, row["idLIGNE"])==-1 && row["idLIGNE"]>0){
					
					tmpIdLigne = row["idLIGNE"];
					
					var defenceLine:DefenceLine =new DefenceLine();
					defenceLine.id = row["idLIGNE"];
					defenceLine.label = row["ligne_libelle"];
					securityMeasure.defenceLineList.addItem(defenceLine);
				}
			}
			return securityMeasureList;
		}	
		
		/*************************************************************************/
		/** Tableau de croisement entre les mesures de sécurité et les risques  **/
		/*************************************************************************/
		public function buildSecurityMeasureByRiskQuery():String
		{
			/*return " SELECT MESURE.idMESURE as idMESURE, MESURE.libelle as mesure_libelle, MESURE.etat, "
				+ " RISQUE.idRISQUE, RISQUE.libelleCourt, RISQUE.libelleLong "							 
				+ " FROM MESURE "
				+ " LEFT OUTER JOIN CONTRIBUER ON CONTRIBUER.idMESURE = MESURE.idMESURE "						 
				+ " LEFT OUTER JOIN RISQUE ON CONTRIBUER.idRISQUE = RISQUE.idRISQUE "
				+ " LEFT OUTER JOIN PORTER ON PORTER.idMESURE = MESURE.idMESURE ";*/
			
			return  " SELECT MESURE.idMESURE as idMESURE, MESURE.libelle as mesure_libelle, MESURE.etat, " +
					" RISQUE.idRISQUE, RISQUE.libelleCourt, RISQUE.libelleLong " +				 
					" FROM MESURE " +
					" LEFT OUTER JOIN PORTER ON PORTER.idMESURE = MESURE.idMESURE " +
					" LEFT OUTER JOIN SM ON SM.idBS = PORTER.idBS " + 
					" LEFT OUTER JOIN COMPOSER ON COMPOSER.idSM = SM.idSM " +    
					" LEFT OUTER JOIN RISQUE ON RISQUE.idRISQUE = COMPOSER.idRISQUE " +
					" LEFT OUTER JOIN TMESURES ON MESURE.idTMESURES = TMESURES.idTMESURES " +
					" where TMESURES.idREFERENTIEL = 1";
		}
		
		public function getSecurityMeasureByRiskList():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = buildSecurityMeasureByRiskQuery();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT, getSecurityMeasureByRiskListResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function getSecurityMeasureByRiskListResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var securityMeasureByRiskList:ArrayCollection = new ArrayCollection();
			if (result != null && result.data != null)
			{
				securityMeasureByRiskList =  constructSecurityMesureByRiskList(result);				
			}
			_sqlStatement.sqlConnection.close();
			responder.result(securityMeasureByRiskList);
		}
		
		public function constructSecurityMesureByRiskList(result:SQLResult):ArrayCollection{
			
			var securityMeasureByRiskList:ArrayCollection = new ArrayCollection();
			
			if (result.data){
			
				var row:Object;
				var numRows:int = result.data.length;			
				var securityMeasure:SecurityMeasure;
				
				var tmpIdMesure:Number;
				var tmpIdRisque:Number;
				var tmpIdBS:Number;
				
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					
					if (tmpIdMesure != row["idMESURE"]){
						
						tmpIdMesure = row["idMESURE"];
						
						securityMeasure = new SecurityMeasure();
						securityMeasure.id = row["idMESURE"];
						securityMeasure.label = row["mesure_libelle"];
						
						securityMeasure.riskList = new ArrayCollection();
						
						securityMeasureByRiskList.addItem(securityMeasure);	
					}
					
					tmpIdRisque = -1;
					if (tmpIdRisque != row["idRISQUE"] && ArrayCollectionTool.findIndexForId(securityMeasure.riskList, row["idRISQUE"])==-1 && row["idRISQUE"]>0){
						
						tmpIdRisque = row["idRISQUE"];
						
						var risk:Risk =new Risk();
						risk.id = row["idRISQUE"];
						risk.short_label = row["libelleCourt"];
						risk.long_label = row["libelleLong"];
						securityMeasure.riskList.addItem(risk);
					}
					
				}
			}
			return securityMeasureByRiskList;
		}	
		
		/**********************************/
		/**Export des mesures de sécurité**/
		/**********************************/
		public function constructSecurityMeasureLightQuery():String{
			
			return "SELECT MESURE.idMESURE as idMESURE, MESURE.libelle as mesure_libelle, MESURE.etat," +
				" BS.idBS as idBS, ifnull(BS.libelle,'') as bs_libelle, " +
				" PERSONNE.idPERSONNE , ifnull(PERSONNE.nom,'') as nom, ifnull(PERSONNE.prenom,'') as prenom, " +
				" INDICATEUR.idINDICATEUR, ifnull(INDICATEUR.libelle,'') as indicateur_libelle," +
				" NINDICATEUR.idNINDICATEUR, ifnull(NINDICATEUR.libelle,'') as nindicateur_libelle, " +
				" TMESURES.idTMESURES as idTMESURES, ifnull(TMESURES.libelle,'') as tmesures_libelle, " +
				" LIGNE.idLIGNE as idLIGNE, ifnull(LIGNE.libelle,'') as ligne_libelle " +
				" FROM MESURE " +
				" LEFT OUTER JOIN TMESURES ON TMESURES.idTMESURES = MESURE.idTMESURES " +
				" LEFT OUTER JOIN PERSONNE ON MESURE.idPERSONNE = PERSONNE.idPERSONNE " +
				" LEFT OUTER JOIN PORTER ON PORTER.idMESURE = MESURE.idMESURE " +
				" LEFT OUTER JOIN BS ON BS.idBS = PORTER.idBS  " +
				" LEFT OUTER JOIN SUIVRE ON SUIVRE.idMESURE = MESURE.idMESURE " +
				" LEFT OUTER JOIN INDICATEUR ON SUIVRE.idINDICATEUR = INDICATEUR.idINDICATEUR " +
				" LEFT OUTER JOIN NINDICATEUR ON SUIVRE.idNINDICATEUR = NINDICATEUR.idNINDICATEUR " +
				" LEFT OUTER JOIN DEFENDRE ON DEFENDRE.idMESURE = MESURE.idMESURE " +
				" LEFT OUTER JOIN LIGNE ON LIGNE.idLIGNE = DEFENDRE.idLIGNE " +
				" WHERE TMESURES.idREFERENTIEL = 1 ";
		}
		
		public function getSecurityMeasureLightList():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = constructSecurityMeasureLightQuery();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT, getSecurityMeasureLightListResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function getSecurityMeasureLightListResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var securityMeasureLightList:ArrayCollection = new ArrayCollection();
			if (result != null && result.data != null)
			{
				securityMeasureLightList =  constructSecurityMesureLightList(result);				
			}
			_sqlStatement.sqlConnection.close();
			responder.result(securityMeasureLightList);
		}
		
		public function constructSecurityMesureLightList(result:SQLResult):ArrayCollection{
			var securityMeasureLightList:ArrayCollection = new ArrayCollection();
			
			if (result.data){
			
				var row:Object;
				var numRows:int = result.data.length;		
				var securityMeasureLight:SecurityMeasure;
				
				var tmpIdMesure:Number;
				var tmpIdIndicateur:Number;
				var tmpIdLigne:Number;
				var tmpIdBS:Number;
				
				for(var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					
					if(tmpIdMesure != row["idMESURE"])
					{
						tmpIdMesure = row["idMESURE"];
						
						securityMeasureLight = new SecurityMeasure();
						securityMeasureLight.id = row["idMESURE"];
						securityMeasureLight.label = row["mesure_libelle"];
						securityMeasureLight.state = row["etat"];
						
						securityMeasureLight.manager = new People();
						securityMeasureLight.manager.id = row["idPERSONNE"];
						securityMeasureLight.manager.first_name = row["nom"];
						securityMeasureLight.manager.last_name =  row["prenom"];
						
						securityMeasureLight.securityMeasureType = new SecurityMeasureType();
						securityMeasureLight.securityMeasureType.id = row["idTMESURES"];
						securityMeasureLight.securityMeasureType.label = row["tmesures_libelle"];
						
						securityMeasureLight.indicatorList = new ArrayCollection();
						securityMeasureLight.defenceLineList = new ArrayCollection();
						securityMeasureLight.supportingAssetList = new ArrayCollection();	
						
						securityMeasureLightList.addItem(securityMeasureLight);
					}
					tmpIdBS = -1;
					tmpIdLigne = -1;
					tmpIdIndicateur = -1;
					if (tmpIdBS != row["idBS"] && ArrayCollectionTool.findIndexForId(securityMeasureLight.supportingAssetList, row["idBS"])==-1 && row["idBS"]>0){
						tmpIdBS = row["idBS"];
						
						var supportingAsset:SupportingAsset = new SupportingAsset();
						supportingAsset.id = row["idBS"];
						supportingAsset.label = row["bs_libelle"];
						securityMeasureLight.supportingAssetList.addItem(supportingAsset);
					}
					if(tmpIdLigne != row["idLIGNE"] && ArrayCollectionTool.findIndexForId(securityMeasureLight.defenceLineList, row["idLIGNE"])==-1 && row["idLIGNE"]>0){
						tmpIdLigne = row["idLIGNE"];
						
						var defenceLine:DefenceLine =new DefenceLine();
						defenceLine.id = row["idLIGNE"];
						defenceLine.label = row["ligne_libelle"];
						securityMeasureLight.defenceLineList.addItem(defenceLine);
					}
					if(tmpIdIndicateur != row["idINDICATEUR"] && ArrayCollectionTool.findIndexForId(securityMeasureLight.indicatorList, row["idINDICATEUR"])==-1 && row["idINDICATEUR"]>0){
						tmpIdIndicateur = row["idINDICATEUR"];
						
						var indicateur:Indicator= new Indicator();
						indicateur.id = row["idINDICATEUR"];
						indicateur.libelle= row["indicateur_libelle"];
						var nindicateur:IndicatorLevel = new IndicatorLevel();
						nindicateur.id = row["idNINDICATEUR"];
						nindicateur.label = row["nindicateur_libelle"];
						indicateur.indicatorLevelForSecurityMeasure = nindicateur;
						securityMeasureLight.indicatorList.addItem(indicateur);
					}
				}
			}
			return securityMeasureLightList;
		}
		
	}
}