package com.anssi.ebios.services
{
	import com.anssi.ebios.model.People;
	import com.anssi.ebios.model.PrimaryAsset;
	import com.anssi.ebios.model.SupportAssetType;
	import com.anssi.ebios.model.SupportingAsset;
	import com.anssi.ebios.utils.Resources;
	import com.logica.fwk.utils.ArrayCollectionTool;
	
	import flash.data.SQLMode;
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLEvent;
	import flash.filesystem.File;
	
	import mx.collections.ArrayCollection;
	import mx.collections.HierarchicalData;
	import mx.rpc.IResponder;

	public class SupportingAssetService extends AppServices
	{
		
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement; 
		private var _supportingAssetList:ArrayCollection;
		private var _currentIndex:Number;
		private var _linkList:ArrayCollection;
		private var _supportingAsset:SupportingAsset;
		private var _link:Object;
		private var _supportingAssetResultList:ArrayCollection = new ArrayCollection();
		
		
		
		public function SupportingAssetService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		/************************************************/
		/** Récupération de la liste des biens support **/
		/************************************************/
		public function getSupportingAssetList():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = constructSupportingAssetQuery();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getSupportingAssetListResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function getSupportingAssetListResult(event:SQLEvent):void{
			var supportingAssetList:ArrayCollection = new ArrayCollection();
			// récupération des résultats
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			// si nous avons des résultats
			if (result != null && result.data != null)
			{
				supportingAssetList = constructSupportingAssetList(result);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(supportingAssetList);		
		}
		
		/*********************************************************************/
		/** Récupération de la liste des biens support retenus pour l'étude **/
		/*********************************************************************/
		public function getRetainedSupportingAssetList():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = constructSupportingAssetQuery('WHERE retenu = true');
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getRetainedSupportingAssetListResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function getRetainedSupportingAssetListResult(event:SQLEvent):void{
			var supportingAssetList:ArrayCollection = new ArrayCollection();
			// récupération des résultats
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			// si nous avons des résultats
			if (result != null && result.data != null)
			{
				supportingAssetList = constructSupportingAssetList(result);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(supportingAssetList);		
		}
		
		
		public function constructSupportingAssetQuery(WHERECondition:String = " "):String{
			return "SELECT BS.idBS as idBS, BS.libelle as libelle, BS.description as description, BS.retenu as retenu, BS.proprietaire as idPERSONNE, PERSONNE.nom as nom, PERSONNE.prenom as prenom " +
				   " FROM BS " +
				   " LEFT OUTER JOIN PERSONNE on BS.proprietaire = PERSONNE.idPERSONNE " + WHERECondition;
		}
		
		public function constructSupportingAssetList(result:SQLResult):ArrayCollection{
			var supportingAssetList:ArrayCollection = new ArrayCollection();
			
			if (result.data){			
				var row:Object;
				var numRows:int = result.data.length;
				
				var supportingAsset:SupportingAsset = null;
				
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					
					supportingAsset = new SupportingAsset();
					supportingAsset.id = row["idBS"];
					supportingAsset.label = row["libelle"];
					supportingAsset.description = row["description"];
					supportingAsset.retained = row["retenu"];
					
					if (row["idPERSONNE"] != null && row["idPERSONNE"] > -1 ){
						var people:People = new People();
						people.id = row["idPERSONNE"];
						people.first_name = row["nom"];
						people.last_name = row["prenom"];
						supportingAsset.proprietaire = people;
					}					
					supportingAssetList.addItem(supportingAsset);
				}
			}
			return supportingAssetList;
		}
		
		
		/*******************************************************/
		/** Récupération de la liste des liens entre BS et BE **/
		/*******************************************************/
		
		public function constructLinkBetweenAssetsQuery():String{
			return " SELECT BS.idBS as idParent, BS.libelle as BS_libelle, LIERBS.idBSenfant as idEnfant, CROISER.idBE as idBE, " +
				" TBS.idTBS, TBS.titre as tbs_titre " +
				" FROM BS " +
				" LEFT OUTER JOIN TBS ON TBS.idTBS = BS.idTBS " +
				" LEFT OUTER JOIN LIERBS ON (LIERBS.idBSparent = BS.idBS AND (LIERBS.idBSenfant IN (SELECT idBS FROM BS WHERE retenu = 1) OR LIERBS.idBSenfant is null)) " +
				" LEFT OUTER JOIN CROISER ON CROISER.idBS = BS.idBS " +
				" WHERE BS.retenu = true " +
				" ORDER BY idParent, idEnfant";
		}
		
		public function getLinkBetweenAssets():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = constructLinkBetweenAssetsQuery();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getLinkBetweenAssetsResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function getLinkBetweenAssetsResult(event:SQLEvent):void{
			_supportingAssetList = new ArrayCollection();
			
			// récupération des résultats
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			// si nous avons des résultats
			if (result != null && result.data != null)
			{
				_supportingAssetList = constructLinkBetweenAssetsList(result);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(_supportingAssetList);		
		}
		
		public function constructLinkBetweenAssetsList(result:SQLResult):ArrayCollection{
				
				_supportingAssetList = new ArrayCollection();
				
				if (result.data){
				
					var row:Object;
					var numRows:int = result.data.length;
					var tmpIdParent:Number;
					var tmpIdPrimaryAsset:Number;
					var tmpIdChild:Number;
					var supportingAsset:SupportingAsset;
					
					for (var i:int = 0; i < numRows; i++)
					{					
						row = result.data[i];
						
						if (tmpIdParent != row["idParent"]){
							tmpIdParent = row["idParent"];
							supportingAsset = new SupportingAsset();
							supportingAsset.id = row["idParent"];
							supportingAsset.label = row["BS_libelle"];
							
							var supportingAssetType:SupportAssetType = new SupportAssetType();
							supportingAssetType.id = row["idTBS"];
							supportingAssetType.title = row["tbs_titre"];
							supportingAsset.type = supportingAssetType;
							
							supportingAsset.children = new ArrayCollection();
							supportingAsset.primaryAssetList = new ArrayCollection();
							
							_supportingAssetResultList.addItem(supportingAsset);
							
							tmpIdPrimaryAsset= -1;
							tmpIdChild = -1;
						}
						
						if (tmpIdPrimaryAsset != row["idBE"] && ArrayCollectionTool.findIndexForId(supportingAsset.primaryAssetList, row["idBE"])==-1 && row["idBE"]>0){
							tmpIdPrimaryAsset = row["idBE"];
							
							var primaryAsset:PrimaryAsset = new PrimaryAsset();
							primaryAsset.id = row["idBE"];
							supportingAsset.primaryAssetList.addItem(primaryAsset);
						}
						
						
						if (tmpIdChild != row["idEnfant"] && ArrayCollectionTool.findIndexForId(supportingAsset.children, row["idEnfant"])==-1 && row["idEnfant"]>0){
							tmpIdChild = row["idEnfant"];
							
							var child:SupportingAsset = new SupportingAsset();
							child.id = row["idEnfant"];
							supportingAsset.children.addItem(child);
						}		
					}
							
					for (var j:int = 0; j < _supportingAssetResultList.length; j++){
						supportingAsset = _supportingAssetResultList.getItemAt(j) as SupportingAsset;
						if (!hasParent(supportingAsset)){
							_supportingAssetList.addItem(supportingAsset);
						}
					}
				}
			
			return _supportingAssetList;
		}
		
		public function constructLinkBetweenAssetsListLight(result:SQLResult):ArrayCollection{
			
			_supportingAssetList = new ArrayCollection();
			
			if (result.data){
				
				var row:Object;
				var numRows:int = result.data.length;
				var tmpIdParent:Number;
				var tmpIdPrimaryAsset:Number;
				var tmpIdChild:Number;
				var supportingAsset:SupportingAsset;
				
				for (var i:int = 0; i < numRows; i++)
				{					
					row = result.data[i];
					
					if (tmpIdParent != row["idParent"]){
						tmpIdParent = row["idParent"];
						supportingAsset = new SupportingAsset();
						supportingAsset.id = row["idParent"];
						supportingAsset.label = row["BS_libelle"];
						
						var supportingAssetType:SupportAssetType = new SupportAssetType();
						supportingAssetType.id = row["idTBS"];
						supportingAssetType.title = row["tbs_titre"];
						supportingAsset.type = supportingAssetType;
						
						supportingAsset.children = new ArrayCollection();
						supportingAsset.primaryAssetList = new ArrayCollection();
						
						_supportingAssetResultList.addItem(supportingAsset);
						
						tmpIdPrimaryAsset= -1;
						tmpIdChild = -1;
					}
					
					if (tmpIdPrimaryAsset != row["idBE"] && ArrayCollectionTool.findIndexForId(supportingAsset.primaryAssetList, row["idBE"])==-1 && row["idBE"]>0){
						tmpIdPrimaryAsset = row["idBE"];
						
						var primaryAsset:PrimaryAsset = new PrimaryAsset();
						primaryAsset.id = row["idBE"];
						supportingAsset.primaryAssetList.addItem(primaryAsset);
					}
					
					
					/*if (tmpIdChild != row["idEnfant"] && ArrayCollectionTool.findIndexForId(supportingAsset.children, row["idEnfant"])==-1 && row["idEnfant"]>0){
						tmpIdChild = row["idEnfant"];
						
						var child:SupportingAsset = new SupportingAsset();
						child.id = row["idEnfant"];
						supportingAsset.children.addItem(child);
					}*/		
				}
				
			}
			
			return _supportingAssetResultList;
		}
		
		
		private function hasParent(supportingAsset:SupportingAsset):Boolean{
			var parentFounded:Boolean = false;
			//Si on trouve le BE dans la liste finale des BE, alors il ne peut pas avoir de parent
			if(ArrayCollectionTool.findIndexForId(_supportingAssetList, supportingAsset.id) > -1){
				parentFounded = false;
			}else{
				//Sinon il faut vérifier que ce BE n'est pas l'enfant d'un autre BE
				//Pour chaque BE (parent) dans la liste, on va vérifier si le BE est l'enfant d'un BE
				for (var i:int = 0; i < _supportingAssetResultList.length; i++){
					var parent:SupportingAsset = _supportingAssetResultList.getItemAt(i) as SupportingAsset;
					if(isChild(parent, supportingAsset)){
						parentFounded = true;
						break;
					}
				}
			}
			return parentFounded;
		}
		
		private function isChild(parent:SupportingAsset, supportingAsset:SupportingAsset):Boolean{
			var childFounded:Boolean = false;
			
			//On parcours la liste des enfants du BE
			for (var i:int = 0; i < parent.children.length; i++){
				var child:SupportingAsset = parent.children.getItemAt(i) as SupportingAsset;
				
				//Si le BE est un enfant, alors on affecte le BE à son parent
				if (supportingAsset.id == child.id){
					parent.children.setItemAt(supportingAsset, i);
					childFounded = true;
				}else{
					//Si l'enfant a lui même des enfants, alors on rappelle la fonction de recherche
					if (child.children != null){
						childFounded = isChild(child, supportingAsset);
					}
				}
				
				if (childFounded){
					break;
				}
			}
			
			return childFounded;				
		}

		/******************************************************/
		/** Mise à jour de la liste des liens entre BS et BE **/
		/******************************************************/
		public function updateLinkBetweenAssets(supportingAssetList:ArrayCollection):void{
			_supportingAssetList = supportingAssetList;
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM CROISER";
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,updateLinkBetweenAssetsResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function updateLinkBetweenAssetsResult(event:SQLEvent):void{
			buildLinkList();
		}
		
		private function buildLinkList():void{
			_linkList = new ArrayCollection();
			for (var i:int = 0; i < _supportingAssetList.length; i++){
				var supportingAsset:SupportingAsset = _supportingAssetList.getItemAt(i) as SupportingAsset;
				addItemIntoLinkList(supportingAsset);
			}
			_currentIndex = -1;
			createLinkBetweenAssets();		
		}
		
		private function addItemIntoLinkList(supportingAsset:SupportingAsset):void{
			for (var i:int = 0; i < supportingAsset.primaryAssetList.length; i++){
				_link = new Object();
				_link.supportingAssetID = supportingAsset.id;
				_link.primaryAssetID = (supportingAsset.primaryAssetList.getItemAt(i) as PrimaryAsset).id;
				_linkList.addItem(_link);
			}
			
			for (var j:int = 0; j < supportingAsset.children.length; j++){
				var child:SupportingAsset = supportingAsset.children.getItemAt(j) as SupportingAsset;
				addItemIntoLinkList(child);
			}
		}
		
		
		private function createLinkBetweenAssets():void{
			
			_currentIndex++;
			
			setBDDName();			
			_sqlStatement = new SQLStatement();			
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			if (_currentIndex < _linkList.length){
				var link:Object = _linkList.getItemAt(_currentIndex);
				
				var query:String = "INSERT INTO CROISER (idBE, idBS, dateCreation, dateModification) VALUES (:idBE, :idBS, :dateCreation, :dateModification)";
				
				_sqlStatement.parameters[":idBE"]= link.primaryAssetID;
				_sqlStatement.parameters[":idBS"]= link.supportingAssetID;
				_sqlStatement.parameters[":dateCreation"]= new Date();
				_sqlStatement.parameters[":dateModification"]= new Date();
				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,createLinkBetweenAssetsResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);
			}else{
				_sqlStatement.sqlConnection.close();
				responder.result(null);
			}
		}
		
		
		private function createLinkBetweenAssetsResult(event:SQLEvent):void{
			createLinkBetweenAssets();
		}		
		
	}
}