package com.anssi.ebios.services
{
	import com.anssi.ebios.model.ThreatSource;
	import com.anssi.ebios.model.ThreatSourceType;
	
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLEvent;
	
	import mx.collections.ArrayCollection;
	import mx.rpc.IResponder;

	public class ThreatSourceService extends AppServices
	{
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement; 
		
		public function ThreatSourceService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
	
		public function getThreatSource():void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String =
					
			"SELECT * FROM SOURCE"
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getThreatSourceResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function getThreatSourceResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			if (result != null && result.data != null)
			{
				var threatSourceList:ArrayCollection = contructThreatSourceList(result);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(threatSourceList);
		}
		
		private function contructThreatSourceList(result:SQLResult):ArrayCollection{
			var threatSourceList:ArrayCollection = new ArrayCollection();
			if(result.data)
			{
				var row:Object;
				var numRows:int = result.data.length;
				var threatSource:ThreatSource;
				
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					threatSource = new ThreatSource();	
					threatSource.id = row["idSOURCE"];
					threatSource.label = row["libelle"]
					
					threatSourceList.addItem(threatSource);
				}
			}
			return threatSourceList;
		}
		
		
		/******************************************************************/
		/** Récupération de la liste des sources de menaces pour le grid **/
		/******************************************************************/
		
		public function getThreatSourceList():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = constructGetThreatSourceQuery("");
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getThreatSourceListResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function getThreatSourceListResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			if (result != null && result.data != null)
			{
				var threatSourceList:ArrayCollection = contructThreatSourceListForGrid(result);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(threatSourceList);
		}

		private function constructGetThreatSourceQuery(condition:String):String{
			
			var query:String = "SELECT idSOURCE, SOURCE.libelle as Slibelle, description, TSOURCES.idTSOURCES as idTsources, " +
				" TSOURCES.exemples as TSexemples, " +
				" TSOURCES.libelle as TSlibelle FROM SOURCE" +
				" LEFT OUTER JOIN TSOURCES ON TSOURCES.idTSOURCES =  SOURCE.idTSOURCES " +
				condition  +
				" order by idSOURCE ";
			
			return query;
		}
		
		private function contructThreatSourceListForGrid (result:SQLResult):ArrayCollection{
			var threatSourceList:ArrayCollection = new ArrayCollection();
			
			var row:Object;
			if(result.data)
			{
				var numRows:int = result.data.length;
				var threatSource:ThreatSource;
				
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					threatSource = new ThreatSource();	
					threatSource.id = row["idSOURCE"];
					threatSource.label = row["Slibelle"];
					threatSource.description = row["description"];
					threatSource.threatSourceType = new ThreatSourceType();
					threatSource.threatSourceType.id = row["idTsources"];
					threatSource.threatSourceType.label = row["TSlibelle"];
					threatSource.threatSourceType.examples = row["TSexemples"];
					threatSourceList.addItem(threatSource);
				}
			}
			return threatSourceList;
		}
		
		
		/******************************************************************/
		/**Récupération d'une source de menace selpon l'id           ******/
		/******************************************************************/
		
		public function getThreatSourceById(id:Number):void
		{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = constructGetThreatSourceQuery('WHERE SOURCE.idSOURCE = :idSOURCE');
			
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idSOURCE"] = id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getThreatSourceByIdResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		private function getThreatSourceByIdResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null)
			{
				
				var threatSource:ThreatSource =  contructThreatSourceListForGrid( result )[0];
			}
			_sqlStatement.sqlConnection.close();
			responder.result(threatSource);
		}
		
		/***************************************************************/
		/** Récupération de la liste des sources de menaces sans type **/
		/***************************************************************/
		public function getThreatSourceWithoutType():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String =
				
				"SELECT * FROM SOURCE WHERE idTSOURCES <= 0 OR idTSOURCES is NULL"
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getThreatSourceWithoutTypeResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function getThreatSourceWithoutTypeResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			if (result != null && result.data != null)
			{
				var threatSourceList:ArrayCollection = contructThreatSourceList(result);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(threatSourceList);
		}
		
		/*************************************/
		/** Création d'une source de menace **/
		/*************************************/
		public function createThreatSource(threatSource:ThreatSource):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "INSERT INTO SOURCE (libelle, description, idTSOURCES, dateCreation, dateModification) " +
				" VALUES (:libelle, :description, :idTSOURCES, :dateCreation, :dateModification)";
			
			_sqlStatement.parameters[":libelle"] = threatSource.label
			_sqlStatement.parameters[":description"] = threatSource.description
			_sqlStatement.parameters[":idTSOURCES"] = threatSource.threatSourceType.id;
			_sqlStatement.parameters[":dateCreation"] = new Date();
			_sqlStatement.parameters[":dateModification"] = new Date();

			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,createThreatSourceResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function createThreatSourceResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			_sqlStatement.sqlConnection.close();
			responder.result(null);
		}
		
		/*********************************************************************************/
		/** Création d'une source de menace et Mise à retenu du type de source de menace**/
		/*********************************************************************************/
		
		public function createThreatSourceAndRetainType(threatSource:ThreatSource):void{
			var query:String ="";
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			openInSyncMode(_sqlStatement);
			
			query="INSERT INTO SOURCE (libelle, description, idTSOURCES, dateCreation, dateModification) " +
				" VALUES (:libelle, :description, :idTSOURCES, :dateCreation, :dateModification)";
			
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":libelle"] = threatSource.label
			_sqlStatement.parameters[":description"] = threatSource.description
			_sqlStatement.parameters[":idTSOURCES"] = threatSource.threatSourceType.id;
			_sqlStatement.parameters[":dateCreation"] = new Date();
			_sqlStatement.parameters[":dateModification"] = new Date();
			_sqlStatement.text = query;
			execStatement(_sqlStatement);
			
			query="UPDATE TSOURCES set retenu = :retenu WHERE idTSOURCES = :idTSOURCES ";
			_sqlStatement.text=query;
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idTSOURCES"] = threatSource.threatSourceType.id;
			_sqlStatement.parameters[":retenu"] = true;
			execStatement(_sqlStatement);
			
			
			_sqlStatement.sqlConnection.close();
			responder.result(null);
		}
		
		/*********************************************************************************/
		/** Mise à jour d'une source de menace avec type de soutce de menace retenu     **/
		/*********************************************************************************/
		
		public function updateThreatSource(threatSource:ThreatSource,oldId:String):void{
			setBDDName();
			_sqlStatement = new SQLStatement();			
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			openInSyncMode(_sqlStatement);
			var query:String =
				
				"UPDATE  SOURCE " +
				" SET libelle= :libelle ," +
				" idTSOURCES= :idTSOURCES ," +
				" description= :description," +
				" dateModification= :dateModification " +
				" WHERE SOURCE.idSOURCE= :id";
			
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":libelle"] = threatSource.label;
			_sqlStatement.parameters[":idTSOURCES"] = threatSource.threatSourceType.id;
			_sqlStatement.parameters[":description"] = threatSource.description;
			_sqlStatement.parameters[":dateModification"] = new Date();
			_sqlStatement.parameters[":id"] = threatSource.id;
			
			_sqlStatement.text = query;
			execStatement(_sqlStatement);
			
			var primaryKey:Number = _sqlStatement.parameters[":id"];
			
			query = verifTSTRetainedQuery(oldId);
			_sqlStatement.clearParameters();
			_sqlStatement.text = query;
			execStatement(_sqlStatement);
			var resultList:Array = _sqlStatement.getResult().data;
			var num:int = resultList[0].numidsource;
			
			if(num == 0){
				// on désélectionne le type de source de menace
				
				query = "UPDATE TSOURCES SET retenu = :retenu WHERE idTSOURCES = :idTSOURCES ";
				_sqlStatement.text=query;
				_sqlStatement.clearParameters();
				_sqlStatement.parameters[":idTSOURCES"] = oldId;
				_sqlStatement.parameters[":retenu"] = false;
				execStatement(_sqlStatement);
			}
			query = "UPDATE TSOURCES SET retenu = :retenu WHERE idTSOURCES = :idTSOURCES ";
			_sqlStatement.text=query;
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idTSOURCES"] = threatSource.threatSourceType.id;
			_sqlStatement.parameters[":retenu"] = true;
			execStatement(_sqlStatement);
			
			
			_sqlStatement.sqlConnection.close();
			responder.result(primaryKey);

		}
		
		/***************************************************/
		/** suppression en cascade d'une source de menace***/
		/***************************************************/
	public function deleteThreatSource(threatSource:ThreatSource):void{
			setBDDName();
			_sqlStatement = new SQLStatement();			
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			openInSyncMode(_sqlStatement);
			var query:String;
			
			query = "DELETE FROM INITIER WHERE idSOURCE = :idSOURCE";
			_sqlStatement.text=query;
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idSOURCE"] = threatSource.id;
			execStatement(_sqlStatement);
			
			query = "DELETE FROM POUVOIR WHERE idSOURCE = :idSOURCE";
			_sqlStatement.text=query;
			execStatement(_sqlStatement);
			
			query = verifTSTRetainedQuery(threatSource.threatSourceType.id);
			_sqlStatement.clearParameters();
			_sqlStatement.text = query;
			execStatement(_sqlStatement);
			var resultList:Array = _sqlStatement.getResult().data;
			var num:int = resultList[0].numidsource;
			
			if(num <= 1){
				// on désélectionne le type de source de menace
				
				query = "UPDATE TSOURCES SET retenu = :retenu WHERE idTSOURCES = :idTSOURCES ";
				_sqlStatement.text=query;
				_sqlStatement.clearParameters();
				_sqlStatement.parameters[":idTSOURCES"] = threatSource.threatSourceType.id;
				_sqlStatement.parameters[":retenu"] = false;
				execStatement(_sqlStatement);
			}
			
			query = "DELETE FROM SOURCE WHERE idSOURCE = :idSOURCE";
			_sqlStatement.text=query;
			_sqlStatement.clearParameters();
			_sqlStatement.parameters[":idSOURCE"] = threatSource.id;
			execStatement(_sqlStatement);
			_sqlStatement.sqlConnection.close();
			responder.result(null);
				
		}
		private function verifTSTRetainedQuery(oldId:String):String{
			var query:String = "SELECT COUNT(idSOURCE) numidsource FROM SOURCE WHERE idTSOURCES = "+oldId;
			return query;			
		}

	}
}