package com.anssi.ebios.services
{
	import com.anssi.ebios.model.ThreatSource;
	import com.anssi.ebios.model.ThreatSourceType;
	import com.anssi.ebios.model.ThreatType;
	
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLEvent;
	
	import mx.collections.ArrayCollection;
	import mx.rpc.IResponder;

	public class ThreatSourceTypeService extends AppServices
	{
		
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement;
		private var _threatSourceType:ThreatSourceType;
		private var _threatSourceToUpdate:ArrayCollection;
		private var _currentIndex:Number = -1;
		private var _primaryKey:Number;
		
		public function ThreatSourceTypeService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		/**************************************************************/
		/** Récupération de la liste des types de sources de menaces **/
		/**************************************************************/
		public function getThreatSourceType():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = constructThreatSourceTypeQuery();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getThreatSourceTypeResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function getThreatSourceTypeResult(event:SQLEvent):void{	
			var result:SQLResult = SQLStatement(event.target).getResult();
			var threatSourceTypeList:ArrayCollection = new ArrayCollection();
			if (result != null && result.data != null){
				threatSourceTypeList = constructThreatSourceTypeList(result);	
			}
			_sqlStatement.sqlConnection.close();
			responder.result(threatSourceTypeList);
		}
		
		public function constructThreatSourceTypeQuery(WHERECondition:String = ""):String{
			return "SELECT TSOURCES.idTSOURCES as idTSOURCES, TSOURCES.libelle as ts_libelle, TSOURCES.exemples, TSOURCES.retenu, ifnull(TSOURCES.justification, '') as justification, " +
				" SOURCE.idSOURCE, SOURCE.libelle as s_libelle " +
				" FROM TSOURCES " +
				" LEFT OUTER JOIN SOURCE ON TSOURCES.idTSOURCES = SOURCE.idTSOURCES " +
				" " + WHERECondition +
				" ORDER BY idTSOURCES";
		}
		
		public function constructThreatSourceTypeList(result:SQLResult):ArrayCollection{
			var threatSourceTypeList:ArrayCollection = new ArrayCollection();
			
			if (result.data){
				var row:Object;
				var numRows:int = result.data.length;
				var threatSourceType:ThreatSourceType;
				var tmpthreatSourceTypeId:Number;
				
				for (var i:int = 0; i < numRows; i++){
					row = result.data[i];
					
					var threatSource:ThreatSource;					
					
					if (tmpthreatSourceTypeId != row["idTSOURCES"]){
						tmpthreatSourceTypeId = row["idTSOURCES"];
						
						threatSourceType= new ThreatSourceType();	
						threatSourceType.threatSourceList = new ArrayCollection();
						
						threatSourceType.id = row["idTSOURCES"];
						threatSourceType.label = row["ts_libelle"];
						threatSourceType.examples = row["exemples"];
						threatSourceType.retained = row["retenu"];
						threatSourceType.justification = row["justification"];
						threatSourceTypeList.addItem(threatSourceType);
					}
					
					if (row["idSOURCE"] > 0){
						threatSource = new ThreatSource();
						threatSource.id = row["idSOURCE"];
						threatSource.label = row["s_libelle"];
						threatSourceType.threatSourceList.addItem(threatSource);
					}
				}
			}
			return threatSourceTypeList;
		}
		
		/***********************************************************/
		/** Récupération d'un type de source de menace via son ID**/
		/**********************************************************/
		public function getThreatSourceTypeById(id:Number):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = constructThreatSourceTypeQuery('WHERE TSOURCES.idTSOURCES = ' + id);
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getThreatSourceTypeByIdResult);
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function getThreatSourceTypeByIdResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null){
				var threatSourceType:ThreatSourceType = constructThreatSourceTypeList(result)[0];	
			}
			_sqlStatement.sqlConnection.close();
			responder.result(threatSourceType);
		}
		
		/*****************************************************************************************/
		/** Mise à jour d'un type de source de menace + Mise à jour du type des sources de menace*/
		/*****************************************************************************************/
		public function updateThreatSourceType(threatSourceType:ThreatSourceType):void{
			_threatSourceType = threatSourceType;
			
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = "UPDATE TSOURCES SET retenu = :retenu," +
				" justification = :justification, " +
				" dateModification = :dateModification "+
				" WHERE idTSOURCES = :idTSOURCES";
			
			_sqlStatement.parameters[":retenu"] = _threatSourceType.retained;
			_sqlStatement.parameters[":justification"] = _threatSourceType.justification;
			_sqlStatement.parameters[":idTSOURCES"] = _threatSourceType.id;
			_sqlStatement.parameters[":dateModification"] = new Date();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT, updateThreatSourceTypeResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function updateThreatSourceTypeResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			_primaryKey = SQLStatement(event.target).parameters[":idTSOURCES"];
			
			if (result != null)
			{
				initializeTypeOfThreatSource();
			}
		}
		
		/** On met à null l'ID du type de source de menace de chaque source de menace du type concerné */
		private function initializeTypeOfThreatSource():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = "UPDATE SOURCE SET idTSOURCES = null, dateModification = :dateModification " +
				" WHERE idTSOURCES = :idTSOURCES";
			
			_sqlStatement.parameters[":idTSOURCES"] = _threatSourceType.id;
			_sqlStatement.parameters[":dateModification"] = new Date();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT, initializeTypeOfThreatSourceResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function initializeTypeOfThreatSourceResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null)
			{
				updateTypeOfThreatSource();
			}
		}
		
		/** Pour chaque sources de menaces contenues dans la liste des sources de menace du type de source de menace concerné
		 * On met à jour l'ID du type de source de menace */
		private function updateTypeOfThreatSource():void{
			_threatSourceToUpdate = _threatSourceType.threatSourceList;
			
			_currentIndex++
			if (_currentIndex < _threatSourceToUpdate.length){
				var threatSource:ThreatSource = _threatSourceToUpdate.getItemAt(_currentIndex) as ThreatSource;
				
				setBDDName();
				_sqlStatement = new SQLStatement();
				_sqlStatement.sqlConnection = this.sqlConnection;
				
				var query:String = "UPDATE SOURCE SET idTSOURCES = :idTSOURCES, dateModification = :dateModification " +
					" WHERE idSOURCE = :idSOURCE";
				
				_sqlStatement.parameters[":idTSOURCES"] = _threatSourceType.id;
				_sqlStatement.parameters[":idSOURCE"] = threatSource.id;
				_sqlStatement.parameters[":dateModification"] = new Date();
				
				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT, updateTypeOfThreatSourceResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);
			}else{
				_sqlStatement.sqlConnection.close();
				responder.result(_primaryKey);
			}
		}
		
		private function updateTypeOfThreatSourceResult(event:SQLEvent):void{
			updateTypeOfThreatSource();
		}
	}
}