package com.anssi.ebios.utils.language
{
	import com.anssi.ebios.utils.Properties;
	import com.anssi.ebios.utils.Resources;
	
	import flash.events.Event;
	import flash.events.EventDispatcher;
	import flash.events.FileListEvent;
	import flash.filesystem.File;
	
	import mx.controls.Alert;
	import mx.resources.ResourceManager;

	public class LanguageManager extends EventDispatcher
	{

		import mx.collections.ArrayCollection;
		import mx.resources.ResourceBundle;
		
		//public static const DIRECTORY_PATH:String = File.applicationStorageDirectory.url+'/languages/';
		
		public static const LOADIND_LANGUAGE_LIST_COMPLETE:String='LOADIND_LANGUAGE_COMPLETE';
		
		private var _dictionaryUtil:DictionaryUtil = new DictionaryUtil();
		private var _listLanguage:ArrayCollection = new ArrayCollection();
		private var _languageNumber:Number;
		private var _languageFolderFilesArray:Array;
		private var _languageFileCounter:Number;
		private var _sharedObjectManager:SharedObjectManager = new SharedObjectManager();
		
		
		[Embed(source="config/config.properties",mimeType ="application/octet-stream")]
		private var config:Class;
		
		public var path:String;
		
		private var configs:Properties = null;
		
		/**
		 * Charger des fichiers de langues externes à l'application : loadLanguage()
		 * Accéder à la langue par default de l'utilisateur stockée dans un shareObject : getDefaultLanguageInShareObject()
		 * Modifier langue courante stockée dans un shareObject : setDefaultLanguage(languageLocaleName:String)
		 * Modifier la langue courante de l'application : updateCurrentApplicationLanguage (languageDto: LanguageDto)
		 */
		public function LanguageManager()
		{
			// on pointe vers le fichier de config
			configs = Properties.getEmbeddedBundle(config);
			path = File.applicationStorageDirectory.nativePath.toString()+Resources.getInstance().getDirectorySeparator()+configs.getValue("app.storage.languages.directory")+Resources.getInstance().getDirectorySeparator();
		}
		
		/**
		 * Cette fonction permet de charger des dictionnaires externe à l'application dynamiquement
		 * Elle parse le contenue d'un repertoire et créer pour chaque fichier de langue (.properties) un objet LanguageDto
		 * L'objet LanguageDto contient une propriété dictionary initialiser avec le contenu des fichier langues
		 * 
		 */
		public function loadLanguage():void
		{
			listDirectory();
		}
		
		private function listDirectory():void
		{
			try
			{  
				var dir:File = new File(path);
				dir.addEventListener( FileListEvent.DIRECTORY_LISTING, handleDirectoryListing );
				dir.getDirectoryListingAsync();
			}
			catch(error : Error)
			{
				Alert.show("Open DIRECTORY_PATH failed: "+ path +'',"Technical Error");
			}
			
		}
		private function handleDirectoryListing( event:FileListEvent ):void
		{
			_languageFileCounter = 0;
			_languageFolderFilesArray = getFormatedLanguageFileInArray(event.files); //Ne garde que les fichiers .properties
			loadFile();
		}
		
		private function loadFile():void // Recursif
		{
			
			_languageFileCounter++;
			
			if(_languageFolderFilesArray.length>=_languageFileCounter)	
			{
				_dictionaryUtil.addEventListener('loadLanguageCompleted',onLoadLanguageComplete);
				_dictionaryUtil.loadFile(_languageFolderFilesArray[_languageFileCounter-1].name,path);
			}
			else //Si tous les fichiers de langues ont été loadés
			{
				_dictionaryUtil.removeEventListener('loadLanguageCompleted',onLoadLanguageComplete);
				
				for each ( var item:File in _languageFolderFilesArray) // On créer une collection d'objets langues
				{		
					var completeFileName:String = item.name;
					var languageName:String =  getLanguageNameByFileName(completeFileName);
					var language:LanguageVO = new LanguageVO()
					language.label = languageName;
					language.locale = languageName;
					language.dictionary = _dictionaryUtil.createDictionary(completeFileName);
					_listLanguage.addItem(language);
				}
				dispatchEvent(new Event(LOADIND_LANGUAGE_LIST_COMPLETE));
			}
		}
		private function onLoadLanguageComplete(evt:Event):void
		{
			loadFile();
		}
		
		public function get defaultLanguageInShareObject():String
		{
			return _sharedObjectManager.defaultLanguage;
		}
		
		public function get availableShareObject():Boolean
		{
			return _sharedObjectManager.availableShareObject;
		}
		
		private function getLanguageNameByFileName(completeFileName:String):String
		{
			return completeFileName.substr(10,completeFileName.length-21); //IN= resources_LANGUE.properties =after substr return => LANGUE
		}
		

		private function getFormatedLanguageFileInArray(tab:Array):Array
		{
			var filterTab:Array=new Array;
			for each (var item:File in tab )
			{
				if(item.extension == 'properties')
				{
					filterTab.push(item);
				}
			} 
			return filterTab;
		}
		
		
		public function setDefaultLanguage(languageLocaleName:String):void
		{
			_sharedObjectManager.saveShareObject(languageLocaleName);
		}
		public function updateCurrentApplicationLanguage(languageDto: LanguageVO):void
		{
			initializeResourceBundle(languageDto.dictionary, languageDto.locale, 'resources');
			ResourceManager.getInstance().localeChain = [languageDto.locale];
		}
		
		private function initializeResourceBundle(dictionary:Object, locale:String, resoureceBundleName:String):void
		{
			var bundle:ResourceBundle = new ResourceBundle(locale, resoureceBundleName);
			
			for(var key:Object in dictionary)
			{
				bundle.content[key] = dictionary[key];
			}
			
			ResourceManager.getInstance().addResourceBundle(bundle);
		}
		
		public function get languageList():ArrayCollection
		{
			return _listLanguage;
		}
	}
}