package com.anssi.ebios.services
{
	import com.anssi.ebios.model.LikelihoodLevel;
	import com.anssi.ebios.model.Requirement;
	import com.anssi.ebios.model.Threat;
	import com.anssi.ebios.model.ThreatType;
	import com.anssi.ebios.model.Vulnerability;
	import com.logica.fwk.component.layout.flipbook.rubenswieringa.book.limited;
	
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLEvent;
	
	import mx.collections.ArrayCollection;
	import mx.rpc.IResponder;

	public class ThreatService extends AppServices
	{
		
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement;
		private var _primaryKey:Number;
		private var _currentIndex:Number = -1;
		private var _threat:Threat;
		
		public function ThreatService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		
		/******************************************/
		/** Récupération de la liste des menaces **/
		/******************************************/	
		public function getThreatList():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = constructThreatListQuery();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getThreatListResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function getThreatListResult(event:SQLEvent):void{

			var result:SQLResult = SQLStatement(event.target).getResult();
			var threatList:ArrayCollection = new ArrayCollection();
			if (result != null && result.data != null)
			{
				threatList = constructThreatList(result);
			}
			
			_sqlStatement.sqlConnection.close();
			responder.result(threatList);
		}
		
		private function constructThreatListQuery(WHERECondition:String = ""):String{
			return "SELECT MENACE.idMENACE as idMenace, MENACE.libelle as Menace, TMENACES.idTMENACES as idTMenace,TMENACES.libelle as TMenace, TMENACES.exemples as exemples, VULN.idVULN as idVULN, VULN.libelle as vulnerabilite, PREREQUIS.idPREREQUIS as idPREREQUIS, PREREQUIS.libelle as prerequis" +
				" FROM MENACE " +
				" LEFT OUTER JOIN TMENACES ON TMENACES.idTMENACES = MENACE.idTMENACES " +
				" LEFT OUTER JOIN EXPLOITER ON EXPLOITER.idMENACE = MENACE.idMENACE " +
				" LEFT OUTER JOIN VULN ON VULN.idVULN = EXPLOITER.idVULN " +
				" LEFT OUTER JOIN PREREQUIS ON PREREQUIS.idTMENACES = TMENACES.idTMENACES " +
				" " + WHERECondition +
				" ORDER BY MENACE.idMENACE, VULN.idVULN, PREREQUIS.idPREREQUIS";
		}
		
		private function constructThreatList(result:SQLResult):ArrayCollection{
			var threatList:ArrayCollection = new ArrayCollection();
			
			var row:Object;
			var numRows:int = result.data.length;
			var threat:Threat= null;
			var tmpThreatId:Number;
			var tmpVulnerabilityId:Number;
			var countVuln:Number = 0;
			
			
			for (var i:int = 0; i < numRows; i++)
			{
				row = result.data[i];
				
				if (tmpThreatId != row["idMenace"]){
					tmpThreatId = row["idMenace"];
					
					threat = new Threat();
					threat.vulnerabilityList = new ArrayCollection();
					threat.requirementList = new ArrayCollection();
					
					countVuln = 0;
					tmpVulnerabilityId = -1;
					
					threat.id = row["idMenace"];
					threat.label = row["Menace"];
					
					var threatType:ThreatType = new ThreatType();
					threatType.id = row["idTMenace"];
					threatType.label = row["TMenace"];
					threatType.examples = row["exemples"];
					
					threat.threatType = threatType;
					
					threatList.addItem(threat);						
				}
				
				if (tmpVulnerabilityId != row["idVULN"]){					
					
					if (row["idVULN"] != null){
						countVuln++;
						tmpVulnerabilityId = row["idVULN"];
						var vuln:Vulnerability = new Vulnerability();
						vuln.id = row["idVULN"];
						vuln.label = row["vulnerabilite"];
						threat.vulnerabilityList.addItem(vuln);
					}else{
						countVuln = 1;
					}
				}
				
				if (countVuln == 1){
					if(row["idPREREQUIS"] > 0){
						var requirement:Requirement = new Requirement();
						requirement.id = row["idPREREQUIS"];
						requirement.label = row["prerequis"];
						threat.requirementList.addItem(requirement);
					}
				}
			}
			return threatList;
		}
		
		
		/***************************************************/
		/** Récupération de la liste des types de menaces **/
		/***************************************************/
		public function getThreatTypeList():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "SELECT * FROM TMENACES";

			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getThreatTypeListResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getThreatTypeListResult(event:SQLEvent):void{
			var threatTypeList:ArrayCollection = null;

			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null)
			{
				threatTypeList = new ArrayCollection();
				
				var row:Object;
				var numRows:int = result.data.length;
				var threatType:ThreatType;
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					threatType = new ThreatType();
					threatType.id = row["idTMENACES"];
					threatType.label = row["libelle"];
					threatType.examples = row["exemples"];
					
					threatTypeList.addItem(threatType);
				}
			}
			
			_sqlStatement.sqlConnection.close();
			responder.result(threatTypeList);
		}
		
		
		/******************************************/
		/** Récupération d'une menace via son ID **/
		/******************************************/
		public function getThreatById(id:Number):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			
			var query:String = constructThreatListQuery('WHERE MENACE.idMENACE = '+id);
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT, getThreatByIdResult);
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getThreatByIdResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null)
			{				
				var threat:Threat =  constructThreatList(result)[0];
			}
			_sqlStatement.sqlConnection.close();
			responder.result(threat);
		}
		
		/***************************/
		/** Création d'une menace **/
		/***************************/
		/** 1)Insertion dans la table MENACE
		 *  2)Affectation des vulnérabilités à la MENACE = Insertion dans la table EXPLOITER pour chaque vulnérabilités */
		
		public function createThreat(threat:Threat):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "INSERT INTO MENACE (idTMENACES, libelle, dateCreation, dateModification) " +
				" VALUES (:idTMENACES, :libelle, :dateCreation, :dateModification)";
			
			_sqlStatement.parameters[":idTMENACES"] = threat.threatType.id;
			_sqlStatement.parameters[":libelle"] = threat.label;
			_sqlStatement.parameters[":dateCreation"] = new Date();
			_sqlStatement.parameters[":dateModification"] = new Date();

			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,createThreatResult);
			
			_threat = new Threat();
			_threat = threat;
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function createThreatResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();

			if (result != null)
			{
				_threat.id = String(result.lastInsertRowID);
			}
			_currentIndex = -1;
			affectVulnerabilityOnThreatCreation();
		}
		
		private function affectVulnerabilityOnThreatCreation():void{
			
			_currentIndex++
			if (_currentIndex < _threat.vulnerabilityList.length){
				
				var vulnerability:Vulnerability =  _threat.vulnerabilityList.getItemAt(_currentIndex) as Vulnerability;
				
				setBDDName();
				_sqlStatement = new SQLStatement();
				
				_sqlStatement.sqlConnection = this.sqlConnection;
				var query:String = "INSERT INTO EXPLOITER(idMENACE, idVULN, dateCreation, dateModification) " +
					" VALUES (:idMENACE, :idVULN, :dateCreation, :dateModification)";
				
				_sqlStatement.parameters[":idMENACE"] = _threat.id;
				_sqlStatement.parameters[":idVULN"] = vulnerability.id;
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();

				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,affectVulnerabilityOnThreatCreationResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);
			}else{
				_sqlStatement.sqlConnection.close();
				responder.result(_threat.id);
			}
		}
		
		private function affectVulnerabilityOnThreatCreationResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			if (result != null){
				affectVulnerabilityOnThreatCreation();				
			}
		}
		
		/******************************/
		/** Suppression d'une menace **/
		/******************************/
		/** 1)Suppression de la table MENACE
		 *  2)Désaffectation des vulnérabilités de la menace supprimée = Suppression de la table EXPLOITER 
		 *  3)Désaffectation de la menace des scénarios de menace auxquels elle était affecté = suppression de la table MENACER*/
		
		public function deleteThreat(threat:Threat):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM MENACE WHERE idMENACE = :idMENACE";
			
			_sqlStatement.parameters[":idMENACE"] = threat.id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,deleteThreatResult);
			
			_threat = new Threat();
			_threat = threat;
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function deleteThreatResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null){
				unaffectVulnerabilityOnThreatDeletion();
			}
		}
		
		private function unaffectVulnerabilityOnThreatDeletion():void{
					
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM EXPLOITER WHERE idMENACE = :idMENACE";
			
			_sqlStatement.parameters[":idMENACE"] = _threat.id;
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,unaffectVulnerabilityOnThreatDeletionResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);

		}
		
		private function unaffectVulnerabilityOnThreatDeletionResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null){
				unaffectThreatFromThreatScenario();
			}
		}
		
		private function unaffectThreatFromThreatScenario():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM MENACER WHERE idMENACE = :idMENACE";
			
			_sqlStatement.parameters[":idMENACE"] = _threat.id;
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,unaffectThreatFromThreatScenarioResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function unaffectThreatFromThreatScenarioResult(event:SQLEvent):void{
			_sqlStatement.sqlConnection.close();
			responder.result(null);
		}
		
		/******************************/
		/** Mise à jour d'une menace **/
		/******************************/
		/** 1)Mise à jour de la table MENACE
		 *  2)Désaffectation des vulnérabilités de la menace mise à jour = Suppression de la table EXPLOITER 
		 *  3)Affectation des vulnérabilités de la menace mise à jour = Insertion dans la table EXPLOITER */
		
		public function updateThreat(threat:Threat):void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "UPDATE MENACE SET libelle = :libelle," +
				" idTMENACES = :idTMENACES ," +
				" dateModification = :dateModification" +
				" WHERE idMENACE= :idMENACE";
			
			_sqlStatement.parameters[":idTMENACES"] = threat.threatType.id;
			_sqlStatement.parameters[":libelle"] = threat.label;
			_sqlStatement.parameters[":idMENACE"] = threat.id;
			_sqlStatement.parameters[":dateModification"] = new Date();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,updateThreatResult);
			
			_threat = new Threat();
			_threat = threat;
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function updateThreatResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null){
				_primaryKey = SQLStatement(event.target).parameters[":idMENACE"];
				unaffectVulnerabilityOnThreatUpdate();
			}			
		}
		
		private function unaffectVulnerabilityOnThreatUpdate():void{
			
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM EXPLOITER WHERE idMENACE = :idMENACE";
			
			_sqlStatement.parameters[":idMENACE"] = _threat.id;
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,unaffectVulnerabilityOnThreatUpdateResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
			
		}
		
		private function unaffectVulnerabilityOnThreatUpdateResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null){
				_currentIndex = -1;
				affectVulnerabilityOnThreatUpdate();
			}
		}
		
		private function affectVulnerabilityOnThreatUpdate():void{
			
			_currentIndex++
			if (_currentIndex < _threat.vulnerabilityList.length){
				
				var vulnerability:Vulnerability =  _threat.vulnerabilityList.getItemAt(_currentIndex) as Vulnerability;
				
				setBDDName();
				_sqlStatement = new SQLStatement();
				
				_sqlStatement.sqlConnection = this.sqlConnection;
				var query:String = "INSERT INTO EXPLOITER(idMENACE, idVULN, dateCreation, dateModification) " +
					" VALUES (:idMENACE, :idVULN, :dateCreation, :dateModification)";
				
				_sqlStatement.parameters[":idMENACE"] = _threat.id;
				_sqlStatement.parameters[":idVULN"] = vulnerability.id;
				_sqlStatement.parameters[":dateCreation"] = new Date();
				_sqlStatement.parameters[":dateModification"] = new Date();

				_sqlStatement.text = query;
				_sqlStatement.addEventListener(SQLEvent.RESULT,affectVulnerabilityOnThreatUpdateResult);
				
				openAndExecStatementInAsyncMode(_sqlStatement);
			}else{
				_sqlStatement.sqlConnection.close();
				responder.result(_primaryKey);
			}
		}
		
		private function affectVulnerabilityOnThreatUpdateResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			if (result != null){
				affectVulnerabilityOnThreatUpdate();				
			}
		}
		
		/************************************************************************/
		/** Récupération de la liste de menace correspondant à l'idTBS d'un SM **/
		/************************************************************************/
		
		public function getThreatListByTBS(id:Number):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = constructThreatListByTBSQuery();
			
			_sqlStatement.parameters[":idSM"]=id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT, getThreatListByTBSResult);
			openAndExecStatementInAsyncMode(_sqlStatement)
		}
		
		private function getThreatListByTBSResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null)
			{				
				var threatList:ArrayCollection =  constructThreatList(result);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(threatList);
			
		}
		
		private function constructThreatListByTBSQuery():String{
			return "SELECT MENACE.idMENACE as idMenace, MENACE.libelle as Menace, TMENACES.idTMENACES as idTMenace,TMENACES.libelle as TMenace, " +
				" TMENACES.exemples as exemples, VULN.idVULN as idVULN, VULN.libelle as vulnerabilite, " +
				" PREREQUIS.idPREREQUIS as idPREREQUIS, PREREQUIS.libelle as prerequis, BS.idTBS " +
				" FROM MENACE , TMENACES, SM, BS " +
				" LEFT OUTER JOIN EXPLOITER ON EXPLOITER.idMENACE = MENACE.idMENACE  " +
				" LEFT OUTER JOIN VULN ON VULN.idVULN = EXPLOITER.idVULN  " +
				" LEFT OUTER JOIN PREREQUIS ON PREREQUIS.idTMENACES = TMENACES.idTMENACES " +
				" where SM.idSM = :idSM " +
				" and TMENACES.idTMENACES = MENACE.idTMENACES " +
				" and (TMENACES.idTBS in (select tbs.idtbs from tbs where tbs.idtbsparent = bs.idtbs and SM.idBS = BS.idBS) " +
				" OR TMENACES.idtbs = bs.idtbs and SM.idBS = BS.idBS)";
		}
	}
}