package com.anssi.ebios.services
{
	import com.anssi.ebios.model.Vulnerability;
	import com.anssi.ebios.model.VulnerabilityType;
	
	import flash.data.SQLResult;
	import flash.data.SQLStatement;
	import flash.events.SQLEvent;
	
	import mx.collections.ArrayCollection;
	import mx.rpc.IResponder;

	public class VulnerabilityService extends AppServices
	{
		
		public var responder:IResponder;
		private var _sqlStatement:SQLStatement;
		private var _vulnerability:Vulnerability ;
		private var _vulnerabilityTypeId:Number = -1;
		
		public function VulnerabilityService(responder:IResponder)
		{
			this.responder = responder;
			this.mode = AppServices.MODE_ASYNCHRONOUS;
		}
		
		/***********************************************************************/
		/** Récupération de la liste des vulnérabilités via le type de menace **/
		/***********************************************************************/
		public function getVulnerabilityListByThreatType(id:Number):void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "SELECT VULN.idVULN as idVULN, VULN.libelle as vuln_libelle " +
							   " FROM VULN, PROFITER " +
							   " WHERE VULN.idTVULN = PROFITER.idTVULN " +
							   " AND PROFITER.idTMENACES = :idTMENACES"
			
			_sqlStatement.parameters[":idTMENACES"] = id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getVulnerabilityListByThreatTypeResult);

			openAndExecStatementInAsyncMode(_sqlStatement);		
			
		}
		
		private function getVulnerabilityListByThreatTypeResult(event:SQLEvent):void{
			var vulnerabilityList:ArrayCollection = null;
			// récupération des résultats
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			// si nous avons des résultats
			if (result != null && result.data != null)
			{
				vulnerabilityList = new ArrayCollection();
				
				var row:Object;
				var numRows:int = result.data.length;
				var vulnerability:Vulnerability;
				for (var i:int = 0; i < numRows; i++)
				{
					row = result.data[i];
					vulnerability = new Vulnerability();
					vulnerability.id = row["idVULN"];
					vulnerability.label = row["vuln_libelle"];
					
					vulnerabilityList.addItem(vulnerability);
				}
			}
			
			_sqlStatement.sqlConnection.close();
			responder.result(vulnerabilityList);
		}
	
		
		/*************************************************/
		/** Récupération de la liste des vulnérabilités **/
		/*************************************************/
		
		public function getVulnerabilityList():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = constructVulnerabilityListQuery();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getVulnerabilityListResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function constructVulnerabilityListQuery(WHERECondition:String = " "):String{
			return "SELECT VULN.idVULN, VULN.libelle as vuln_libelle, VULN.idTVULN as idTVULN ,TVULN.libelle as tvuln_libelle" +
				" FROM VULN, TVULN " +
				" WHERE VULN.idTVULN = TVULN.idTVULN" +
				" " + WHERECondition;
		}
		
		private function getVulnerabilityListResult(event:SQLEvent):void
		{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var vulnerabilityList:ArrayCollection = new ArrayCollection();
			if (result != null && result.data != null)
			{
				vulnerabilityList = constructVulnerabilityList(result);
			}
			_sqlStatement.sqlConnection.close();
			responder.result(vulnerabilityList);
		}
		
		private function constructVulnerabilityList(result:SQLResult):ArrayCollection{
			var dat:Date = new Date();
			var str:String = dat.hours+":"+dat.minutes+":"+dat.seconds+":"+dat.milliseconds ; 			
			var vulnerabilityList:ArrayCollection = new ArrayCollection();
			var row:Object;
			var numRows:int = result.data.length;
			var vulnerability:Vulnerability;
			var vulnerabilityType:VulnerabilityType;
			
			for (var i:int = 0; i < numRows; i++)
			{
				row = result.data[i];
				if (row["idTVULN"] != null){
					vulnerabilityType = new VulnerabilityType();
					vulnerabilityType.id = row["idTVULN"];
					vulnerabilityType.label = row["tvuln_libelle"];
				}
				
				vulnerability = new Vulnerability();
				vulnerability.id = row["idVULN"];
				vulnerability.label = row ["vuln_libelle"];
				vulnerability.vulnerabilityType = vulnerabilityType;
				
				vulnerabilityList.addItem(vulnerability);
			}	
			return vulnerabilityList;
		}
		
		/*************************************************/
		/** Récupération d'une vulnérabilité via son ID **/
		/*************************************************/
		
		public function getVulnerabilityById(id:Number):void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = constructVulnerabilityListQuery('AND VULN.idVULN = '+id);
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,getVulnerabilityByIdResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);	
		}
		
		private function getVulnerabilityByIdResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			if (result != null && result.data != null)
			{
				var vulnerability:Vulnerability = constructVulnerabilityList(result)[0];
			}
			_sqlStatement.sqlConnection.close();
			responder.result(vulnerability);
		}
		
		/*************************************/
		/** Suppression d'une vulnérabilité **/
		/*************************************/
		public function deleteVulnerability(vulnerability:Vulnerability):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM VULN WHERE idVULN = :idVULN";
			
			_sqlStatement.parameters[":idVULN"] = vulnerability.id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,deleteVulnerabilityResult);
			
			_vulnerability = vulnerability;
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function deleteVulnerabilityResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			if (result != null){
				unaffectVulnerabilityOnDelete();
			}
		}
		
		private function unaffectVulnerabilityOnDelete():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM EXPLOITER WHERE idVULN = :idVULN";
			
			_sqlStatement.parameters[":idVULN"] = _vulnerability.id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,unaffectVulnerabilityOnDeleteResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function unaffectVulnerabilityOnDeleteResult(event:SQLEvent):void{
			_sqlStatement.sqlConnection.close();
			responder.result(null);
		}
		
		/**********************************/
		/** Création d'une vulnérabilité **/
		/**********************************/
		public function createVulnerability(vulnerability:Vulnerability):void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "INSERT INTO VULN (idTVULN, libelle, dateCreation, dateModification) " +
				" VALUES (:idTVULN, :libelle, :dateCreation, :dateModification)";
			
			_sqlStatement.parameters[":idTVULN"] = vulnerability.vulnerabilityType.id;
			_sqlStatement.parameters[":libelle"] = vulnerability.label;
			_sqlStatement.parameters[":dateCreation"] = new Date();
			_sqlStatement.parameters[":dateModification"] = new Date();

			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,createVulnerabilityResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function createVulnerabilityResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			var primaryKey:Number;
			if (result != null)
			{
				primaryKey = result.lastInsertRowID;
			}
			_sqlStatement.sqlConnection.close();
			responder.result(primaryKey);
		}
		
		/*************************************/
		/** Mise à jour d'une vulnérabilité **/
		/*************************************/
		/** Si le type de de la vulnérabilité a été modifié, on supprime le lien MENACE - VULN dans la 
		 * table EXPLOITER */
		public function updateVulnerabilityAndChekVulnerabilityTypeChange(vulnerability:Vulnerability):void{
			_vulnerability = vulnerability;
			chekVulnerabilityTypeChange();
		}	
		
		
		private function chekVulnerabilityTypeChange():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "SELECT idTVULN FROM VULN WHERE idVULN = :idVULN";
			
			_sqlStatement.parameters[":idVULN"] = _vulnerability.id;
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,chekVulnerabilityTypeChangeResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function chekVulnerabilityTypeChangeResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			var row:Object;
			
			if (result != null){
				row = result.data[0];
				_vulnerabilityTypeId = row["idTVULN"];
			}
			
			if (_vulnerabilityTypeId != Number(_vulnerability.vulnerabilityType.id)){
				unaffectVulnerabilityOnUpdate();
			}else{
				updateVulnerability();
			}
		}
		
		private function unaffectVulnerabilityOnUpdate():void{
			setBDDName();
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "DELETE FROM EXPLOITER WHERE idVULN = :idVULN";
			
			_sqlStatement.parameters[":idVULN"] = _vulnerability.id;
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,unaffectVulnerabilityOnUpdateResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);
		}
		
		private function unaffectVulnerabilityOnUpdateResult(event:SQLEvent):void{
			updateVulnerability();
		}
		
		private function updateVulnerability():void{
			setBDDName();
			
			_sqlStatement = new SQLStatement();
			
			_sqlStatement.sqlConnection = this.sqlConnection;
			var query:String = "UPDATE VULN SET libelle = :libelle ," +
				" idTVULN = :idTVULN , " +
				" dateModification = :dateModification" +
				" WHERE idVULN = :idVULN";
			
			_sqlStatement.parameters[":idTVULN"] = _vulnerability.vulnerabilityType.id;
			_sqlStatement.parameters[":libelle"] = _vulnerability.label;
			_sqlStatement.parameters[":idVULN"] = _vulnerability.id;
			_sqlStatement.parameters[":dateModification"] = new Date();
			
			_sqlStatement.text = query;
			_sqlStatement.addEventListener(SQLEvent.RESULT,updateVulnerabilityResult);
			
			openAndExecStatementInAsyncMode(_sqlStatement);		
		}
		
		private function updateVulnerabilityResult(event:SQLEvent):void{
			var result:SQLResult = SQLStatement(event.target).getResult();
			
			var primaryKey:Number;
			primaryKey = SQLStatement(event.target).parameters[":idVULN"];
			
			_sqlStatement.sqlConnection.close();
			responder.result(primaryKey);
		}
	}
}